<?php
/**
 * Class model decor
 *
 * @package wp-viral-click
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPPdc_Model_Deco' )) {

  /**
   * Class model decor
   */
  class IPPdc_Model_Deco
  {
    /**
     * Take setting name
     *
     * @var string
     */
    protected $_settingName = '__ippdc-deco-setting';

    /**
     * Save setting
     *
     * @param  int $postId
     * @return void
     */
    public function saveSetting( $postId )
    {
      $postId   = absint( $postId );
      $data     = $this->_getSettingData( $postId );
      $setting  = new IPPdc_Setting( $postId, $this->_settingName );
      $result   = $setting->setSettings( $data );
      return $result;
    }

    /**
     * Get setting data
     *
     * @param  int $postId
     * @return array
     */
    protected function _getSettingData( $postId )
    {
      $settings = array();
      $data     = array_merge( $_POST, $_GET );

      if ( empty( $data['type'] )) {
        return $settings;
      }
      $type = apply_filters( 'pre_term_name', $data['type'] );
      $settings['type'] = $type;

      //
      //
      //Save style settings
      //
      if ( isset( $data['width'] )) {
        $settings['width'] = absint( $data['width'] );
      }
      if ( isset( $data['height'] )) {
        $settings['height'] = absint( $data['height'] );
      }
      if ( isset( $data['window_width'] )) {
        $settings['window_width'] = absint( $data['window_width'] );
      }
      if ( isset( $data['window_height'] )) {
        $settings['window_height'] = absint( $data['window_height'] );
      }
      if ( isset( $data['opacity'] )) {
        $settings['opacity'] = apply_filters( 'pre_term_name', $data['opacity'] );
      }

      //
      //
      //Save position settings
      //
      if ( isset( $data['top'] )) {
        $settings['top'] = absint( $data['top'] );
      }
      if ( isset( $data['left'] )) {
        $settings['left'] = absint( $data['left'] );
      }
      if ( isset( $data['zindex'] )) {
        $settings['zindex'] = absint( $data['zindex'] );
      }
      if ( isset( $data['pos_helper'] )) {
        $settings['pos_helper'] = apply_filters( 'pre_term_name', $data['pos_helper'] );
      }

      //
      //
      //Save duration settings
      //
      if ( isset( $data['date_start'] )) {
        $settings['date_start'] = apply_filters( 'single_post_title', $data['date_start'] );
      }
      if ( isset( $data['date_end'] )) {
        $settings['date_end'] = apply_filters( 'single_post_title', $data['date_end'] );
      }

      //
      //Image
      if ( $type == 'image' ) {
        $image    = $this->_getSettingImage( $data );
        $settings = array_merge( $settings, $image );
      }

      //
      //Video
      if ( $type == 'video' ) {
        $video    = $this->_getSettingVideo( $data );
        $settings = array_merge( $settings, $video );
      }

      //
      //Effect
      if ( $type == 'effect' ) {
        $effect   = $this->_getSettingEffect( $data );
        $settings = array_merge( $settings, $effect );
      }

      //
      //Note
      if ( $type == 'note' ) {
        $note     = $this->_getSettingNote( $data );
        $settings = array_merge( $settings, $note );
      }

      //
      //Box
      if ( $type == 'box' ) {
        $box      = $this->_getSettingBox( $data );
        $settings = array_merge( $settings, $box );
      }

      return $settings;
    }

    /**
     * Get setting image data
     *
     * @param  array $data
     * @return array
     */
    protected function _getSettingImage( $data )
    {
      $settings = array();
      //
      //Image
      if ( isset( $data['image'] )) {
        $settings['image'] = apply_filters( 'single_post_title', $data['image'] );
      }
      //Image type
      if ( isset( $data['image_type'] )) {
        $settings['image_type'] = apply_filters( 'pre_term_name', $data['image_type'] );
      }
      return $settings;
    }

    /**
     * Get setting effect data
     *
     * @param  array $data
     * @return array
     */
    protected function _getSettingEffect( $data )
    {
      $settings = array();

      //Effect type
      if ( isset( $data['effect_type'] )) {
        $settings['effect_type'] = apply_filters( 'pre_term_name', $data['effect_type'] );
      }
      //Effect color
      if ( isset( $data['effect_color'] )) {
        $settings['effect_color'] = apply_filters( 'pre_term_name', $data['effect_color'] );
      }

      return $settings;
    }

    /**
     * Get setting video data
     *
     * @param  array $data
     * @return array
     */
    protected function _getSettingVideo( $data )
    {
      $settings = array();
      //
      //Video ID
      if ( isset( $data['video_id'] )) {
        $settings['video_id'] = apply_filters( 'pre_term_name', $data['video_id'] );
      }
      //
      //Video Autoplay
      if ( isset( $data['autoplay'] )) {
        $settings['autoplay'] = apply_filters( 'pre_term_name', $data['autoplay'] );
      }
      return $settings;
    }

    /**
     * Get setting note data
     *
     * @param  array $data
     * @return array
     */
    protected function _getSettingNote( $data )
    {
      $settings = array();
      //
      //Content
      if ( isset( $data['content'] )) {
        $settings['content'] = apply_filters( 'single_post_title', $data['content'] );
      }
      //
      //Background color
      if ( isset( $data['bgcolor'] )) {
        $settings['bgcolor'] = apply_filters( 'single_post_title', $data['bgcolor'] );
      }
      //
      //Color
      if ( isset( $data['color'] )) {
        $settings['color'] = apply_filters( 'single_post_title', $data['color'] );
      }
      //
      //Border Color
      if ( isset( $data['border_color'] )) {
        $settings['border_color'] = apply_filters( 'single_post_title', $data['border_color'] );
      }
      //
      //Border Size
      if ( isset( $data['border_size'] )) {
        $settings['border_size'] = absint( $data['border_size'] );
      }
      return $settings;
    }

    /**
     * Get setting box data
     *
     * @param  array $data
     * @return array
     */
    protected function _getSettingBox( $data )
    {
      $settings = array();

      //
      //title
      if ( isset( $data['title'] )) {
        $settings['title'] = apply_filters( 'single_post_title', $data['title'] );
      }
      //
      //Content
      if ( isset( $data['content'] )) {
        $settings['content'] = apply_filters( 'single_post_title', $data['content'] );
      }
      //
      //Button Label
      if ( isset( $data['button_label'] )) {
        $settings['button_label'] = apply_filters( 'single_post_title', $data['button_label'] );
      }
      //
      //Button URL
      if ( isset( $data['button_url'] )) {
        $settings['button_url'] = apply_filters( 'pre_link_url', $data['button_url'] );
      }
      //
      //Background color
      if ( isset( $data['bgcolor'] )) {
        $settings['bgcolor'] = apply_filters( 'single_post_title', $data['bgcolor'] );
      }
      //
      //Color
      if ( isset( $data['color'] )) {
        $settings['color'] = apply_filters( 'single_post_title', $data['color'] );
      }
      //
      //Border Color
      if ( isset( $data['border_color'] )) {
        $settings['border_color'] = apply_filters( 'single_post_title', $data['border_color'] );
      }
      //
      //Border Size
      if ( isset( $data['border_size'] )) {
        $settings['border_size'] = absint( $data['border_size'] );
      }
      //
      //Button style
      if ( isset( $data['button_style'] )) {
        $settings['button_style'] = apply_filters( 'pre_term_name', $data['button_style'] );
      }
      //
      //Button color
      if ( isset( $data['button_color'] )) {
        $settings['button_color'] = apply_filters( 'pre_term_name', $data['button_color'] );
      }

      return $settings;
    }

  }
}
