<?php
if ( ! class_exists( 'IPPdc_Viewer' ))
{
  /**
   * Viewer class
   *
   * @package wp-instant-decor-plus
   * @author InstaProduct
   * @link http://insta-product.com/
   */

  class IPPdc_Viewer
  {
    //{{ front

    /**
     * Front viewer
     *
     * @return void
     */
    public function front()
    {
      global $post;

      $pageId = false;
      if ( is_page() || is_single() ) {
				$pageId = $post->ID;
			}
      $decos = $this->_getDecorations( $pageId );
      $decos = $this->_checkDurations( $decos );
      $this->decorations = $decos;

      $this->view( 'front/main' );
    }

    //}}
    //{{ frontAdmin

    /**
     * Front viewer
     *
     * @return void
     */
    public function frontAdmin()
    {
      global $user_ID;

      if ( empty( $user_ID )) {
        return false;
      }
      $this->pageId = IPPDC_PAGENAME;

      $this->view( 'admin/main' );
    }

    //}}
    //{{ view

    /**
     * Get admin view file
     *
     * @param string $filename
     * @return void
     */
    public function view( $filename )
    {
      $path  = IPPDC_VIEW;
      $path .= strtolower( $filename ) . '.php';
      if ( file_exists( $path )) {
        include( $path );
      }
    }

    //}}
    //{{ _checkDurations

    /**
     * Check duration for all decorations
     *
     * @param  array $decorations
     * @return array
     */
    protected function _checkDurations( $decorations )
    {
      if ( empty( $decorations )) {
        return false;
      }
      $results = array();
      foreach( $decorations as $deco )
      {
        $setting   = new IPPdc_Setting( $deco->ID, '__ippdc-deco-setting' );
        $dateStart = $setting->getSetting( 'date_start' );
        $dateEnd   = $setting->getSetting( 'date_end' );
        $now       = time();

        if ( $dateStart && ! $dateEnd )
        {
          $start = strtotime( $dateStart );
          if ( $now > $start ) {
            $results[] = $deco;
          }
        }
        else if ( $dateStart && $dateEnd )
        {
          $start = strtotime( $dateStart );
          $end   = strtotime( $dateEnd );
          if ( $now > $start && $now < $end ) {
            $results[] = $deco;
          }
        }
        else
        {
          $results[] = $deco;
        }
      }
      return $results;
    }

    //}}
    //{{ _getDecorations

    /**
     * Get all decorations
     *
     * @param  ind $pageId
     * @return void
     */
    protected function _getDecorations( $pageId  = false )
    {
      $args = array(
          'orderby'        => 'post_date',
          'order'          => 'DESC',
          'post_type'      => 'ippdc_deco',
          'post_status'    => array('publish'),
          'posts_per_page' => -1,
          'paged'          => 1
      );
      if ( $pageId ) {
        $args['post_parent'] = absint( $pageId );
      }
      $query  = new WP_Query;
      $result = $query->query( $args );

      return $result;
    }

    //}}
  }
}
