<?php
/**
 * Main application class
 *
 * @package wp-instant-decor-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

//
//Model
require_once( IPPDC_APP . '/models/deco.php' );

//
//Include all function files
require_once( IPPDC_LIB . '/config.php' );
require_once( IPPDC_LIB . '/setting.php' );
require_once( IPPDC_LIB . '/font.php' );
require_once( IPPDC_LIB . '/faicon.php' );
require_once( IPPDC_APP . '/controller.php' );
require_once( IPPDC_APP . '/viewer.php' );
//Color library
if ( ! class_exists( 'phpColor' )) {
	require_once( IPPDC_LIB . '/Color.php' );
}

if ( ! class_exists( 'IPPdc_App' ))
{
	class IPPdc_App
	{
		//{{ run

		/**
		 * Run all functions
		 *
		 * @return void
		 */
		public static function run()
		{
			$hook = sanitize_title( IPPDC_TITLE );

			//
			//Admin init
			add_action( 'admin_init', array( __CLASS__, 'adminInit' ) );

      add_action( 'wp_footer', array( __CLASS__, 'front' ) );

			//Add admin bar menu
			add_action('admin_bar_menu', array( __CLASS__, 'barMenu' ), 999);

			//
      //Front style & script
      add_action('wp_head', array( __CLASS__, 'publicStyle' ) );

      if ( ! is_admin() ) {
        add_action('wp_enqueue_scripts', array( __CLASS__, 'publicScript' ), 10 );
      }
		}

		//}}
		//{{ adminInit

		/**
		 * Admin init
		 *
		 * @return void
		 */
		public static function adminInit()
		{
			/**
			 * Ajax handler
			 **/
			$controller = new IPPdc_Controller();
			$controller->ajax();
		}

		//}}
		//{{ front

		/**
		 * Front settings view
		 *
		 * @return void
		 */
		public static function front()
		{
			$viewer = new IPPdc_Viewer();
			$viewer->frontAdmin();
			$viewer->front();
		}

		//}}
		//{{ barMenu

		/**
		 * Bar menu view
		 *
		 * @param  object $admin_bar
		 * @return void
		 */
		public static function barMenu( $admin_bar )
		{
			if ( is_admin() ) {
				return true;
			}

			if ( is_home() || is_single() || is_page() )
			{
				$admin_bar->add_node( array(
			    'id'     => 'ippcd-menu',
			    'title'  => __( 'Add Page Decorator', IPPDC_SLUG ),
			    'href'   => '#',
			    'meta'   => array(
		        'title' => __('Add Page Decorator', IPPDC_SLUG ),
			    ),
				) );

				$admin_bar->add_menu( array(
			    'id'     => 'ippcd-menu-image',
			    'title'  => __( 'Image', IPPDC_SLUG ),
					'parent' => 'ippcd-menu',
			    'href'   => '#ippcd-modal-image',
			    'meta'   => array(
		        'title' => __('Add Image Decorator', IPPDC_SLUG ),
						'class' => 'remodal-btn'
			    ),
				) );

				$admin_bar->add_menu( array(
			    'id'     => 'ippcd-menu-effect',
			    'title'  => __( 'Snow Effect', IPPDC_SLUG ),
					'parent' => 'ippcd-menu',
			    'href'   => '#ippcd-modal-effect',
			    'meta'   => array(
		        'title' => __('Add Snow Effect Decorator', IPPDC_SLUG ),
						'class' => 'remodal-btn'
			    ),
				) );

				$admin_bar->add_menu( array(
			    'id'     => 'ippcd-menu-video',
			    'title'  => __( 'Video', IPPDC_SLUG ),
					'parent' => 'ippcd-menu',
			    'href'   => '#ippcd-modal-video',
			    'meta'   => array(
		        'title' => __('Add Video Decorator', IPPDC_SLUG ),
						'class' => 'remodal-btn'
			    ),
				) );

				$admin_bar->add_menu( array(
			    'id'     => 'ippcd-menu-note',
			    'title'  => __( 'Note', IPPDC_SLUG ),
					'parent' => 'ippcd-menu',
			    'href'   => '#ippcd-modal-note',
			    'meta'   => array(
		        'title' => __('Add Note', IPPDC_SLUG ),
						'class' => 'remodal-btn'
			    ),
				) );

				$admin_bar->add_menu( array(
			    'id'     => 'ippcd-menu-box',
			    'title'  => __( 'Box', IPPDC_SLUG ),
					'parent' => 'ippcd-menu',
			    'href'   => '#ippcd-modal-box',
			    'meta'   => array(
		        'title' => __('Add Box', IPPDC_SLUG ),
						'class' => 'remodal-btn'
			    ),
				) );
			}

			return $admin_bar;
		}

    //}}
    //{{ publicStyle

    /**
     * Print public style
     *
     * @return void
     */
    public static function publicStyle()
    {
			global $user_ID;

			if ( ! empty( $user_ID ))
			{
				wp_deregister_style( 'ippdc-colorpicker' );
				wp_register_style(
					'ippdc-colorpicker',
					IPPDC_BASE_URL . 'assets/css/colorpicker.css',
					false,
					null
				);
				wp_enqueue_style('ippdc-colorpicker');

				wp_deregister_style( 'ippdc-colorpicker-layout' );
				wp_register_style(
					'ippdc-colorpicker-layout',
					IPPDC_BASE_URL . 'assets/css/layout.css',
					false,
					null
				);
				wp_enqueue_style('ippdc-colorpicker-layout');

				wp_deregister_style( 'remodal' );
				wp_register_style(
					'remodal',
					IPPDC_BASE_URL . 'assets/css/remodal.css',
					false,
					null
				);
				wp_enqueue_style('remodal');

				wp_deregister_style( 'remodal-theme' );
				wp_register_style(
					'remodal-theme',
					IPPDC_BASE_URL . 'assets/css/remodal-default-theme.css',
					false,
					null
				);
				wp_enqueue_style('remodal-theme');

				wp_enqueue_style('ip-datetime-style');
				wp_deregister_style( 'ip-datetime-style' );
				wp_register_style(
					'ip-datetime-style',
					IPPDC_BASE_URL . 'assets/css/jquery.datetimepicker.css',
					false,
					null
				);
				wp_enqueue_style('ip-datetime-style');

				wp_deregister_style( 'ippdc-public-option-style' );
				wp_register_style(
					'ippdc-public-option-style',
					IPPDC_BASE_URL . 'assets/css/public-option.min.css',
					false,
					null
				);
				wp_enqueue_style('ippdc-public-option-style');

			}

			wp_deregister_style( 'ippdc-public-style' );
			wp_register_style(
				'ippdc-public-style',
				IPPDC_BASE_URL . 'assets/css/public.min.css',
				false,
				null
			);
			wp_enqueue_style('ippdc-public-style');
    ?>
			<?php
			if ( ! empty( $user_ID )) {
				echo '<link href="https://fonts.googleapis.com/css?family=Roboto+Condensed:300,400,400i,700,700i" rel="stylesheet">';
			}

			global $post;

			if ( is_home() ) {
				$typePage = 'home';
			}
			elseif ( is_page() || is_single() ) {
				$typePage = 'page';
			}
			if ( $post ) {
				$postId = $post->ID;
			}

			$updirs = wp_upload_dir();
			?>
      <script type="text/javascript">
        var ippdc_ajaxurl    		 = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
        var ippdc_img_url    		 = '<?php echo IPPDC_BASE_URL . 'assets/img/'; ?>';
        var ippdc_deco_img_url	 = '<?php echo IPPDC_BASE_URL . 'assets/deco-images/'; ?>';
        var ippdc_effect_img_url = '<?php echo IPPDC_BASE_URL . 'assets/effects/'; ?>';
        var ippdc_upload_url 		 = '<?php echo $updirs['baseurl']; ?>/';
        var ippdc_typePage   		 = '<?php echo $typePage; ?>';
        var ippdc_postId     		 = '<?php echo $postId; ?>';
				var ippdc_messages   		 = {

					'system_error': '<?php _e( 'There is a system error that made decorations can not be added.', IPPDC_SLUG ); ?>',

					'effect_type': '<?php _e( 'You must set the type of the background effect.', IPPDC_SLUG ); ?>',
					'effect_color': '<?php _e( 'You must set the color of the background effect.', IPPDC_SLUG ); ?>',

					'video_url': '<?php _e( 'You must enter the url of the youtube video.', IPPDC_SLUG ); ?>',
					'video_autoplay': '<?php _e( 'You must set the autoplay method of the video.', IPPDC_SLUG ); ?>',
					'video_height': '<?php _e( 'You must specify the height of the video.', IPPDC_SLUG ); ?>',
					'video_width': '<?php _e( 'You must specify the width of the video.', IPPDC_SLUG ); ?>',

					'note_content': '<?php _e( 'You must enter the note content.', IPPDC_SLUG ); ?>',
					'note_height': '<?php _e( 'You must specify the height of the note.', IPPDC_SLUG ); ?>',
					'note_width': '<?php _e( 'You must specify the width of the note.', IPPDC_SLUG ); ?>',

					'box_title': '<?php _e( 'You must enter the title of the box.', IPPDC_SLUG ); ?>',
					'box_content': '<?php _e( 'You must enter the content of the box.', IPPDC_SLUG ); ?>',
					'box_button_label': '<?php _e( 'You must enter the label of the button.', IPPDC_SLUG ); ?>',
					'box_button_url': '<?php _e( 'You must enter the url of the button.', IPPDC_SLUG ); ?>',
					'box_height': '<?php _e( 'You must specify the height of the box.', IPPDC_SLUG ); ?>',
					'box_width': '<?php _e( 'You must specify the width of the box.', IPPDC_SLUG ); ?>',
				};
				<?php
				if ( ! empty( $user_ID )) {
					echo 'var ippdc_isLogin = true;';
				} else {
					echo 'var ippdc_isLogin = false;';
				}
				?>
      </script>

    <?php
    }

    //}}
    //{{ publicScript

    /**
     * Print public script
     *
     * @return void
     */
    public static function publicScript()
    {
			global $user_ID;

      wp_enqueue_script('jquery');

      wp_deregister_script('jquery-ui');
      wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
      wp_enqueue_script('jquery-ui');


			if ( ! empty( $user_ID ))
			{
	      wp_deregister_script('ippdc-colorpicker');
	      wp_enqueue_script(
	        'ippdc-colorpicker',
	        IPPDC_BASE_URL . 'assets/js/third_party/colorpicker.js',
	        array( 'jquery' ),
	        1,
	        true
	      );
	      wp_deregister_script('ippdc-colorpicker-eye');
	      wp_enqueue_script(
	        'ippdc-colorpicker-eye',
	        IPPDC_BASE_URL . 'assets/js/third_party/eye.js',
	        array( 'jquery' ),
	        1,
	        true
	      );
	      wp_deregister_script('ippdc-colorpicker-utils');
	      wp_enqueue_script(
	        'ippdc-colorpicker-utils',
	        IPPDC_BASE_URL . 'assets/js/third_party/utils.js',
	        array( 'jquery' ),
	        1,
	        true
	      );
	      wp_deregister_script('ippdc-colorpicker-layout');
	      wp_enqueue_script(
	        'ippdc-colorpicker-layout',
	        IPPDC_BASE_URL . 'assets/js/third_party/layout.js',
	        array( 'jquery' ),
	        1,
	        true
	      );

	      wp_deregister_script('ippdc-public-option-script');
	      wp_enqueue_script(
	        'ippdc-public-option-script',
	        IPPDC_BASE_URL . 'assets/js/public-option.js',
	        array( 'jquery' ),
	        1,
	        true
	      );
			}
			else
			{
	      wp_deregister_script('ippdc-public-script');
	      wp_enqueue_script(
	        'ippdc-public-script',
	        IPPDC_BASE_URL . 'assets/js/public.min.js',
	        array( 'jquery' ),
	        1,
	        true
	      );
			}

    }
		//}}
	}
}
