/*  Snowfall jquery plugin

    ====================================================================
    LICENSE
    ====================================================================
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing, software
       distributed under the License is distributed on an "AS IS" BASIS,
       WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
       See the License for the specific language governing permissions and
       limitations under the License.
    ====================================================================

    Version 1.51 Dec 2nd 2012
    // fixed bug where snow collection didn't happen if a valid doctype was declared.

    Version 1.5 Oct 5th 2011
    Added collecting snow! Uses the canvas element to collect snow. In order to initialize snow collection use the following

    $(document).snowfall({collection : 'element'});

    element = any valid jquery selector.

    The plugin then creates a canvas above every element that matches the selector, and collects the snow. If there are a varrying amount of elements the
    flakes get assigned a random one on start they will collide.

    Version 1.4 Dec 8th 2010
    Fixed issues (I hope) with scroll bars flickering due to snow going over the edge of the screen.
    Added round snowflakes via css, will not work for any version of IE. - Thanks to Luke Barker of http://www.infinite-eye.com/
    Added shadows as an option via css again will not work with IE. The idea behind shadows, is to show flakes on lighter colored web sites - Thanks Yutt

    Version 1.3.1 Nov 25th 2010
    Updated script that caused flakes not to show at all if plugin was initialized with no options, also added the fixes that Han Bongers suggested

    Developed by Jason Brown for any bugs or questions email me at loktar69@hotmail
    info on the plugin is located on Somethinghitme.com

    values for snow options are

    flakeCount,
    flakeColor,
    flakeIndex,
    minSize,
    maxSize,
    minSpeed,
    maxSpeed,
    round,      true or false, makes the snowflakes rounded if the browser supports it.
    shadow      true or false, gives the snowflakes a shadow if the browser supports it.

    Example Usage :
    $(document).snowfall({flakeCount : 100, maxSpeed : 10});

    -or-

    $('#element').snowfall({flakeCount : 800, maxSpeed : 5, maxSize : 5});

    -or with defaults-

    $(document).snowfall();

    - To clear -
    $('#element').snowfall('clear');
*/

// requestAnimationFrame polyfill from https://github.com/darius/requestAnimationFrame
if (!Date.now)
    Date.now = function() { return new Date().getTime(); };

(function() {
    'use strict';

    var vendors = ['webkit', 'moz'];
    for (var i = 0; i < vendors.length && !window.requestAnimationFrame; ++i) {
        var vp = vendors[i];
        window.requestAnimationFrame = window[vp+'RequestAnimationFrame'];
        window.cancelAnimationFrame = (window[vp+'CancelAnimationFrame']
                                   || window[vp+'CancelRequestAnimationFrame']);
    }
    if (/iP(ad|hone|od).*OS 6/.test(window.navigator.userAgent) // iOS6 is buggy
        || !window.requestAnimationFrame || !window.cancelAnimationFrame) {
        var lastTime = 0;
        window.requestAnimationFrame = function(callback) {
            var now = Date.now();
            var nextTime = Math.max(lastTime + 16, now);
            return setTimeout(function() { callback(lastTime = nextTime); },
                              nextTime - now);
        };
        window.cancelAnimationFrame = clearTimeout;
    }
}());

(function($){
    $.snowfall = function(element, options){
        var flakes = [],
            defaults = {
                flakeCount : 35,
                flakeColor : '#ffffff',
				flakePosition: 'absolute',
                flakeIndex: 999999,
                minSize : 1,
                maxSize : 2,
                minSpeed : 1,
                maxSpeed : 5,
                round : false,
                shadow : false,
                collection : false,
                collectionHeight : 40,
                deviceorientation : false
            },
            options = $.extend(defaults, options),
            random = function random(min, max){
                return Math.round(min + Math.random()*(max-min));
            };

            $(element).data("snowfall", this);

            // Snow flake object
            function Flake(_x, _y, _size, _speed){
                // Flake properties
                this.x  = _x;
                this.y  = _y;
                this.size = _size;
                this.speed = _speed;
                this.step = 0;
                this.stepSize = random(1,10) / 100;

                if(options.collection){
                    this.target = canvasCollection[random(0,canvasCollection.length-1)];
                }

                var flakeMarkup = null;

                if(options.image){
                    flakeMarkup = document.createElement("img");
                    flakeMarkup.src = options.image;
                }else{
                    flakeMarkup = document.createElement("div");
                    $(flakeMarkup).css({'background' : options.flakeColor});
                }

                $(flakeMarkup).attr({
                    'class': 'snowfall-flakes',
                }).css({
                    'width' : this.size,
                    'height' : this.size,
                    'position' : options.flakePosition,
                    'top' : this.y,
                    'left' : this.x,
                    'fontSize' : 0,
                    'zIndex' : options.flakeIndex
                });

                if($(element).get(0).tagName === $(document).get(0).tagName){
                    $('body').append($(flakeMarkup));
                    element = $('body');
                }else{
                    $(element).append($(flakeMarkup));
                }

                this.element = flakeMarkup;

                // Update function, used to update the snow flakes, and checks current snowflake against bounds
                this.update = function(){
                    this.y += this.speed;

                    if(this.y > (elHeight) - (this.size  + 6)){
                        this.reset();
                    }

                    this.element.style.top = this.y + 'px';
                    this.element.style.left = this.x + 'px';

                    this.step += this.stepSize;

                    if (doRatio === false) {
                        this.x += Math.cos(this.step);
                    } else {
                        this.x += (doRatio + Math.cos(this.step));
                    }

                    // Pileup check
                    if(options.collection){
                        if(this.x > this.target.x && this.x < this.target.width + this.target.x && this.y > this.target.y && this.y < this.target.height + this.target.y){
                            var ctx = this.target.element.getContext("2d"),
                                curX = this.x - this.target.x,
                                curY = this.y - this.target.y,
                                colData = this.target.colData;

                                if(colData[parseInt(curX)][parseInt(curY+this.speed+this.size)] !== undefined || curY+this.speed+this.size > this.target.height){
                                    if(curY+this.speed+this.size > this.target.height){
                                        while(curY+this.speed+this.size > this.target.height && this.speed > 0){
                                            this.speed *= .5;
                                        }

                                        ctx.fillStyle = defaults.flakeColor;

                                        if(colData[parseInt(curX)][parseInt(curY+this.speed+this.size)] == undefined){
                                            colData[parseInt(curX)][parseInt(curY+this.speed+this.size)] = 1;
                                            ctx.fillRect(curX, (curY)+this.speed+this.size, this.size, this.size);
                                        }else{
                                            colData[parseInt(curX)][parseInt(curY+this.speed)] = 1;
                                            ctx.fillRect(curX, curY+this.speed, this.size, this.size);
                                        }
                                        this.reset();
                                    }else{
                                        // flow to the sides
                                        this.speed = 1;
                                        this.stepSize = 0;

                                        if(parseInt(curX)+1 < this.target.width && colData[parseInt(curX)+1][parseInt(curY)+1] == undefined ){
                                            // go left
                                            this.x++;
                                        }else if(parseInt(curX)-1 > 0 && colData[parseInt(curX)-1][parseInt(curY)+1] == undefined ){
                                            // go right
                                            this.x--;
                                        }else{
                                            //stop
                                            ctx.fillStyle = defaults.flakeColor;
                                            ctx.fillRect(curX, curY, this.size, this.size);
                                            colData[parseInt(curX)][parseInt(curY)] = 1;
                                            this.reset();
                                        }
                                    }
                                }
                        }
                    }

                    if(this.x + this.size > (elWidth) - widthOffset || this.x < widthOffset){
                        this.reset();
                    }
                }

                // Resets the snowflake once it reaches one of the bounds set
                this.reset = function(){
                    this.y = 0;
                    this.x = random(widthOffset, elWidth - widthOffset);
                    this.stepSize = random(1,10) / 100;
                    this.size = random((options.minSize * 100), (options.maxSize * 100)) / 100;
                    this.element.style.width = this.size + 'px';
                    this.element.style.height = this.size + 'px';
                    this.speed = random(options.minSpeed, options.maxSpeed);
                }
            }

            // local vars
            var i = 0,
                elHeight = $(element).height(),
                elWidth = $(element).width(),
                widthOffset = 0,
                snowTimeout = 0;

            // Collection Piece ******************************
            if(options.collection !== false){
                var testElem = document.createElement('canvas');
                if(!!(testElem.getContext && testElem.getContext('2d'))){
                    var canvasCollection = [],
                        elements = $(options.collection),
                        collectionHeight = options.collectionHeight;

                    for(var i =0; i < elements.length; i++){
                            var bounds = elements[i].getBoundingClientRect(),
                                $canvas = $('<canvas/>',
                                    {
                                        'class' : 'snowfall-canvas'
                                    }),
                                collisionData = [];

                            if(bounds.top-collectionHeight > 0){
                                $('body').append($canvas);

                                $canvas.css({
                                    'position' : options.flakePosition,
                                    'left'     : bounds.left + 'px',
                                    'top'      : bounds.top-collectionHeight + 'px'
                                })
                                .prop({
                                    width: bounds.width,
                                    height: collectionHeight
                                });

                                for(var w = 0; w < bounds.width; w++){
                                    collisionData[w] = [];
                                }

                                canvasCollection.push({
                                    element : $canvas.get(0),
                                    x : bounds.left,
                                    y : bounds.top-collectionHeight,
                                    width : bounds.width,
                                    height: collectionHeight,
                                    colData : collisionData
                                });
                            }
                    }
                }else{
                    // Canvas element isnt supported
                    options.collection = false;
                }
            }
            // ************************************************

            // This will reduce the horizontal scroll bar from displaying, when the effect is applied to the whole page
            if($(element).get(0).tagName === $(document).get(0).tagName){
                widthOffset = 25;
            }

            // Bind the window resize event so we can get the innerHeight again
            $(window).bind("resize", function(){
                elHeight = $(element)[0].clientHeight;
                elWidth = $(element)[0].offsetWidth;
            });


            // initialize the flakes
            for(i = 0; i < options.flakeCount; i+=1){
                flakes.push(new Flake(random(widthOffset,elWidth - widthOffset), random(0, elHeight), random((options.minSize * 100), (options.maxSize * 100)) / 100, random(options.minSpeed, options.maxSpeed)));
            }

            // This adds the style to make the snowflakes round via border radius property
            if(options.round){
                $('.snowfall-flakes').css({'-moz-border-radius' : options.maxSize, '-webkit-border-radius' : options.maxSize, 'border-radius' : options.maxSize});
            }

            // This adds shadows just below the snowflake so they pop a bit on lighter colored web pages
            if(options.shadow){
                $('.snowfall-flakes').css({'-moz-box-shadow' : '1px 1px 1px #555', '-webkit-box-shadow' : '1px 1px 1px #555', 'box-shadow' : '1px 1px 1px #555'});
            }

            // On newer Macbooks Snowflakes will fall based on deviceorientation
            var doRatio = false;
            if (options.deviceorientation) {
                $(window).bind('deviceorientation', function(event) {
                    doRatio = event.originalEvent.gamma * 0.1;
                });
            }

            // this controls flow of the updating snow
            function snow(){
                for( i = 0; i < flakes.length; i += 1){
                    flakes[i].update();
                }

                snowTimeout = requestAnimationFrame(function(){snow()});
            }

            snow();

            // clears the snowflakes
            this.clear = function(){
                $('.snowfall-canvas').remove();
                $(element).children('.snowfall-flakes').remove();
                cancelAnimationFrame(snowTimeout);
            }
    };

    // Initialize the options and the plugin
    $.fn.snowfall = function(options){
        if(typeof(options) == "object" || options == undefined){
                 return this.each(function(i){
                    (new $.snowfall(this, options));
                });
        }else if (typeof(options) == "string") {
            return this.each(function(i){
                var snow = $(this).data('snowfall');
                if(snow){
                    snow.clear();
                }
            });
        }
    };
})(jQuery);

/*
 *  Remodal - v1.1.0
 *  Responsive, lightweight, fast, synchronized with CSS animations, fully customizable modal window plugin with declarative configuration and hash tracking.
 *  http://vodkabears.github.io/remodal/
 *
 *  Made by Ilya Makarov
 *  Under MIT License
 */

!(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    define(['jquery'], function($) {
      return factory(root, $);
    });
  } else if (typeof exports === 'object') {
    factory(root, require('jquery'));
  } else {
    factory(root, root.jQuery || root.Zepto);
  }
})(this, function(global, $) {

  'use strict';

  /**
   * Name of the plugin
   * @private
   * @const
   * @type {String}
   */
  var PLUGIN_NAME = 'remodal';

  /**
   * Namespace for CSS and events
   * @private
   * @const
   * @type {String}
   */
  var NAMESPACE = global.REMODAL_GLOBALS && global.REMODAL_GLOBALS.NAMESPACE || PLUGIN_NAME;

  /**
   * Animationstart event with vendor prefixes
   * @private
   * @const
   * @type {String}
   */
  var ANIMATIONSTART_EVENTS = $.map(
    ['animationstart', 'webkitAnimationStart', 'MSAnimationStart', 'oAnimationStart'],

    function(eventName) {
      return eventName + '.' + NAMESPACE;
    }

  ).join(' ');

  /**
   * Animationend event with vendor prefixes
   * @private
   * @const
   * @type {String}
   */
  var ANIMATIONEND_EVENTS = $.map(
    ['animationend', 'webkitAnimationEnd', 'MSAnimationEnd', 'oAnimationEnd'],

    function(eventName) {
      return eventName + '.' + NAMESPACE;
    }

  ).join(' ');

  /**
   * Default settings
   * @private
   * @const
   * @type {Object}
   */
  var DEFAULTS = $.extend({
    hashTracking: true,
    closeOnConfirm: true,
    closeOnCancel: true,
    closeOnEscape: true,
    closeOnOutsideClick: true,
    modifier: '',
    appendTo: null
  }, global.REMODAL_GLOBALS && global.REMODAL_GLOBALS.DEFAULTS);

  /**
   * States of the Remodal
   * @private
   * @const
   * @enum {String}
   */
  var STATES = {
    CLOSING: 'closing',
    CLOSED: 'closed',
    OPENING: 'opening',
    OPENED: 'opened'
  };

  /**
   * Reasons of the state change.
   * @private
   * @const
   * @enum {String}
   */
  var STATE_CHANGE_REASONS = {
    CONFIRMATION: 'confirmation',
    CANCELLATION: 'cancellation'
  };

  /**
   * Is animation supported?
   * @private
   * @const
   * @type {Boolean}
   */
  var IS_ANIMATION = (function() {
    var style = document.createElement('div').style;

    return style.animationName !== undefined ||
      style.WebkitAnimationName !== undefined ||
      style.MozAnimationName !== undefined ||
      style.msAnimationName !== undefined ||
      style.OAnimationName !== undefined;
  })();

  /**
   * Is iOS?
   * @private
   * @const
   * @type {Boolean}
   */
  var IS_IOS = /iPad|iPhone|iPod/.test(navigator.platform);

  /**
   * Current modal
   * @private
   * @type {Remodal}
   */
  var current;

  /**
   * Scrollbar position
   * @private
   * @type {Number}
   */
  var scrollTop;

  /**
   * Returns an animation duration
   * @private
   * @param {jQuery} $elem
   * @returns {Number}
   */
  function getAnimationDuration($elem) {
    if (
      IS_ANIMATION &&
      $elem.css('animation-name') === 'none' &&
      $elem.css('-webkit-animation-name') === 'none' &&
      $elem.css('-moz-animation-name') === 'none' &&
      $elem.css('-o-animation-name') === 'none' &&
      $elem.css('-ms-animation-name') === 'none'
    ) {
      return 0;
    }

    var duration = $elem.css('animation-duration') ||
      $elem.css('-webkit-animation-duration') ||
      $elem.css('-moz-animation-duration') ||
      $elem.css('-o-animation-duration') ||
      $elem.css('-ms-animation-duration') ||
      '0s';

    var delay = $elem.css('animation-delay') ||
      $elem.css('-webkit-animation-delay') ||
      $elem.css('-moz-animation-delay') ||
      $elem.css('-o-animation-delay') ||
      $elem.css('-ms-animation-delay') ||
      '0s';

    var iterationCount = $elem.css('animation-iteration-count') ||
      $elem.css('-webkit-animation-iteration-count') ||
      $elem.css('-moz-animation-iteration-count') ||
      $elem.css('-o-animation-iteration-count') ||
      $elem.css('-ms-animation-iteration-count') ||
      '1';

    var max;
    var len;
    var num;
    var i;

    duration = duration.split(', ');
    delay = delay.split(', ');
    iterationCount = iterationCount.split(', ');

    // The 'duration' size is the same as the 'delay' size
    for (i = 0, len = duration.length, max = Number.NEGATIVE_INFINITY; i < len; i++) {
      num = parseFloat(duration[i]) * parseInt(iterationCount[i], 10) + parseFloat(delay[i]);

      if (num > max) {
        max = num;
      }
    }

    return max;
  }

  /**
   * Returns a scrollbar width
   * @private
   * @returns {Number}
   */
  function getScrollbarWidth() {
    if ($(document.body).height() <= $(window).height()) {
      return 0;
    }

    var outer = document.createElement('div');
    var inner = document.createElement('div');
    var widthNoScroll;
    var widthWithScroll;

    outer.style.visibility = 'hidden';
    outer.style.width = '100px';
    document.body.appendChild(outer);

    widthNoScroll = outer.offsetWidth;

    // Force scrollbars
    outer.style.overflow = 'scroll';

    // Add inner div
    inner.style.width = '100%';
    outer.appendChild(inner);

    widthWithScroll = inner.offsetWidth;

    // Remove divs
    outer.parentNode.removeChild(outer);

    return widthNoScroll - widthWithScroll;
  }

  /**
   * Locks the screen
   * @private
   */
  function lockScreen() {
    if (IS_IOS) {
      return;
    }

    var $html = $('html');
    var lockedClass = namespacify('is-locked');
    var paddingRight;
    var $body;

    if (!$html.hasClass(lockedClass)) {
      $body = $(document.body);

      // Zepto does not support '-=', '+=' in the `css` method
      paddingRight = parseInt($body.css('padding-right'), 10) + getScrollbarWidth();

      $body.css('padding-right', paddingRight + 'px');
      $html.addClass(lockedClass);
    }
  }

  /**
   * Unlocks the screen
   * @private
   */
  function unlockScreen() {
    if (IS_IOS) {
      return;
    }

    var $html = $('html');
    var lockedClass = namespacify('is-locked');
    var paddingRight;
    var $body;

    if ($html.hasClass(lockedClass)) {
      $body = $(document.body);

      // Zepto does not support '-=', '+=' in the `css` method
      paddingRight = parseInt($body.css('padding-right'), 10) - getScrollbarWidth();

      $body.css('padding-right', paddingRight + 'px');
      $html.removeClass(lockedClass);
    }
  }

  /**
   * Sets a state for an instance
   * @private
   * @param {Remodal} instance
   * @param {STATES} state
   * @param {Boolean} isSilent If true, Remodal does not trigger events
   * @param {String} Reason of a state change.
   */
  function setState(instance, state, isSilent, reason) {

    var newState = namespacify('is', state);
    var allStates = [namespacify('is', STATES.CLOSING),
                     namespacify('is', STATES.OPENING),
                     namespacify('is', STATES.CLOSED),
                     namespacify('is', STATES.OPENED)].join(' ');

    instance.$bg
      .removeClass(allStates)
      .addClass(newState);

    instance.$overlay
      .removeClass(allStates)
      .addClass(newState);

    instance.$wrapper
      .removeClass(allStates)
      .addClass(newState);

    instance.$modal
      .removeClass(allStates)
      .addClass(newState);

    instance.state = state;
    !isSilent && instance.$modal.trigger({
      type: state,
      reason: reason
    }, [{ reason: reason }]);
  }

  /**
   * Synchronizes with the animation
   * @param {Function} doBeforeAnimation
   * @param {Function} doAfterAnimation
   * @param {Remodal} instance
   */
  function syncWithAnimation(doBeforeAnimation, doAfterAnimation, instance) {
    var runningAnimationsCount = 0;

    var handleAnimationStart = function(e) {
      if (e.target !== this) {
        return;
      }

      runningAnimationsCount++;
    };

    var handleAnimationEnd = function(e) {
      if (e.target !== this) {
        return;
      }

      if (--runningAnimationsCount === 0) {

        // Remove event listeners
        $.each(['$bg', '$overlay', '$wrapper', '$modal'], function(index, elemName) {
          instance[elemName].off(ANIMATIONSTART_EVENTS + ' ' + ANIMATIONEND_EVENTS);
        });

        doAfterAnimation();
      }
    };

    $.each(['$bg', '$overlay', '$wrapper', '$modal'], function(index, elemName) {
      instance[elemName]
        .on(ANIMATIONSTART_EVENTS, handleAnimationStart)
        .on(ANIMATIONEND_EVENTS, handleAnimationEnd);
    });

    doBeforeAnimation();

    // If the animation is not supported by a browser or its duration is 0
    if (
      getAnimationDuration(instance.$bg) === 0 &&
      getAnimationDuration(instance.$overlay) === 0 &&
      getAnimationDuration(instance.$wrapper) === 0 &&
      getAnimationDuration(instance.$modal) === 0
    ) {

      // Remove event listeners
      $.each(['$bg', '$overlay', '$wrapper', '$modal'], function(index, elemName) {
        instance[elemName].off(ANIMATIONSTART_EVENTS + ' ' + ANIMATIONEND_EVENTS);
      });

      doAfterAnimation();
    }
  }

  /**
   * Closes immediately
   * @private
   * @param {Remodal} instance
   */
  function halt(instance) {
    if (instance.state === STATES.CLOSED) {
      return;
    }

    $.each(['$bg', '$overlay', '$wrapper', '$modal'], function(index, elemName) {
      instance[elemName].off(ANIMATIONSTART_EVENTS + ' ' + ANIMATIONEND_EVENTS);
    });

    instance.$bg.removeClass(instance.settings.modifier);
    instance.$overlay.removeClass(instance.settings.modifier).hide();
    instance.$wrapper.hide();
    unlockScreen();
    setState(instance, STATES.CLOSED, true);
  }

  /**
   * Parses a string with options
   * @private
   * @param str
   * @returns {Object}
   */
  function parseOptions(str) {
    var obj = {};
    var arr;
    var len;
    var val;
    var i;

    // Remove spaces before and after delimiters
    str = str.replace(/\s*:\s*/g, ':').replace(/\s*,\s*/g, ',');

    // Parse a string
    arr = str.split(',');
    for (i = 0, len = arr.length; i < len; i++) {
      arr[i] = arr[i].split(':');
      val = arr[i][1];

      // Convert a string value if it is like a boolean
      if (typeof val === 'string' || val instanceof String) {
        val = val === 'true' || (val === 'false' ? false : val);
      }

      // Convert a string value if it is like a number
      if (typeof val === 'string' || val instanceof String) {
        val = !isNaN(val) ? +val : val;
      }

      obj[arr[i][0]] = val;
    }

    return obj;
  }

  /**
   * Generates a string separated by dashes and prefixed with NAMESPACE
   * @private
   * @param {...String}
   * @returns {String}
   */
  function namespacify() {
    var result = NAMESPACE;

    for (var i = 0; i < arguments.length; ++i) {
      result += '-' + arguments[i];
    }

    return result;
  }

  /**
   * Handles the hashchange event
   * @private
   * @listens hashchange
   */
  function handleHashChangeEvent() {
    var id = location.hash.replace('#', '');
    var instance;
    var $elem;

    if (!id) {

      // Check if we have currently opened modal and animation was completed
      if (current && current.state === STATES.OPENED && current.settings.hashTracking) {
        current.close();
      }
    } else {

      // Catch syntax error if your hash is bad
      try {
        $elem = $(
          '[data-' + PLUGIN_NAME + '-id="' + id + '"]'
        );
      } catch (err) {}

      if ($elem && $elem.length) {
        instance = $[PLUGIN_NAME].lookup[$elem.data(PLUGIN_NAME)];

        if (instance && instance.settings.hashTracking) {
          instance.open();
        }
      }

    }
  }

  /**
   * Remodal constructor
   * @constructor
   * @param {jQuery} $modal
   * @param {Object} options
   */
  function Remodal($modal, options) {
    var $body = $(document.body);
    var $appendTo = $body;
    var remodal = this;

    remodal.settings = $.extend({}, DEFAULTS, options);
    remodal.index = $[PLUGIN_NAME].lookup.push(remodal) - 1;
    remodal.state = STATES.CLOSED;

    remodal.$overlay = $('.' + namespacify('overlay'));

    if (remodal.settings.appendTo !== null && remodal.settings.appendTo.length) {
      $appendTo = $(remodal.settings.appendTo);
    }

    if (!remodal.$overlay.length) {
      remodal.$overlay = $('<div>').addClass(namespacify('overlay') + ' ' + namespacify('is', STATES.CLOSED)).hide();
      $appendTo.append(remodal.$overlay);
    }

    remodal.$bg = $('.' + namespacify('bg')).addClass(namespacify('is', STATES.CLOSED));

    remodal.$modal = $modal
      .addClass(
        NAMESPACE + ' ' +
        namespacify('is-initialized') + ' ' +
        remodal.settings.modifier + ' ' +
        namespacify('is', STATES.CLOSED))
      .attr('tabindex', '-1');

    remodal.$wrapper = $('<div>')
      .addClass(
        namespacify('wrapper') + ' ' +
        remodal.settings.modifier + ' ' +
        namespacify('is', STATES.CLOSED))
      .hide()
      .append(remodal.$modal);
    $appendTo.append(remodal.$wrapper);

    // Add the event listener for the close button
    remodal.$wrapper.on('click.' + NAMESPACE, '[data-' + PLUGIN_NAME + '-action="close"]', function(e) {
      e.preventDefault();

      remodal.close();
    });

    // Add the event listener for the cancel button
    remodal.$wrapper.on('click.' + NAMESPACE, '[data-' + PLUGIN_NAME + '-action="cancel"]', function(e) {
      e.preventDefault();

      remodal.$modal.trigger(STATE_CHANGE_REASONS.CANCELLATION);

      if (remodal.settings.closeOnCancel) {
        remodal.close(STATE_CHANGE_REASONS.CANCELLATION);
      }
    });

    // Add the event listener for the confirm button
    remodal.$wrapper.on('click.' + NAMESPACE, '[data-' + PLUGIN_NAME + '-action="confirm"]', function(e) {
      e.preventDefault();

      remodal.$modal.trigger(STATE_CHANGE_REASONS.CONFIRMATION);

      if (remodal.settings.closeOnConfirm) {
        remodal.close(STATE_CHANGE_REASONS.CONFIRMATION);
      }
    });

    // Add the event listener for the overlay
    remodal.$wrapper.on('click.' + NAMESPACE, function(e) {
      var $target = $(e.target);

      if (!$target.hasClass(namespacify('wrapper'))) {
        return;
      }

      if (remodal.settings.closeOnOutsideClick) {
        remodal.close();
      }
    });
  }

  /**
   * Opens a modal window
   * @public
   */
  Remodal.prototype.open = function() {
    var remodal = this;
    var id;

    // Check if the animation was completed
    if (remodal.state === STATES.OPENING || remodal.state === STATES.CLOSING) {
      return;
    }

    id = remodal.$modal.attr('data-' + PLUGIN_NAME + '-id');

    if (id && remodal.settings.hashTracking) {
      scrollTop = $(window).scrollTop();
      location.hash = id;
    }

    if (current && current !== remodal) {
      halt(current);
    }

    current = remodal;
    lockScreen();
    remodal.$bg.addClass(remodal.settings.modifier);
    remodal.$overlay.addClass(remodal.settings.modifier).show();
    remodal.$wrapper.show().scrollTop(0);
    remodal.$modal.focus();

    syncWithAnimation(
      function() {
        setState(remodal, STATES.OPENING);
      },

      function() {
        setState(remodal, STATES.OPENED);
      },

      remodal);
  };

  /**
   * Closes a modal window
   * @public
   * @param {String} reason
   */
  Remodal.prototype.close = function(reason) {
    var remodal = this;

    // Check if the animation was completed
    if (remodal.state === STATES.OPENING || remodal.state === STATES.CLOSING) {
      return;
    }

    if (
      remodal.settings.hashTracking &&
      remodal.$modal.attr('data-' + PLUGIN_NAME + '-id') === location.hash.substr(1)
    ) {
      location.hash = '';
      $(window).scrollTop(scrollTop);
    }

    syncWithAnimation(
      function() {
        setState(remodal, STATES.CLOSING, false, reason);
      },

      function() {
        remodal.$bg.removeClass(remodal.settings.modifier);
        remodal.$overlay.removeClass(remodal.settings.modifier).hide();
        remodal.$wrapper.hide();
        unlockScreen();

        setState(remodal, STATES.CLOSED, false, reason);
      },

      remodal);
  };

  /**
   * Returns a current state of a modal
   * @public
   * @returns {STATES}
   */
  Remodal.prototype.getState = function() {
    return this.state;
  };

  /**
   * Destroys a modal
   * @public
   */
  Remodal.prototype.destroy = function() {
    var lookup = $[PLUGIN_NAME].lookup;
    var instanceCount;

    halt(this);
    this.$wrapper.remove();

    delete lookup[this.index];
    instanceCount = $.grep(lookup, function(instance) {
      return !!instance;
    }).length;

    if (instanceCount === 0) {
      this.$overlay.remove();
      this.$bg.removeClass(
        namespacify('is', STATES.CLOSING) + ' ' +
        namespacify('is', STATES.OPENING) + ' ' +
        namespacify('is', STATES.CLOSED) + ' ' +
        namespacify('is', STATES.OPENED));
    }
  };

  /**
   * Special plugin object for instances
   * @public
   * @type {Object}
   */
  $[PLUGIN_NAME] = {
    lookup: []
  };

  /**
   * Plugin constructor
   * @constructor
   * @param {Object} options
   * @returns {JQuery}
   */
  $.fn[PLUGIN_NAME] = function(opts) {
    var instance;
    var $elem;

    this.each(function(index, elem) {
      $elem = $(elem);

      if ($elem.data(PLUGIN_NAME) == null) {
        instance = new Remodal($elem, opts);
        $elem.data(PLUGIN_NAME, instance.index);

        if (
          instance.settings.hashTracking &&
          $elem.attr('data-' + PLUGIN_NAME + '-id') === location.hash.substr(1)
        ) {
          instance.open();
        }
      } else {
        instance = $[PLUGIN_NAME].lookup[$elem.data(PLUGIN_NAME)];
      }
    });

    return instance;
  };

  $(document).ready(function() {

    // data-remodal-target opens a modal window with the special Id
    $(document).on('click', '[data-' + PLUGIN_NAME + '-target]', function(e) {
      e.preventDefault();

      var elem = e.currentTarget;
      var id = elem.getAttribute('data-' + PLUGIN_NAME + '-target');
      var $target = $('[data-' + PLUGIN_NAME + '-id="' + id + '"]');

      $[PLUGIN_NAME].lookup[$target.data(PLUGIN_NAME)].open();
    });

    // Auto initialization of modal windows
    // They should have the 'remodal' class attribute
    // Also you can write the `data-remodal-options` attribute to pass params into the modal
    $(document).find('.' + NAMESPACE).each(function(i, container) {
      var $container = $(container);
      var options = $container.data(PLUGIN_NAME + '-options');

      if (!options) {
        options = {};
      } else if (typeof options === 'string' || options instanceof String) {
        options = parseOptions(options);
      }

      $container[PLUGIN_NAME](options);
    });

    // Handles the keydown event
    $(document).on('keydown.' + NAMESPACE, function(e) {
      if (current && current.settings.closeOnEscape && current.state === STATES.OPENED && e.keyCode === 27) {
        current.close();
      }
    });

    // Handles the hashchange event
    $(window).on('hashchange.' + NAMESPACE, handleHashChangeEvent);
  });
});

/**
 * @preserve jQuery DateTimePicker plugin v2.4.5
 * @homepage http://xdsoft.net/jqplugins/datetimepicker/
 * (c) 2014, Chupurnov Valeriy.
 */
/*global document,window,jQuery,setTimeout,clearTimeout,HighlightedDate,getCurrentValue*/
(function ($) {
	'use strict';
	var default_options  = {
		i18n: {
			ar: { // Arabic
				months: [
					"كانون الثاني", "شباط", "آذار", "نيسان", "مايو", "حزيران", "تموز", "آب", "أيلول", "تشرين الأول", "تشرين الثاني", "كانون الأول"
				],
				dayOfWeek: [
					"ن", "ث", "ع", "خ", "ج", "س", "ح"
				]
			},
			ro: { // Romanian
				months: [
					"ianuarie", "februarie", "martie", "aprilie", "mai", "iunie", "iulie", "august", "septembrie", "octombrie", "noiembrie", "decembrie"
				],
				dayOfWeek: [
					"l", "ma", "mi", "j", "v", "s", "d"
				]
			},
			id: { // Indonesian
				months: [
					"Januari", "Februari", "Maret", "April", "Mei", "Juni", "Juli", "Agustus", "September", "Oktober", "November", "Desember"
				],
				dayOfWeek: [
					"Min", "Sen", "Sel", "Rab", "Kam", "Jum", "Sab"
				]
			},
			is: { // Icelandic
				months: [
					"Janúar", "Febrúar", "Mars", "Apríl", "Maí", "Júní", "Júlí", "Ágúst", "September", "Október", "Nóvember", "Desember"
				],
				dayOfWeek: [
					"Sun", "Mán", "Þrið", "Mið", "Fim", "Fös", "Lau"
				]
			},
			bg: { // Bulgarian
				months: [
					"Януари", "Февруари", "Март", "Април", "Май", "Юни", "Юли", "Август", "Септември", "Октомври", "Ноември", "Декември"
				],
				dayOfWeek: [
					"Нд", "Пн", "Вт", "Ср", "Чт", "Пт", "Сб"
				]
			},
			fa: { // Persian/Farsi
				months: [
					'فروردین', 'اردیبهشت', 'خرداد', 'تیر', 'مرداد', 'شهریور', 'مهر', 'آبان', 'آذر', 'دی', 'بهمن', 'اسفند'
				],
				dayOfWeek: [
					'یکشنبه', 'دوشنبه', 'سه شنبه', 'چهارشنبه', 'پنجشنبه', 'جمعه', 'شنبه'
				]
			},
			ru: { // Russian
				months: [
					'Январь', 'Февраль', 'Март', 'Апрель', 'Май', 'Июнь', 'Июль', 'Август', 'Сентябрь', 'Октябрь', 'Ноябрь', 'Декабрь'
				],
				dayOfWeek: [
					"Вск", "Пн", "Вт", "Ср", "Чт", "Пт", "Сб"
				]
			},
			uk: { // Ukrainian
				months: [
					'Січень', 'Лютий', 'Березень', 'Квітень', 'Травень', 'Червень', 'Липень', 'Серпень', 'Вересень', 'Жовтень', 'Листопад', 'Грудень'
				],
				dayOfWeek: [
					"Ндл", "Пнд", "Втр", "Срд", "Чтв", "Птн", "Сбт"
				]
			},
			en: { // English
				months: [
					"January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"
				],
				dayOfWeek: [
					"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
				]
			},
			el: { // Ελληνικά
				months: [
					"Ιανουάριος", "Φεβρουάριος", "Μάρτιος", "Απρίλιος", "Μάιος", "Ιούνιος", "Ιούλιος", "Αύγουστος", "Σεπτέμβριος", "Οκτώβριος", "Νοέμβριος", "Δεκέμβριος"
				],
				dayOfWeek: [
					"Κυρ", "Δευ", "Τρι", "Τετ", "Πεμ", "Παρ", "Σαβ"
				]
			},
			de: { // German
				months: [
					'Januar', 'Februar', 'März', 'April', 'Mai', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember'
				],
				dayOfWeek: [
					"So", "Mo", "Di", "Mi", "Do", "Fr", "Sa"
				]
			},
			nl: { // Dutch
				months: [
					"januari", "februari", "maart", "april", "mei", "juni", "juli", "augustus", "september", "oktober", "november", "december"
				],
				dayOfWeek: [
					"zo", "ma", "di", "wo", "do", "vr", "za"
				]
			},
			tr: { // Turkish
				months: [
					"Ocak", "Şubat", "Mart", "Nisan", "Mayıs", "Haziran", "Temmuz", "Ağustos", "Eylül", "Ekim", "Kasım", "Aralık"
				],
				dayOfWeek: [
					"Paz", "Pts", "Sal", "Çar", "Per", "Cum", "Cts"
				]
			},
			fr: { //French
				months: [
					"Janvier", "Février", "Mars", "Avril", "Mai", "Juin", "Juillet", "Août", "Septembre", "Octobre", "Novembre", "Décembre"
				],
				dayOfWeek: [
					"Dim", "Lun", "Mar", "Mer", "Jeu", "Ven", "Sam"
				]
			},
			es: { // Spanish
				months: [
					"Enero", "Febrero", "Marzo", "Abril", "Mayo", "Junio", "Julio", "Agosto", "Septiembre", "Octubre", "Noviembre", "Diciembre"
				],
				dayOfWeek: [
					"Dom", "Lun", "Mar", "Mié", "Jue", "Vie", "Sáb"
				]
			},
			th: { // Thai
				months: [
					'มกราคม', 'กุมภาพันธ์', 'มีนาคม', 'เมษายน', 'พฤษภาคม', 'มิถุนายน', 'กรกฎาคม', 'สิงหาคม', 'กันยายน', 'ตุลาคม', 'พฤศจิกายน', 'ธันวาคม'
				],
				dayOfWeek: [
					'อา.', 'จ.', 'อ.', 'พ.', 'พฤ.', 'ศ.', 'ส.'
				]
			},
			pl: { // Polish
				months: [
					"styczeń", "luty", "marzec", "kwiecień", "maj", "czerwiec", "lipiec", "sierpień", "wrzesień", "październik", "listopad", "grudzień"
				],
				dayOfWeek: [
					"nd", "pn", "wt", "śr", "cz", "pt", "sb"
				]
			},
			pt: { // Portuguese
				months: [
					"Janeiro", "Fevereiro", "Março", "Abril", "Maio", "Junho", "Julho", "Agosto", "Setembro", "Outubro", "Novembro", "Dezembro"
				],
				dayOfWeek: [
					"Dom", "Seg", "Ter", "Qua", "Qui", "Sex", "Sab"
				]
			},
			ch: { // Simplified Chinese
				months: [
					"一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月"
				],
				dayOfWeek: [
					"日", "一", "二", "三", "四", "五", "六"
				]
			},
			se: { // Swedish
				months: [
					"Januari", "Februari", "Mars", "April", "Maj", "Juni", "Juli", "Augusti", "September",  "Oktober", "November", "December"
				],
				dayOfWeek: [
					"Sön", "Mån", "Tis", "Ons", "Tor", "Fre", "Lör"
				]
			},
			kr: { // Korean
				months: [
					"1월", "2월", "3월", "4월", "5월", "6월", "7월", "8월", "9월", "10월", "11월", "12월"
				],
				dayOfWeek: [
					"일", "월", "화", "수", "목", "금", "토"
				]
			},
			it: { // Italian
				months: [
					"Gennaio", "Febbraio", "Marzo", "Aprile", "Maggio", "Giugno", "Luglio", "Agosto", "Settembre", "Ottobre", "Novembre", "Dicembre"
				],
				dayOfWeek: [
					"Dom", "Lun", "Mar", "Mer", "Gio", "Ven", "Sab"
				]
			},
			da: { // Dansk
				months: [
					"January", "Februar", "Marts", "April", "Maj", "Juni", "July", "August", "September", "Oktober", "November", "December"
				],
				dayOfWeek: [
					"Søn", "Man", "Tir", "Ons", "Tor", "Fre", "Lør"
				]
			},
			no: { // Norwegian
				months: [
					"Januar", "Februar", "Mars", "April", "Mai", "Juni", "Juli", "August", "September", "Oktober", "November", "Desember"
				],
				dayOfWeek: [
					"Søn", "Man", "Tir", "Ons", "Tor", "Fre", "Lør"
				]
			},
			ja: { // Japanese
				months: [
					"1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月"
				],
				dayOfWeek: [
					"日", "月", "火", "水", "木", "金", "土"
				]
			},
			vi: { // Vietnamese
				months: [
					"Tháng 1", "Tháng 2", "Tháng 3", "Tháng 4", "Tháng 5", "Tháng 6", "Tháng 7", "Tháng 8", "Tháng 9", "Tháng 10", "Tháng 11", "Tháng 12"
				],
				dayOfWeek: [
					"CN", "T2", "T3", "T4", "T5", "T6", "T7"
				]
			},
			sl: { // Slovenščina
				months: [
					"Januar", "Februar", "Marec", "April", "Maj", "Junij", "Julij", "Avgust", "September", "Oktober", "November", "December"
				],
				dayOfWeek: [
					"Ned", "Pon", "Tor", "Sre", "Čet", "Pet", "Sob"
				]
			},
			cs: { // Čeština
				months: [
					"Leden", "Únor", "Březen", "Duben", "Květen", "Červen", "Červenec", "Srpen", "Září", "Říjen", "Listopad", "Prosinec"
				],
				dayOfWeek: [
					"Ne", "Po", "Út", "St", "Čt", "Pá", "So"
				]
			},
			hu: { // Hungarian
				months: [
					"Január", "Február", "Március", "Április", "Május", "Június", "Július", "Augusztus", "Szeptember", "Október", "November", "December"
				],
				dayOfWeek: [
					"Va", "Hé", "Ke", "Sze", "Cs", "Pé", "Szo"
				]
			},
			az: { //Azerbaijanian (Azeri)
				months: [
					"Yanvar", "Fevral", "Mart", "Aprel", "May", "Iyun", "Iyul", "Avqust", "Sentyabr", "Oktyabr", "Noyabr", "Dekabr"
				],
				dayOfWeek: [
					"B", "Be", "Ça", "Ç", "Ca", "C", "Ş"
				]
			},
			bs: { //Bosanski
				months: [
					"Januar", "Februar", "Mart", "April", "Maj", "Jun", "Jul", "Avgust", "Septembar", "Oktobar", "Novembar", "Decembar"
				],
				dayOfWeek: [
					"Ned", "Pon", "Uto", "Sri", "Čet", "Pet", "Sub"
				]
			},
			ca: { //Català
				months: [
					"Gener", "Febrer", "Març", "Abril", "Maig", "Juny", "Juliol", "Agost", "Setembre", "Octubre", "Novembre", "Desembre"
				],
				dayOfWeek: [
					"Dg", "Dl", "Dt", "Dc", "Dj", "Dv", "Ds"
				]
			},
			'en-GB': { //English (British)
				months: [
					"January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"
				],
				dayOfWeek: [
					"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
				]
			},
			et: { //"Eesti"
				months: [
					"Jaanuar", "Veebruar", "Märts", "Aprill", "Mai", "Juuni", "Juuli", "August", "September", "Oktoober", "November", "Detsember"
				],
				dayOfWeek: [
					"P", "E", "T", "K", "N", "R", "L"
				]
			},
			eu: { //Euskara
				months: [
					"Urtarrila", "Otsaila", "Martxoa", "Apirila", "Maiatza", "Ekaina", "Uztaila", "Abuztua", "Iraila", "Urria", "Azaroa", "Abendua"
				],
				dayOfWeek: [
					"Ig.", "Al.", "Ar.", "Az.", "Og.", "Or.", "La."
				]
			},
			fi: { //Finnish (Suomi)
				months: [
					"Tammikuu", "Helmikuu", "Maaliskuu", "Huhtikuu", "Toukokuu", "Kesäkuu", "Heinäkuu", "Elokuu", "Syyskuu", "Lokakuu", "Marraskuu", "Joulukuu"
				],
				dayOfWeek: [
					"Su", "Ma", "Ti", "Ke", "To", "Pe", "La"
				]
			},
			gl: { //Galego
				months: [
					"Xan", "Feb", "Maz", "Abr", "Mai", "Xun", "Xul", "Ago", "Set", "Out", "Nov", "Dec"
				],
				dayOfWeek: [
					"Dom", "Lun", "Mar", "Mer", "Xov", "Ven", "Sab"
				]
			},
			hr: { //Hrvatski
				months: [
					"Siječanj", "Veljača", "Ožujak", "Travanj", "Svibanj", "Lipanj", "Srpanj", "Kolovoz", "Rujan", "Listopad", "Studeni", "Prosinac"
				],
				dayOfWeek: [
					"Ned", "Pon", "Uto", "Sri", "Čet", "Pet", "Sub"
				]
			},
			ko: { //Korean (한국어)
				months: [
					"1월", "2월", "3월", "4월", "5월", "6월", "7월", "8월", "9월", "10월", "11월", "12월"
				],
				dayOfWeek: [
					"일", "월", "화", "수", "목", "금", "토"
				]
			},
			lt: { //Lithuanian (lietuvių)
				months: [
					"Sausio", "Vasario", "Kovo", "Balandžio", "Gegužės", "Birželio", "Liepos", "Rugpjūčio", "Rugsėjo", "Spalio", "Lapkričio", "Gruodžio"
				],
				dayOfWeek: [
					"Sek", "Pir", "Ant", "Tre", "Ket", "Pen", "Šeš"
				]
			},
			lv: { //Latvian (Latviešu)
				months: [
					"Janvāris", "Februāris", "Marts", "Aprīlis ", "Maijs", "Jūnijs", "Jūlijs", "Augusts", "Septembris", "Oktobris", "Novembris", "Decembris"
				],
				dayOfWeek: [
					"Sv", "Pr", "Ot", "Tr", "Ct", "Pk", "St"
				]
			},
			mk: { //Macedonian (Македонски)
				months: [
					"јануари", "февруари", "март", "април", "мај", "јуни", "јули", "август", "септември", "октомври", "ноември", "декември"
				],
				dayOfWeek: [
					"нед", "пон", "вто", "сре", "чет", "пет", "саб"
				]
			},
			mn: { //Mongolian (Монгол)
				months: [
					"1-р сар", "2-р сар", "3-р сар", "4-р сар", "5-р сар", "6-р сар", "7-р сар", "8-р сар", "9-р сар", "10-р сар", "11-р сар", "12-р сар"
				],
				dayOfWeek: [
					"Дав", "Мяг", "Лха", "Пүр", "Бсн", "Бям", "Ням"
				]
			},
			'pt-BR': { //Português(Brasil)
				months: [
					"Janeiro", "Fevereiro", "Março", "Abril", "Maio", "Junho", "Julho", "Agosto", "Setembro", "Outubro", "Novembro", "Dezembro"
				],
				dayOfWeek: [
					"Dom", "Seg", "Ter", "Qua", "Qui", "Sex", "Sáb"
				]
			},
			sk: { //Slovenčina
				months: [
					"Január", "Február", "Marec", "Apríl", "Máj", "Jún", "Júl", "August", "September", "Október", "November", "December"
				],
				dayOfWeek: [
					"Ne", "Po", "Ut", "St", "Št", "Pi", "So"
				]
			},
			sq: { //Albanian (Shqip)
				months: [
					"January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"
				],
				dayOfWeek: [
					"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
				]
			},
			'sr-YU': { //Serbian (Srpski)
				months: [
					"Januar", "Februar", "Mart", "April", "Maj", "Jun", "Jul", "Avgust", "Septembar", "Oktobar", "Novembar", "Decembar"
				],
				dayOfWeek: [
					"Ned", "Pon", "Uto", "Sre", "čet", "Pet", "Sub"
				]
			},
			sr: { //Serbian Cyrillic (Српски)
				months: [
					"јануар", "фебруар", "март", "април", "мај", "јун", "јул", "август", "септембар", "октобар", "новембар", "децембар"
				],
				dayOfWeek: [
					"нед", "пон", "уто", "сре", "чет", "пет", "суб"
				]
			},
			sv: { //Svenska
				months: [
					"Januari", "Februari", "Mars", "April", "Maj", "Juni", "Juli", "Augusti", "September", "Oktober", "November", "December"
				],
				dayOfWeek: [
					"Sön", "Mån", "Tis", "Ons", "Tor", "Fre", "Lör"
				]
			},
			'zh-TW': { //Traditional Chinese (繁體中文)
				months: [
					"一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月"
				],
				dayOfWeek: [
					"日", "一", "二", "三", "四", "五", "六"
				]
			},
			zh: { //Simplified Chinese (简体中文)
				months: [
					"一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月"
				],
				dayOfWeek: [
					"日", "一", "二", "三", "四", "五", "六"
				]
			},
			he: { //Hebrew (עברית)
				months: [
					'ינואר', 'פברואר', 'מרץ', 'אפריל', 'מאי', 'יוני', 'יולי', 'אוגוסט', 'ספטמבר', 'אוקטובר', 'נובמבר', 'דצמבר'
				],
				dayOfWeek: [
					'א\'', 'ב\'', 'ג\'', 'ד\'', 'ה\'', 'ו\'', 'שבת'
				]
			},
			hy: { // Armenian
				months: [
					"Հունվար", "Փետրվար", "Մարտ", "Ապրիլ", "Մայիս", "Հունիս", "Հուլիս", "Օգոստոս", "Սեպտեմբեր", "Հոկտեմբեր", "Նոյեմբեր", "Դեկտեմբեր"
				],
				dayOfWeek: [
					"Կի", "Երկ", "Երք", "Չոր", "Հնգ", "Ուրբ", "Շբթ"
				]
			},
            kg: { // Kyrgyz
                months: [
                    'Үчтүн айы', 'Бирдин айы', 'Жалган Куран', 'Чын Куран', 'Бугу', 'Кулжа', 'Теке', 'Баш Оона', 'Аяк Оона', 'Тогуздун айы', 'Жетинин айы', 'Бештин айы'
                ],
                dayOfWeek: [
                    "Жек", "Дүй", "Шей", "Шар", "Бей", "Жум", "Ише"
                ]
            }
		},
		value: '',
		lang: 'en',

		format:	'Y/m/d H:i',
		formatTime:	'H:i',
		formatDate:	'Y/m/d',

		startDate:	false, // new Date(), '1986/12/08', '-1970/01/05','-1970/01/05',
		step: 60,
		monthChangeSpinner: true,

		closeOnDateSelect: false,
		closeOnTimeSelect: true,
		closeOnWithoutClick: true,
		closeOnInputClick: true,

		timepicker: true,
		datepicker: true,
		weeks: false,

		defaultTime: false,	// use formatTime format (ex. '10:00' for formatTime:	'H:i')
		defaultDate: false,	// use formatDate format (ex new Date() or '1986/12/08' or '-1970/01/05' or '-1970/01/05')

		minDate: false,
		maxDate: false,
		minTime: false,
		maxTime: false,
		disabledMinTime: false,
		disabledMaxTime: false,

		allowTimes: [],
		opened: false,
		initTime: true,
		inline: false,
		theme: '',

		onSelectDate: function () {},
		onSelectTime: function () {},
		onChangeMonth: function () {},
		onChangeYear: function () {},
		onChangeDateTime: function () {},
		onShow: function () {},
		onClose: function () {},
		onGenerate: function () {},

		withoutCopyright: true,
		inverseButton: false,
		hours12: false,
		next: 'xdsoft_next',
		prev : 'xdsoft_prev',
		dayOfWeekStart: 0,
		parentID: 'body',
		timeHeightInTimePicker: 25,
		timepickerScrollbar: true,
		todayButton: true,
		prevButton: true,
		nextButton: true,
		defaultSelect: true,

		scrollMonth: true,
		scrollTime: true,
		scrollInput: true,

		lazyInit: false,
		mask: false,
		validateOnBlur: true,
		allowBlank: true,
		yearStart: 1950,
		yearEnd: 2050,
		monthStart: 0,
		monthEnd: 11,
		style: '',
		id: '',
		fixed: false,
		roundTime: 'round', // ceil, floor
		className: '',
		weekends: [],
		highlightedDates: [],
		highlightedPeriods: [],
		disabledDates : [],
		disabledWeekDays: [],
		yearOffset: 0,
		beforeShowDay: null,

		enterLikeTab: true,
        showApplyButton: false
	};
	// fix for ie8
	if (!window.getComputedStyle) {
		window.getComputedStyle = function (el, pseudo) {
			this.el = el;
			this.getPropertyValue = function (prop) {
				var re = /(\-([a-z]){1})/g;
				if (prop === 'float') {
					prop = 'styleFloat';
				}
				if (re.test(prop)) {
					prop = prop.replace(re, function (a, b, c) {
						return c.toUpperCase();
					});
				}
				return el.currentStyle[prop] || null;
			};
			return this;
		};
	}
	if (!Array.prototype.indexOf) {
		Array.prototype.indexOf = function (obj, start) {
			var i, j;
			for (i = (start || 0), j = this.length; i < j; i += 1) {
				if (this[i] === obj) { return i; }
			}
			return -1;
		};
	}
	Date.prototype.countDaysInMonth = function () {
		return new Date(this.getFullYear(), this.getMonth() + 1, 0).getDate();
	};
	$.fn.xdsoftScroller = function (percent) {
		return this.each(function () {
			var timeboxparent = $(this),
				pointerEventToXY = function (e) {
					var out = {x: 0, y: 0},
						touch;
					if (e.type === 'touchstart' || e.type === 'touchmove' || e.type === 'touchend' || e.type === 'touchcancel') {
						touch  = e.originalEvent.touches[0] || e.originalEvent.changedTouches[0];
						out.x = touch.clientX;
						out.y = touch.clientY;
					} else if (e.type === 'mousedown' || e.type === 'mouseup' || e.type === 'mousemove' || e.type === 'mouseover' || e.type === 'mouseout' || e.type === 'mouseenter' || e.type === 'mouseleave') {
						out.x = e.clientX;
						out.y = e.clientY;
					}
					return out;
				},
				move = 0,
				timebox,
				parentHeight,
				height,
				scrollbar,
				scroller,
				maximumOffset = 100,
				start = false,
				startY = 0,
				startTop = 0,
				h1 = 0,
				touchStart = false,
				startTopScroll = 0,
				calcOffset = function () {};
			if (percent === 'hide') {
				timeboxparent.find('.xdsoft_scrollbar').hide();
				return;
			}
			if (!$(this).hasClass('xdsoft_scroller_box')) {
				timebox = timeboxparent.children().eq(0);
				parentHeight = timeboxparent[0].clientHeight;
				height = timebox[0].offsetHeight;
				scrollbar = $('<div class="xdsoft_scrollbar"></div>');
				scroller = $('<div class="xdsoft_scroller"></div>');
				scrollbar.append(scroller);

				timeboxparent.addClass('xdsoft_scroller_box').append(scrollbar);
				calcOffset = function calcOffset(event) {
					var offset = pointerEventToXY(event).y - startY + startTopScroll;
					if (offset < 0) {
						offset = 0;
					}
					if (offset + scroller[0].offsetHeight > h1) {
						offset = h1 - scroller[0].offsetHeight;
					}
					timeboxparent.trigger('scroll_element.xdsoft_scroller', [maximumOffset ? offset / maximumOffset : 0]);
				};

				scroller
					.on('touchstart.xdsoft_scroller mousedown.xdsoft_scroller', function (event) {
						if (!parentHeight) {
							timeboxparent.trigger('resize_scroll.xdsoft_scroller', [percent]);
						}

						startY = pointerEventToXY(event).y;
						startTopScroll = parseInt(scroller.css('margin-top'), 10);
						h1 = scrollbar[0].offsetHeight;

						if (event.type === 'mousedown') {
							if (document) {
								$(document.body).addClass('xdsoft_noselect');
							}
							$([document.body, window]).on('mouseup.xdsoft_scroller', function arguments_callee() {
								$([document.body, window]).off('mouseup.xdsoft_scroller', arguments_callee)
									.off('mousemove.xdsoft_scroller', calcOffset)
									.removeClass('xdsoft_noselect');
							});
							$(document.body).on('mousemove.xdsoft_scroller', calcOffset);
						} else {
							touchStart = true;
							event.stopPropagation();
							event.preventDefault();
						}
					})
					.on('touchmove', function (event) {
						if (touchStart) {
							event.preventDefault();
							calcOffset(event);
						}
					})
					.on('touchend touchcancel', function (event) {
						touchStart =  false;
						startTopScroll = 0;
					});

				timeboxparent
					.on('scroll_element.xdsoft_scroller', function (event, percentage) {
						if (!parentHeight) {
							timeboxparent.trigger('resize_scroll.xdsoft_scroller', [percentage, true]);
						}
						percentage = percentage > 1 ? 1 : (percentage < 0 || isNaN(percentage)) ? 0 : percentage;

						scroller.css('margin-top', maximumOffset * percentage);

						setTimeout(function () {
							timebox.css('marginTop', -parseInt((timebox[0].offsetHeight - parentHeight) * percentage, 10));
						}, 10);
					})
					.on('resize_scroll.xdsoft_scroller', function (event, percentage, noTriggerScroll) {
						var percent, sh;
						parentHeight = timeboxparent[0].clientHeight;
						height = timebox[0].offsetHeight;
						percent = parentHeight / height;
						sh = percent * scrollbar[0].offsetHeight;
						if (percent > 1) {
							scroller.hide();
						} else {
							scroller.show();
							scroller.css('height', parseInt(sh > 10 ? sh : 10, 10));
							maximumOffset = scrollbar[0].offsetHeight - scroller[0].offsetHeight;
							if (noTriggerScroll !== true) {
								timeboxparent.trigger('scroll_element.xdsoft_scroller', [percentage || Math.abs(parseInt(timebox.css('marginTop'), 10)) / (height - parentHeight)]);
							}
						}
					});

				timeboxparent.on('mousewheel', function (event) {
					var top = Math.abs(parseInt(timebox.css('marginTop'), 10));

					top = top - (event.deltaY * 20);
					if (top < 0) {
						top = 0;
					}

					timeboxparent.trigger('scroll_element.xdsoft_scroller', [top / (height - parentHeight)]);
					event.stopPropagation();
					return false;
				});

				timeboxparent.on('touchstart', function (event) {
					start = pointerEventToXY(event);
					startTop = Math.abs(parseInt(timebox.css('marginTop'), 10));
				});

				timeboxparent.on('touchmove', function (event) {
					if (start) {
						event.preventDefault();
						var coord = pointerEventToXY(event);
						timeboxparent.trigger('scroll_element.xdsoft_scroller', [(startTop - (coord.y - start.y)) / (height - parentHeight)]);
					}
				});

				timeboxparent.on('touchend touchcancel', function (event) {
					start = false;
					startTop = 0;
				});
			}
			timeboxparent.trigger('resize_scroll.xdsoft_scroller', [percent]);
		});
	};

	$.fn.datetimepicker = function (opt) {
		var KEY0 = 48,
			KEY9 = 57,
			_KEY0 = 96,
			_KEY9 = 105,
			CTRLKEY = 17,
			DEL = 46,
			ENTER = 13,
			ESC = 27,
			BACKSPACE = 8,
			ARROWLEFT = 37,
			ARROWUP = 38,
			ARROWRIGHT = 39,
			ARROWDOWN = 40,
			TAB = 9,
			F5 = 116,
			AKEY = 65,
			CKEY = 67,
			VKEY = 86,
			ZKEY = 90,
			YKEY = 89,
			ctrlDown	=	false,
			options = ($.isPlainObject(opt) || !opt) ? $.extend(true, {}, default_options, opt) : $.extend(true, {}, default_options),

			lazyInitTimer = 0,
			createDateTimePicker,
			destroyDateTimePicker,

			lazyInit = function (input) {
				input
					.on('open.xdsoft focusin.xdsoft mousedown.xdsoft', function initOnActionCallback(event) {
						if (input.is(':disabled') || input.data('xdsoft_datetimepicker')) {
							return;
						}
						clearTimeout(lazyInitTimer);
						lazyInitTimer = setTimeout(function () {

							if (!input.data('xdsoft_datetimepicker')) {
								createDateTimePicker(input);
							}
							input
								.off('open.xdsoft focusin.xdsoft mousedown.xdsoft', initOnActionCallback)
								.trigger('open.xdsoft');
						}, 100);
					});
			};

		createDateTimePicker = function (input) {
			var datetimepicker = $('<div class="xdsoft_datetimepicker xdsoft_noselect"></div>'),
				xdsoft_copyright = $('<div class="xdsoft_copyright"><a target="_blank" href="http://xdsoft.net/jqplugins/datetimepicker/">xdsoft.net</a></div>'),
				datepicker = $('<div class="xdsoft_datepicker active"></div>'),
				mounth_picker = $('<div class="xdsoft_mounthpicker"><button type="button" class="xdsoft_prev"></button><button type="button" class="xdsoft_today_button"></button>' +
					'<div class="xdsoft_label xdsoft_month"><span></span><i></i></div>' +
					'<div class="xdsoft_label xdsoft_year"><span></span><i></i></div>' +
					'<button type="button" class="xdsoft_next"></button></div>'),
				calendar = $('<div class="xdsoft_calendar"></div>'),
				timepicker = $('<div class="xdsoft_timepicker active"><button type="button" class="xdsoft_prev"></button><div class="xdsoft_time_box"></div><button type="button" class="xdsoft_next"></button></div>'),
				timeboxparent = timepicker.find('.xdsoft_time_box').eq(0),
				timebox = $('<div class="xdsoft_time_variant"></div>'),
                applyButton = $('<button type="button" class="xdsoft_save_selected blue-gradient-button">Save Selected</button>'),
				/*scrollbar = $('<div class="xdsoft_scrollbar"></div>'),
				scroller = $('<div class="xdsoft_scroller"></div>'),*/
				monthselect = $('<div class="xdsoft_select xdsoft_monthselect"><div></div></div>'),
				yearselect = $('<div class="xdsoft_select xdsoft_yearselect"><div></div></div>'),
				triggerAfterOpen = false,
				XDSoft_datetime,
				//scroll_element,
				xchangeTimer,
				timerclick,
				current_time_index,
				setPos,
				timer = 0,
				timer1 = 0,
				_xdsoft_datetime;

			if (options.id) {
				datetimepicker.attr('id', options.id);
			}
			if (options.style) {
				datetimepicker.attr('style', options.style);
			}
			if (options.weeks) {
				datetimepicker.addClass('xdsoft_showweeks');
			}

			datetimepicker.addClass('xdsoft_' + options.theme);
			datetimepicker.addClass(options.className);

			mounth_picker
				.find('.xdsoft_month span')
					.after(monthselect);
			mounth_picker
				.find('.xdsoft_year span')
					.after(yearselect);

			mounth_picker
				.find('.xdsoft_month,.xdsoft_year')
					.on('mousedown.xdsoft', function (event) {
					var select = $(this).find('.xdsoft_select').eq(0),
						val = 0,
						top = 0,
						visible = select.is(':visible'),
						items,
						i;

					mounth_picker
						.find('.xdsoft_select')
							.hide();
					if (_xdsoft_datetime.currentTime) {
						val = _xdsoft_datetime.currentTime[$(this).hasClass('xdsoft_month') ? 'getMonth' : 'getFullYear']();
					}

					select[visible ? 'hide' : 'show']();
					for (items = select.find('div.xdsoft_option'), i = 0; i < items.length; i += 1) {
						if (items.eq(i).data('value') === val) {
							break;
						} else {
							top += items[0].offsetHeight;
						}
					}

					select.xdsoftScroller(top / (select.children()[0].offsetHeight - (select[0].clientHeight)));
					event.stopPropagation();
					return false;
				});

			mounth_picker
				.find('.xdsoft_select')
					.xdsoftScroller()
				.on('mousedown.xdsoft', function (event) {
					event.stopPropagation();
					event.preventDefault();
				})
				.on('mousedown.xdsoft', '.xdsoft_option', function (event) {

					if (_xdsoft_datetime.currentTime === undefined || _xdsoft_datetime.currentTime === null) {
						_xdsoft_datetime.currentTime = _xdsoft_datetime.now();
					}

					var year = _xdsoft_datetime.currentTime.getFullYear();
					if (_xdsoft_datetime && _xdsoft_datetime.currentTime) {
						_xdsoft_datetime.currentTime[$(this).parent().parent().hasClass('xdsoft_monthselect') ? 'setMonth' : 'setFullYear']($(this).data('value'));
					}

					$(this).parent().parent().hide();

					datetimepicker.trigger('xchange.xdsoft');
					if (options.onChangeMonth && $.isFunction(options.onChangeMonth)) {
						options.onChangeMonth.call(datetimepicker, _xdsoft_datetime.currentTime, datetimepicker.data('input'));
					}

					if (year !== _xdsoft_datetime.currentTime.getFullYear() && $.isFunction(options.onChangeYear)) {
						options.onChangeYear.call(datetimepicker, _xdsoft_datetime.currentTime, datetimepicker.data('input'));
					}
				});

			datetimepicker.setOptions = function (_options) {
				var highlightedDates = {},
					getCaretPos = function (input) {
						try {
							if (document.selection && document.selection.createRange) {
								var range = document.selection.createRange();
								return range.getBookmark().charCodeAt(2) - 2;
							}
							if (input.setSelectionRange) {
								return input.selectionStart;
							}
						} catch (e) {
							return 0;
						}
					},
					setCaretPos = function (node, pos) {
						node = (typeof node === "string" || node instanceof String) ? document.getElementById(node) : node;
						if (!node) {
							return false;
						}
						if (node.createTextRange) {
							var textRange = node.createTextRange();
							textRange.collapse(true);
							textRange.moveEnd('character', pos);
							textRange.moveStart('character', pos);
							textRange.select();
							return true;
						}
						if (node.setSelectionRange) {
							node.setSelectionRange(pos, pos);
							return true;
						}
						return false;
					},
					isValidValue = function (mask, value) {
						var reg = mask
							.replace(/([\[\]\/\{\}\(\)\-\.\+]{1})/g, '\\$1')
							.replace(/_/g, '{digit+}')
							.replace(/([0-9]{1})/g, '{digit$1}')
							.replace(/\{digit([0-9]{1})\}/g, '[0-$1_]{1}')
							.replace(/\{digit[\+]\}/g, '[0-9_]{1}');
						return (new RegExp(reg)).test(value);
					};
				options = $.extend(true, {}, options, _options);

				if (_options.allowTimes && $.isArray(_options.allowTimes) && _options.allowTimes.length) {
					options.allowTimes = $.extend(true, [], _options.allowTimes);
				}

				if (_options.weekends && $.isArray(_options.weekends) && _options.weekends.length) {
					options.weekends = $.extend(true, [], _options.weekends);
				}

				if (_options.highlightedDates && $.isArray(_options.highlightedDates) && _options.highlightedDates.length) {
					$.each(_options.highlightedDates, function (index, value) {
						var splitData = $.map(value.split(','), $.trim),
							exDesc,
							hDate = new HighlightedDate(Date.parseDate(splitData[0], options.formatDate), splitData[1], splitData[2]), // date, desc, style
							keyDate = hDate.date.dateFormat(options.formatDate);
						if (highlightedDates[keyDate] !== undefined) {
							exDesc = highlightedDates[keyDate].desc;
							if (exDesc && exDesc.length && hDate.desc && hDate.desc.length) {
								highlightedDates[keyDate].desc = exDesc + "\n" + hDate.desc;
							}
						} else {
							highlightedDates[keyDate] = hDate;
						}
					});

					options.highlightedDates = $.extend(true, [], highlightedDates);
				}

				if (_options.highlightedPeriods && $.isArray(_options.highlightedPeriods) && _options.highlightedPeriods.length) {
					highlightedDates = $.extend(true, [], options.highlightedDates);
					$.each(_options.highlightedPeriods, function (index, value) {
						var splitData = $.map(value.split(','), $.trim),
							dateTest = Date.parseDate(splitData[0], options.formatDate), // start date
							dateEnd = Date.parseDate(splitData[1], options.formatDate),
							desc = splitData[2],
							hDate,
							keyDate,
							exDesc,
							style = splitData[3];

						while (dateTest <= dateEnd) {
							hDate = new HighlightedDate(dateTest, desc, style);
							keyDate = dateTest.dateFormat(options.formatDate);
							dateTest.setDate(dateTest.getDate() + 1);
							if (highlightedDates[keyDate] !== undefined) {
								exDesc = highlightedDates[keyDate].desc;
								if (exDesc && exDesc.length && hDate.desc && hDate.desc.length) {
									highlightedDates[keyDate].desc = exDesc + "\n" + hDate.desc;
								}
							} else {
								highlightedDates[keyDate] = hDate;
							}
						}
					});

					options.highlightedDates = $.extend(true, [], highlightedDates);
				}

				if (_options.disabledDates && $.isArray(_options.disabledDates) && _options.disabledDates.length) {
					options.disabledDates = $.extend(true, [], _options.disabledDates);
				}

				if (_options.disabledWeekDays && $.isArray(_options.disabledWeekDays) && _options.disabledWeekDays.length) {
				    options.disabledWeekDays = $.extend(true, [], _options.disabledWeekDays);
				}

				if ((options.open || options.opened) && (!options.inline)) {
					input.trigger('open.xdsoft');
				}

				if (options.inline) {
					triggerAfterOpen = true;
					datetimepicker.addClass('xdsoft_inline');
					input.after(datetimepicker).hide();
				}

				if (options.inverseButton) {
					options.next = 'xdsoft_prev';
					options.prev = 'xdsoft_next';
				}

				if (options.datepicker) {
					datepicker.addClass('active');
				} else {
					datepicker.removeClass('active');
				}

				if (options.timepicker) {
					timepicker.addClass('active');
				} else {
					timepicker.removeClass('active');
				}

				if (options.value) {
					_xdsoft_datetime.setCurrentTime(options.value);
					if (input && input.val) {
						input.val(_xdsoft_datetime.str);
					}
				}

				if (isNaN(options.dayOfWeekStart)) {
					options.dayOfWeekStart = 0;
				} else {
					options.dayOfWeekStart = parseInt(options.dayOfWeekStart, 10) % 7;
				}

				if (!options.timepickerScrollbar) {
					timeboxparent.xdsoftScroller('hide');
				}

				if (options.minDate && /^-(.*)$/.test(options.minDate)) {
					options.minDate = _xdsoft_datetime.strToDateTime(options.minDate).dateFormat(options.formatDate);
				}

				if (options.maxDate &&  /^\+(.*)$/.test(options.maxDate)) {
					options.maxDate = _xdsoft_datetime.strToDateTime(options.maxDate).dateFormat(options.formatDate);
				}

				applyButton.toggle(options.showApplyButton);

				mounth_picker
					.find('.xdsoft_today_button')
						.css('visibility', !options.todayButton ? 'hidden' : 'visible');

				mounth_picker
					.find('.' + options.prev)
						.css('visibility', !options.prevButton ? 'hidden' : 'visible');

				mounth_picker
					.find('.' + options.next)
						.css('visibility', !options.nextButton ? 'hidden' : 'visible');

				if (options.mask) {
					input.off('keydown.xdsoft');

					if (options.mask === true) {
						options.mask = options.format
							.replace(/Y/g, '9999')
							.replace(/F/g, '9999')
							.replace(/m/g, '19')
							.replace(/d/g, '39')
							.replace(/H/g, '29')
							.replace(/i/g, '59')
							.replace(/s/g, '59');
					}

					if ($.type(options.mask) === 'string') {
						if (!isValidValue(options.mask, input.val())) {
							input.val(options.mask.replace(/[0-9]/g, '_'));
						}

						input.on('keydown.xdsoft', function (event) {
							var val = this.value,
								key = event.which,
								pos,
								digit;

							if (((key >= KEY0 && key <= KEY9) || (key >= _KEY0 && key <= _KEY9)) || (key === BACKSPACE || key === DEL)) {
								pos = getCaretPos(this);
								digit = (key !== BACKSPACE && key !== DEL) ? String.fromCharCode((_KEY0 <= key && key <= _KEY9) ? key - KEY0 : key) : '_';

								if ((key === BACKSPACE || key === DEL) && pos) {
									pos -= 1;
									digit = '_';
								}

								while (/[^0-9_]/.test(options.mask.substr(pos, 1)) && pos < options.mask.length && pos > 0) {
									pos += (key === BACKSPACE || key === DEL) ? -1 : 1;
								}

								val = val.substr(0, pos) + digit + val.substr(pos + 1);
								if ($.trim(val) === '') {
									val = options.mask.replace(/[0-9]/g, '_');
								} else {
									if (pos === options.mask.length) {
										event.preventDefault();
										return false;
									}
								}

								pos += (key === BACKSPACE || key === DEL) ? 0 : 1;
								while (/[^0-9_]/.test(options.mask.substr(pos, 1)) && pos < options.mask.length && pos > 0) {
									pos += (key === BACKSPACE || key === DEL) ? -1 : 1;
								}

								if (isValidValue(options.mask, val)) {
									this.value = val;
									setCaretPos(this, pos);
								} else if ($.trim(val) === '') {
									this.value = options.mask.replace(/[0-9]/g, '_');
								} else {
									input.trigger('error_input.xdsoft');
								}
							} else {
								if (([AKEY, CKEY, VKEY, ZKEY, YKEY].indexOf(key) !== -1 && ctrlDown) || [ESC, ARROWUP, ARROWDOWN, ARROWLEFT, ARROWRIGHT, F5, CTRLKEY, TAB, ENTER].indexOf(key) !== -1) {
									return true;
								}
							}

							event.preventDefault();
							return false;
						});
					}
				}
				if (options.validateOnBlur) {
					input
						.off('blur.xdsoft')
						.on('blur.xdsoft', function () {
							if (options.allowBlank && !$.trim($(this).val()).length) {
								$(this).val(null);
								datetimepicker.data('xdsoft_datetime').empty();
							} else if (!Date.parseDate($(this).val(), options.format)) {
								var splittedHours   = +([$(this).val()[0], $(this).val()[1]].join('')),
									splittedMinutes = +([$(this).val()[2], $(this).val()[3]].join(''));

								// parse the numbers as 0312 => 03:12
								if (!options.datepicker && options.timepicker && splittedHours >= 0 && splittedHours < 24 && splittedMinutes >= 0 && splittedMinutes < 60) {
									$(this).val([splittedHours, splittedMinutes].map(function (item) {
										return item > 9 ? item : '0' + item;
									}).join(':'));
								} else {
									$(this).val((_xdsoft_datetime.now()).dateFormat(options.format));
								}

								datetimepicker.data('xdsoft_datetime').setCurrentTime($(this).val());
							} else {
								datetimepicker.data('xdsoft_datetime').setCurrentTime($(this).val());
							}

							datetimepicker.trigger('changedatetime.xdsoft');
						});
				}
				options.dayOfWeekStartPrev = (options.dayOfWeekStart === 0) ? 6 : options.dayOfWeekStart - 1;

				datetimepicker
					.trigger('xchange.xdsoft')
					.trigger('afterOpen.xdsoft');
			};

			datetimepicker
				.data('options', options)
				.on('mousedown.xdsoft', function (event) {
					event.stopPropagation();
					event.preventDefault();
					yearselect.hide();
					monthselect.hide();
					return false;
				});

			//scroll_element = timepicker.find('.xdsoft_time_box');
			timeboxparent.append(timebox);
			timeboxparent.xdsoftScroller();

			datetimepicker.on('afterOpen.xdsoft', function () {
				timeboxparent.xdsoftScroller();
			});

			datetimepicker
				.append(datepicker)
				.append(timepicker);

			if (options.withoutCopyright !== true) {
				datetimepicker
					.append(xdsoft_copyright);
			}

			datepicker
				.append(mounth_picker)
				.append(calendar)
				.append(applyButton);

			$(options.parentID)
				.append(datetimepicker);

			XDSoft_datetime = function () {
				var _this = this;
				_this.now = function (norecursion) {
					var d = new Date(),
						date,
						time;

					if (!norecursion && options.defaultDate) {
						date = _this.strToDateTime(options.defaultDate);
						d.setFullYear(date.getFullYear());
						d.setMonth(date.getMonth());
						d.setDate(date.getDate());
					}

					if (options.yearOffset) {
						d.setFullYear(d.getFullYear() + options.yearOffset);
					}

					if (!norecursion && options.defaultTime) {
						time = _this.strtotime(options.defaultTime);
						d.setHours(time.getHours());
						d.setMinutes(time.getMinutes());
					}
					return d;
				};

				_this.isValidDate = function (d) {
					if (Object.prototype.toString.call(d) !== "[object Date]") {
						return false;
					}
					return !isNaN(d.getTime());
				};

				_this.setCurrentTime = function (dTime) {
					_this.currentTime = (typeof dTime === 'string') ? _this.strToDateTime(dTime) : _this.isValidDate(dTime) ? dTime : _this.now();
					datetimepicker.trigger('xchange.xdsoft');
				};

				_this.empty = function () {
					_this.currentTime = null;
				};

				_this.getCurrentTime = function (dTime) {
					return _this.currentTime;
				};

				_this.nextMonth = function () {

					if (_this.currentTime === undefined || _this.currentTime === null) {
						_this.currentTime = _this.now();
					}

					var month = _this.currentTime.getMonth() + 1,
						year;
					if (month === 12) {
						_this.currentTime.setFullYear(_this.currentTime.getFullYear() + 1);
						month = 0;
					}

					year = _this.currentTime.getFullYear();

					_this.currentTime.setDate(
						Math.min(
							new Date(_this.currentTime.getFullYear(), month + 1, 0).getDate(),
							_this.currentTime.getDate()
						)
					);
					_this.currentTime.setMonth(month);

					if (options.onChangeMonth && $.isFunction(options.onChangeMonth)) {
						options.onChangeMonth.call(datetimepicker, _xdsoft_datetime.currentTime, datetimepicker.data('input'));
					}

					if (year !== _this.currentTime.getFullYear() && $.isFunction(options.onChangeYear)) {
						options.onChangeYear.call(datetimepicker, _xdsoft_datetime.currentTime, datetimepicker.data('input'));
					}

					datetimepicker.trigger('xchange.xdsoft');
					return month;
				};

				_this.prevMonth = function () {

					if (_this.currentTime === undefined || _this.currentTime === null) {
						_this.currentTime = _this.now();
					}

					var month = _this.currentTime.getMonth() - 1;
					if (month === -1) {
						_this.currentTime.setFullYear(_this.currentTime.getFullYear() - 1);
						month = 11;
					}
					_this.currentTime.setDate(
						Math.min(
							new Date(_this.currentTime.getFullYear(), month + 1, 0).getDate(),
							_this.currentTime.getDate()
						)
					);
					_this.currentTime.setMonth(month);
					if (options.onChangeMonth && $.isFunction(options.onChangeMonth)) {
						options.onChangeMonth.call(datetimepicker, _xdsoft_datetime.currentTime, datetimepicker.data('input'));
					}
					datetimepicker.trigger('xchange.xdsoft');
					return month;
				};

				_this.getWeekOfYear = function (datetime) {
					var onejan = new Date(datetime.getFullYear(), 0, 1);
					return Math.ceil((((datetime - onejan) / 86400000) + onejan.getDay() + 1) / 7);
				};

				_this.strToDateTime = function (sDateTime) {
					var tmpDate = [], timeOffset, currentTime;

					if (sDateTime && sDateTime instanceof Date && _this.isValidDate(sDateTime)) {
						return sDateTime;
					}

					tmpDate = /^(\+|\-)(.*)$/.exec(sDateTime);
					if (tmpDate) {
						tmpDate[2] = Date.parseDate(tmpDate[2], options.formatDate);
					}
					if (tmpDate  && tmpDate[2]) {
						timeOffset = tmpDate[2].getTime() - (tmpDate[2].getTimezoneOffset()) * 60000;
						currentTime = new Date((_this.now(true)).getTime() + parseInt(tmpDate[1] + '1', 10) * timeOffset);
					} else {
						currentTime = sDateTime ? Date.parseDate(sDateTime, options.format) : _this.now();
					}

					if (!_this.isValidDate(currentTime)) {
						currentTime = _this.now();
					}

					return currentTime;
				};

				_this.strToDate = function (sDate) {
					if (sDate && sDate instanceof Date && _this.isValidDate(sDate)) {
						return sDate;
					}

					var currentTime = sDate ? Date.parseDate(sDate, options.formatDate) : _this.now(true);
					if (!_this.isValidDate(currentTime)) {
						currentTime = _this.now(true);
					}
					return currentTime;
				};

				_this.strtotime = function (sTime) {
					if (sTime && sTime instanceof Date && _this.isValidDate(sTime)) {
						return sTime;
					}
					var currentTime = sTime ? Date.parseDate(sTime, options.formatTime) : _this.now(true);
					if (!_this.isValidDate(currentTime)) {
						currentTime = _this.now(true);
					}
					return currentTime;
				};

				_this.str = function () {
					return _this.currentTime.dateFormat(options.format);
				};
				_this.currentTime = this.now();
			};

			_xdsoft_datetime = new XDSoft_datetime();

			applyButton.on('click', function (e) {//pathbrite
                e.preventDefault();
                datetimepicker.data('changed', true);
                _xdsoft_datetime.setCurrentTime(getCurrentValue());
                input.val(_xdsoft_datetime.str());
                datetimepicker.trigger('close.xdsoft');
            });
			mounth_picker
				.find('.xdsoft_today_button')
				.on('mousedown.xdsoft', function () {
					datetimepicker.data('changed', true);
					_xdsoft_datetime.setCurrentTime(0);
					datetimepicker.trigger('afterOpen.xdsoft');
				}).on('dblclick.xdsoft', function () {
					var currentDate = _xdsoft_datetime.getCurrentTime(), minDate, maxDate;
					currentDate = new Date(currentDate.getFullYear(), currentDate.getMonth(), currentDate.getDate());
					minDate = _xdsoft_datetime.strToDate(options.minDate);
					minDate = new Date(minDate.getFullYear(), minDate.getMonth(), minDate.getDate());
					if (currentDate < minDate) {
						return;
					}
					maxDate = _xdsoft_datetime.strToDate(options.maxDate);
					maxDate = new Date(maxDate.getFullYear(), maxDate.getMonth(), maxDate.getDate());
					if (currentDate > maxDate) {
						return;
					}
					input.val(_xdsoft_datetime.str());
					datetimepicker.trigger('close.xdsoft');
				});
			mounth_picker
				.find('.xdsoft_prev,.xdsoft_next')
				.on('mousedown.xdsoft', function () {
					var $this = $(this),
						timer = 0,
						stop = false;

					(function arguments_callee1(v) {
						if ($this.hasClass(options.next)) {
							_xdsoft_datetime.nextMonth();
						} else if ($this.hasClass(options.prev)) {
							_xdsoft_datetime.prevMonth();
						}
						if (options.monthChangeSpinner) {
							if (!stop) {
								timer = setTimeout(arguments_callee1, v || 100);
							}
						}
					}(500));

					$([document.body, window]).on('mouseup.xdsoft', function arguments_callee2() {
						clearTimeout(timer);
						stop = true;
						$([document.body, window]).off('mouseup.xdsoft', arguments_callee2);
					});
				});

			timepicker
				.find('.xdsoft_prev,.xdsoft_next')
				.on('mousedown.xdsoft', function () {
					var $this = $(this),
						timer = 0,
						stop = false,
						period = 110;
					(function arguments_callee4(v) {
						var pheight = timeboxparent[0].clientHeight,
							height = timebox[0].offsetHeight,
							top = Math.abs(parseInt(timebox.css('marginTop'), 10));
						if ($this.hasClass(options.next) && (height - pheight) - options.timeHeightInTimePicker >= top) {
							timebox.css('marginTop', '-' + (top + options.timeHeightInTimePicker) + 'px');
						} else if ($this.hasClass(options.prev) && top - options.timeHeightInTimePicker >= 0) {
							timebox.css('marginTop', '-' + (top - options.timeHeightInTimePicker) + 'px');
						}
						timeboxparent.trigger('scroll_element.xdsoft_scroller', [Math.abs(parseInt(timebox.css('marginTop'), 10) / (height - pheight))]);
						period = (period > 10) ? 10 : period - 10;
						if (!stop) {
							timer = setTimeout(arguments_callee4, v || period);
						}
					}(500));
					$([document.body, window]).on('mouseup.xdsoft', function arguments_callee5() {
						clearTimeout(timer);
						stop = true;
						$([document.body, window])
							.off('mouseup.xdsoft', arguments_callee5);
					});
				});

			xchangeTimer = 0;
			// base handler - generating a calendar and timepicker
			datetimepicker
				.on('xchange.xdsoft', function (event) {
					clearTimeout(xchangeTimer);
					xchangeTimer = setTimeout(function () {

						if (_xdsoft_datetime.currentTime === undefined || _xdsoft_datetime.currentTime === null) {
							_xdsoft_datetime.currentTime = _xdsoft_datetime.now();
						}

						var table =	'',
							start = new Date(_xdsoft_datetime.currentTime.getFullYear(), _xdsoft_datetime.currentTime.getMonth(), 1, 12, 0, 0),
							i = 0,
							j,
							today = _xdsoft_datetime.now(),
							maxDate = false,
							minDate = false,
							hDate,
							day,
							d,
							y,
							m,
							w,
							classes = [],
							customDateSettings,
							newRow = true,
							time = '',
							h = '',
							line_time,
							description;

						while (start.getDay() !== options.dayOfWeekStart) {
							start.setDate(start.getDate() - 1);
						}

						table += '<table><thead><tr>';

						if (options.weeks) {
							table += '<th></th>';
						}

						for (j = 0; j < 7; j += 1) {
							table += '<th>' + options.i18n[options.lang].dayOfWeek[(j + options.dayOfWeekStart) % 7] + '</th>';
						}

						table += '</tr></thead>';
						table += '<tbody>';

						if (options.maxDate !== false) {
							maxDate = _xdsoft_datetime.strToDate(options.maxDate);
							maxDate = new Date(maxDate.getFullYear(), maxDate.getMonth(), maxDate.getDate(), 23, 59, 59, 999);
						}

						if (options.minDate !== false) {
							minDate = _xdsoft_datetime.strToDate(options.minDate);
							minDate = new Date(minDate.getFullYear(), minDate.getMonth(), minDate.getDate());
						}

						while (i < _xdsoft_datetime.currentTime.countDaysInMonth() || start.getDay() !== options.dayOfWeekStart || _xdsoft_datetime.currentTime.getMonth() === start.getMonth()) {
							classes = [];
							i += 1;

							day = start.getDay();
							d = start.getDate();
							y = start.getFullYear();
							m = start.getMonth();
							w = _xdsoft_datetime.getWeekOfYear(start);
							description = '';

							classes.push('xdsoft_date');

							if (options.beforeShowDay && $.isFunction(options.beforeShowDay.call)) {
								customDateSettings = options.beforeShowDay.call(datetimepicker, start);
							} else {
								customDateSettings = null;
							}

							if ((maxDate !== false && start > maxDate) || (minDate !== false && start < minDate) || (customDateSettings && customDateSettings[0] === false)) {
								classes.push('xdsoft_disabled');
							} else if (options.disabledDates.indexOf(start.dateFormat(options.formatDate)) !== -1) {
								classes.push('xdsoft_disabled');
							} else if (options.disabledWeekDays.indexOf(day) !== -1) {
							    classes.push('xdsoft_disabled');
							}

							if (customDateSettings && customDateSettings[1] !== "") {
								classes.push(customDateSettings[1]);
							}

							if (_xdsoft_datetime.currentTime.getMonth() !== m) {
								classes.push('xdsoft_other_month');
							}

							if ((options.defaultSelect || datetimepicker.data('changed')) && _xdsoft_datetime.currentTime.dateFormat(options.formatDate) === start.dateFormat(options.formatDate)) {
								classes.push('xdsoft_current');
							}

							if (today.dateFormat(options.formatDate) === start.dateFormat(options.formatDate)) {
								classes.push('xdsoft_today');
							}

							if (start.getDay() === 0 || start.getDay() === 6 || options.weekends.indexOf(start.dateFormat(options.formatDate)) !== -1) {
								classes.push('xdsoft_weekend');
							}

							if (options.highlightedDates[start.dateFormat(options.formatDate)] !== undefined) {
								hDate = options.highlightedDates[start.dateFormat(options.formatDate)];
								classes.push(hDate.style === undefined ? 'xdsoft_highlighted_default' : hDate.style);
								description = hDate.desc === undefined ? '' : hDate.desc;
							}

							if (options.beforeShowDay && $.isFunction(options.beforeShowDay)) {
								classes.push(options.beforeShowDay(start));
							}

							if (newRow) {
								table += '<tr>';
								newRow = false;
								if (options.weeks) {
									table += '<th>' + w + '</th>';
								}
							}

							table += '<td data-date="' + d + '" data-month="' + m + '" data-year="' + y + '"' + ' class="xdsoft_date xdsoft_day_of_week' + start.getDay() + ' ' + classes.join(' ') + '" title="' + description + '">' +
										'<div>' + d + '</div>' +
									'</td>';

							if (start.getDay() === options.dayOfWeekStartPrev) {
								table += '</tr>';
								newRow = true;
							}

							start.setDate(d + 1);
						}
						table += '</tbody></table>';

						calendar.html(table);

						mounth_picker.find('.xdsoft_label span').eq(0).text(options.i18n[options.lang].months[_xdsoft_datetime.currentTime.getMonth()]);
						mounth_picker.find('.xdsoft_label span').eq(1).text(_xdsoft_datetime.currentTime.getFullYear());

						// generate timebox
						time = '';
						h = '';
						m = '';
						line_time = function line_time(h, m) {
							var now = _xdsoft_datetime.now(), optionDateTime, current_time;
							now.setHours(h);
							h = parseInt(now.getHours(), 10);
							now.setMinutes(m);
							m = parseInt(now.getMinutes(), 10);
							optionDateTime = new Date(_xdsoft_datetime.currentTime);
							optionDateTime.setHours(h);
							optionDateTime.setMinutes(m);
							classes = [];
							if ((options.minDateTime !== false && options.minDateTime > optionDateTime) || (options.maxTime !== false && _xdsoft_datetime.strtotime(options.maxTime).getTime() < now.getTime()) || (options.minTime !== false && _xdsoft_datetime.strtotime(options.minTime).getTime() > now.getTime())) {
								classes.push('xdsoft_disabled');
							}
							if ((options.minDateTime !== false && options.minDateTime > optionDateTime) || ((options.disabledMinTime !== false && now.getTime() > _xdsoft_datetime.strtotime(options.disabledMinTime).getTime()) && (options.disabledMaxTime !== false && now.getTime() < _xdsoft_datetime.strtotime(options.disabledMaxTime).getTime()))) {
								classes.push('xdsoft_disabled');
							}

							current_time = new Date(_xdsoft_datetime.currentTime);
							current_time.setHours(parseInt(_xdsoft_datetime.currentTime.getHours(), 10));
							current_time.setMinutes(Math[options.roundTime](_xdsoft_datetime.currentTime.getMinutes() / options.step) * options.step);

							if ((options.initTime || options.defaultSelect || datetimepicker.data('changed')) && current_time.getHours() === parseInt(h, 10) && (options.step > 59 || current_time.getMinutes() === parseInt(m, 10))) {
								if (options.defaultSelect || datetimepicker.data('changed')) {
									classes.push('xdsoft_current');
								} else if (options.initTime) {
									classes.push('xdsoft_init_time');
								}
							}
							if (parseInt(today.getHours(), 10) === parseInt(h, 10) && parseInt(today.getMinutes(), 10) === parseInt(m, 10)) {
								classes.push('xdsoft_today');
							}
							time += '<div class="xdsoft_time ' + classes.join(' ') + '" data-hour="' + h + '" data-minute="' + m + '">' + now.dateFormat(options.formatTime) + '</div>';
						};

						if (!options.allowTimes || !$.isArray(options.allowTimes) || !options.allowTimes.length) {
							for (i = 0, j = 0; i < (options.hours12 ? 12 : 24); i += 1) {
								for (j = 0; j < 60; j += options.step) {
									h = (i < 10 ? '0' : '') + i;
									m = (j < 10 ? '0' : '') + j;
									line_time(h, m);
								}
							}
						} else {
							for (i = 0; i < options.allowTimes.length; i += 1) {
								h = _xdsoft_datetime.strtotime(options.allowTimes[i]).getHours();
								m = _xdsoft_datetime.strtotime(options.allowTimes[i]).getMinutes();
								line_time(h, m);
							}
						}

						timebox.html(time);

						opt = '';
						i = 0;

						for (i = parseInt(options.yearStart, 10) + options.yearOffset; i <= parseInt(options.yearEnd, 10) + options.yearOffset; i += 1) {
							opt += '<div class="xdsoft_option ' + (_xdsoft_datetime.currentTime.getFullYear() === i ? 'xdsoft_current' : '') + '" data-value="' + i + '">' + i + '</div>';
						}
						yearselect.children().eq(0)
												.html(opt);

						for (i = parseInt(options.monthStart, 10), opt = ''; i <= parseInt(options.monthEnd, 10); i += 1) {
							opt += '<div class="xdsoft_option ' + (_xdsoft_datetime.currentTime.getMonth() === i ? 'xdsoft_current' : '') + '" data-value="' + i + '">' + options.i18n[options.lang].months[i] + '</div>';
						}
						monthselect.children().eq(0).html(opt);
						$(datetimepicker)
							.trigger('generate.xdsoft');
					}, 10);
					event.stopPropagation();
				})
				.on('afterOpen.xdsoft', function () {
					if (options.timepicker) {
						var classType, pheight, height, top;
						if (timebox.find('.xdsoft_current').length) {
							classType = '.xdsoft_current';
						} else if (timebox.find('.xdsoft_init_time').length) {
							classType = '.xdsoft_init_time';
						}
						if (classType) {
							pheight = timeboxparent[0].clientHeight;
							height = timebox[0].offsetHeight;
							top = timebox.find(classType).index() * options.timeHeightInTimePicker + 1;
							if ((height - pheight) < top) {
								top = height - pheight;
							}
							timeboxparent.trigger('scroll_element.xdsoft_scroller', [parseInt(top, 10) / (height - pheight)]);
						} else {
							timeboxparent.trigger('scroll_element.xdsoft_scroller', [0]);
						}
					}
				});

			timerclick = 0;
			calendar
				.on('click.xdsoft', 'td', function (xdevent) {
					xdevent.stopPropagation();  // Prevents closing of Pop-ups, Modals and Flyouts in Bootstrap
					timerclick += 1;
					var $this = $(this),
						currentTime = _xdsoft_datetime.currentTime;

					if (currentTime === undefined || currentTime === null) {
						_xdsoft_datetime.currentTime = _xdsoft_datetime.now();
						currentTime = _xdsoft_datetime.currentTime;
					}

					if ($this.hasClass('xdsoft_disabled')) {
						return false;
					}

					currentTime.setDate(1);
					currentTime.setFullYear($this.data('year'));
					currentTime.setMonth($this.data('month'));
					currentTime.setDate($this.data('date'));

					datetimepicker.trigger('select.xdsoft', [currentTime]);

					input.val(_xdsoft_datetime.str());
					if ((timerclick > 1 || (options.closeOnDateSelect === true || (options.closeOnDateSelect === false && !options.timepicker))) && !options.inline) {
						datetimepicker.trigger('close.xdsoft');
					}

					if (options.onSelectDate &&	$.isFunction(options.onSelectDate)) {
						options.onSelectDate.call(datetimepicker, _xdsoft_datetime.currentTime, datetimepicker.data('input'), xdevent);
					}

					datetimepicker.data('changed', true);
					datetimepicker.trigger('xchange.xdsoft');
					datetimepicker.trigger('changedatetime.xdsoft');
					setTimeout(function () {
						timerclick = 0;
					}, 200);
				});

			timebox
				.on('click.xdsoft', 'div', function (xdevent) {
					xdevent.stopPropagation();
					var $this = $(this),
						currentTime = _xdsoft_datetime.currentTime;

					if (currentTime === undefined || currentTime === null) {
						_xdsoft_datetime.currentTime = _xdsoft_datetime.now();
						currentTime = _xdsoft_datetime.currentTime;
					}

					if ($this.hasClass('xdsoft_disabled')) {
						return false;
					}
					currentTime.setHours($this.data('hour'));
					currentTime.setMinutes($this.data('minute'));
					datetimepicker.trigger('select.xdsoft', [currentTime]);

					datetimepicker.data('input').val(_xdsoft_datetime.str());

                    if (options.inline !== true && options.closeOnTimeSelect === true) {
                        datetimepicker.trigger('close.xdsoft');
                    }

					if (options.onSelectTime && $.isFunction(options.onSelectTime)) {
						options.onSelectTime.call(datetimepicker, _xdsoft_datetime.currentTime, datetimepicker.data('input'), xdevent);
					}
					datetimepicker.data('changed', true);
					datetimepicker.trigger('xchange.xdsoft');
					datetimepicker.trigger('changedatetime.xdsoft');
				});


			datepicker
				.on('mousewheel.xdsoft', function (event) {
					if (!options.scrollMonth) {
						return true;
					}
					if (event.deltaY < 0) {
						_xdsoft_datetime.nextMonth();
					} else {
						_xdsoft_datetime.prevMonth();
					}
					return false;
				});

			input
				.on('mousewheel.xdsoft', function (event) {
					if (!options.scrollInput) {
						return true;
					}
					if (!options.datepicker && options.timepicker) {
						current_time_index = timebox.find('.xdsoft_current').length ? timebox.find('.xdsoft_current').eq(0).index() : 0;
						if (current_time_index + event.deltaY >= 0 && current_time_index + event.deltaY < timebox.children().length) {
							current_time_index += event.deltaY;
						}
						if (timebox.children().eq(current_time_index).length) {
							timebox.children().eq(current_time_index).trigger('mousedown');
						}
						return false;
					}
					if (options.datepicker && !options.timepicker) {
						datepicker.trigger(event, [event.deltaY, event.deltaX, event.deltaY]);
						if (input.val) {
							input.val(_xdsoft_datetime.str());
						}
						datetimepicker.trigger('changedatetime.xdsoft');
						return false;
					}
				});

			datetimepicker
				.on('changedatetime.xdsoft', function (event) {
					if (options.onChangeDateTime && $.isFunction(options.onChangeDateTime)) {
						var $input = datetimepicker.data('input');
						options.onChangeDateTime.call(datetimepicker, _xdsoft_datetime.currentTime, $input, event);
						delete options.value;
						$input.trigger('change');
					}
				})
				.on('generate.xdsoft', function () {
					if (options.onGenerate && $.isFunction(options.onGenerate)) {
						options.onGenerate.call(datetimepicker, _xdsoft_datetime.currentTime, datetimepicker.data('input'));
					}
					if (triggerAfterOpen) {
						datetimepicker.trigger('afterOpen.xdsoft');
						triggerAfterOpen = false;
					}
				})
				.on('click.xdsoft', function (xdevent) {
					xdevent.stopPropagation();
				});

			current_time_index = 0;

			setPos = function () {
				var offset = datetimepicker.data('input').offset(), top = offset.top + datetimepicker.data('input')[0].offsetHeight - 1, left = offset.left, position = "absolute", node;
				if (options.fixed) {
					top -= $(window).scrollTop();
					left -= $(window).scrollLeft();
					position = "fixed";
				} else {
					if (top + datetimepicker[0].offsetHeight > $(window).height() + $(window).scrollTop()) {
						top = offset.top - datetimepicker[0].offsetHeight + 1;
					}
					if (top < 0) {
						top = 0;
					}
					if (left + datetimepicker[0].offsetWidth > $(window).width()) {
						left = $(window).width() - datetimepicker[0].offsetWidth;
					}
				}

				node = datetimepicker[0];
				do {
					node = node.parentNode;
					if (window.getComputedStyle(node).getPropertyValue('position') === 'relative' && $(window).width() >= node.offsetWidth) {
						left = left - (($(window).width() - node.offsetWidth) / 2);
						break;
					}
				} while (node.nodeName !== 'HTML');
				datetimepicker.css({
					left: left,
					top: top,
					position: position
				});
			};
			datetimepicker
				.on('open.xdsoft', function (event) {
					var onShow = true;
					if (options.onShow && $.isFunction(options.onShow)) {
						onShow = options.onShow.call(datetimepicker, _xdsoft_datetime.currentTime, datetimepicker.data('input'), event);
					}
					if (onShow !== false) {
						datetimepicker.show();
						setPos();
						$(window)
							.off('resize.xdsoft', setPos)
							.on('resize.xdsoft', setPos);

						if (options.closeOnWithoutClick) {
							$([document.body, window]).on('mousedown.xdsoft', function arguments_callee6() {
								datetimepicker.trigger('close.xdsoft');
								$([document.body, window]).off('mousedown.xdsoft', arguments_callee6);
							});
						}
					}
				})
				.on('close.xdsoft', function (event) {
					var onClose = true;
					mounth_picker
						.find('.xdsoft_month,.xdsoft_year')
							.find('.xdsoft_select')
								.hide();
					if (options.onClose && $.isFunction(options.onClose)) {
						onClose = options.onClose.call(datetimepicker, _xdsoft_datetime.currentTime, datetimepicker.data('input'), event);
					}
					if (onClose !== false && !options.opened && !options.inline) {
						datetimepicker.hide();
					}
					event.stopPropagation();
				})
				.on('toggle.xdsoft', function (event) {
					if (datetimepicker.is(':visible')) {
						datetimepicker.trigger('close.xdsoft');
					} else {
						datetimepicker.trigger('open.xdsoft');
					}
				})
				.data('input', input);

			timer = 0;
			timer1 = 0;

			datetimepicker.data('xdsoft_datetime', _xdsoft_datetime);
			datetimepicker.setOptions(options);

			function getCurrentValue() {
				var ct = false, time;

				if (options.startDate) {
					ct = _xdsoft_datetime.strToDate(options.startDate);
				} else {
					ct = options.value || ((input && input.val && input.val()) ? input.val() : '');
					if (ct) {
						ct = _xdsoft_datetime.strToDateTime(ct);
					} else if (options.defaultDate) {
						ct = _xdsoft_datetime.strToDateTime(options.defaultDate);
						if (options.defaultTime) {
							time = _xdsoft_datetime.strtotime(options.defaultTime);
							ct.setHours(time.getHours());
							ct.setMinutes(time.getMinutes());
						}
					}
				}

				if (ct && _xdsoft_datetime.isValidDate(ct)) {
					datetimepicker.data('changed', true);
				} else {
					ct = '';
				}

				return ct || 0;
			}

			_xdsoft_datetime.setCurrentTime(getCurrentValue());

			input
				.data('xdsoft_datetimepicker', datetimepicker)
				.on('open.xdsoft focusin.xdsoft mousedown.xdsoft', function (event) {
					if (input.is(':disabled') || (input.data('xdsoft_datetimepicker').is(':visible') && options.closeOnInputClick)) {
						return;
					}
					clearTimeout(timer);
					timer = setTimeout(function () {
						if (input.is(':disabled')) {
							return;
						}

						triggerAfterOpen = true;
						_xdsoft_datetime.setCurrentTime(getCurrentValue());

						datetimepicker.trigger('open.xdsoft');
					}, 100);
				})
				.on('keydown.xdsoft', function (event) {
					var val = this.value, elementSelector,
						key = event.which;
					if ([ENTER].indexOf(key) !== -1 && options.enterLikeTab) {
						elementSelector = $("input:visible,textarea:visible");
						datetimepicker.trigger('close.xdsoft');
						elementSelector.eq(elementSelector.index(this) + 1).focus();
						return false;
					}
					if ([TAB].indexOf(key) !== -1) {
						datetimepicker.trigger('close.xdsoft');
						return true;
					}
				});
		};
		destroyDateTimePicker = function (input) {
			var datetimepicker = input.data('xdsoft_datetimepicker');
			if (datetimepicker) {
				datetimepicker.data('xdsoft_datetime', null);
				datetimepicker.remove();
				input
					.data('xdsoft_datetimepicker', null)
					.off('.xdsoft');
				$(window).off('resize.xdsoft');
				$([window, document.body]).off('mousedown.xdsoft');
				if (input.unmousewheel) {
					input.unmousewheel();
				}
			}
		};
		$(document)
			.off('keydown.xdsoftctrl keyup.xdsoftctrl')
			.on('keydown.xdsoftctrl', function (e) {
				if (e.keyCode === CTRLKEY) {
					ctrlDown = true;
				}
			})
			.on('keyup.xdsoftctrl', function (e) {
				if (e.keyCode === CTRLKEY) {
					ctrlDown = false;
				}
			});
		return this.each(function () {
			var datetimepicker = $(this).data('xdsoft_datetimepicker'), $input;
			if (datetimepicker) {
				if ($.type(opt) === 'string') {
					switch (opt) {
					case 'show':
						$(this).select().focus();
						datetimepicker.trigger('open.xdsoft');
						break;
					case 'hide':
						datetimepicker.trigger('close.xdsoft');
						break;
					case 'toggle':
						datetimepicker.trigger('toggle.xdsoft');
						break;
					case 'destroy':
						destroyDateTimePicker($(this));
						break;
					case 'reset':
						this.value = this.defaultValue;
						if (!this.value || !datetimepicker.data('xdsoft_datetime').isValidDate(Date.parseDate(this.value, options.format))) {
							datetimepicker.data('changed', false);
						}
						datetimepicker.data('xdsoft_datetime').setCurrentTime(this.value);
						break;
					case 'validate':
						$input = datetimepicker.data('input');
						$input.trigger('blur.xdsoft');
						break;
					}
				} else {
					datetimepicker
						.setOptions(opt);
				}
				return 0;
			}
			if ($.type(opt) !== 'string') {
				if (!options.lazyInit || options.open || options.inline) {
					createDateTimePicker($(this));
				} else {
					lazyInit($(this));
				}
			}
		});
	};
	$.fn.datetimepicker.defaults = default_options;
}(jQuery));

function HighlightedDate(date, desc, style) {
	"use strict";
	this.date = date;
	this.desc = desc;
	this.style = style;
}

(function () {

/*! Copyright (c) 2013 Brandon Aaron (http://brandon.aaron.sh)
 * Licensed under the MIT License (LICENSE.txt).
 *
 * Version: 3.1.12
 *
 * Requires: jQuery 1.2.2+
 */
!function(a){"function"==typeof define&&define.amd?define(["jquery"],a):"object"==typeof exports?module.exports=a:a(jQuery)}(function(a){function b(b){var g=b||window.event,h=i.call(arguments,1),j=0,l=0,m=0,n=0,o=0,p=0;if(b=a.event.fix(g),b.type="mousewheel","detail"in g&&(m=-1*g.detail),"wheelDelta"in g&&(m=g.wheelDelta),"wheelDeltaY"in g&&(m=g.wheelDeltaY),"wheelDeltaX"in g&&(l=-1*g.wheelDeltaX),"axis"in g&&g.axis===g.HORIZONTAL_AXIS&&(l=-1*m,m=0),j=0===m?l:m,"deltaY"in g&&(m=-1*g.deltaY,j=m),"deltaX"in g&&(l=g.deltaX,0===m&&(j=-1*l)),0!==m||0!==l){if(1===g.deltaMode){var q=a.data(this,"mousewheel-line-height");j*=q,m*=q,l*=q}else if(2===g.deltaMode){var r=a.data(this,"mousewheel-page-height");j*=r,m*=r,l*=r}if(n=Math.max(Math.abs(m),Math.abs(l)),(!f||f>n)&&(f=n,d(g,n)&&(f/=40)),d(g,n)&&(j/=40,l/=40,m/=40),j=Math[j>=1?"floor":"ceil"](j/f),l=Math[l>=1?"floor":"ceil"](l/f),m=Math[m>=1?"floor":"ceil"](m/f),k.settings.normalizeOffset&&this.getBoundingClientRect){var s=this.getBoundingClientRect();o=b.clientX-s.left,p=b.clientY-s.top}return b.deltaX=l,b.deltaY=m,b.deltaFactor=f,b.offsetX=o,b.offsetY=p,b.deltaMode=0,h.unshift(b,j,l,m),e&&clearTimeout(e),e=setTimeout(c,200),(a.event.dispatch||a.event.handle).apply(this,h)}}function c(){f=null}function d(a,b){return k.settings.adjustOldDeltas&&"mousewheel"===a.type&&b%120===0}var e,f,g=["wheel","mousewheel","DOMMouseScroll","MozMousePixelScroll"],h="onwheel"in document||document.documentMode>=9?["wheel"]:["mousewheel","DomMouseScroll","MozMousePixelScroll"],i=Array.prototype.slice;if(a.event.fixHooks)for(var j=g.length;j;)a.event.fixHooks[g[--j]]=a.event.mouseHooks;var k=a.event.special.mousewheel={version:"3.1.12",setup:function(){if(this.addEventListener)for(var c=h.length;c;)this.addEventListener(h[--c],b,!1);else this.onmousewheel=b;a.data(this,"mousewheel-line-height",k.getLineHeight(this)),a.data(this,"mousewheel-page-height",k.getPageHeight(this))},teardown:function(){if(this.removeEventListener)for(var c=h.length;c;)this.removeEventListener(h[--c],b,!1);else this.onmousewheel=null;a.removeData(this,"mousewheel-line-height"),a.removeData(this,"mousewheel-page-height")},getLineHeight:function(b){var c=a(b),d=c["offsetParent"in a.fn?"offsetParent":"parent"]();return d.length||(d=a("body")),parseInt(d.css("fontSize"),10)||parseInt(c.css("fontSize"),10)||16},getPageHeight:function(b){return a(b).height()},settings:{adjustOldDeltas:!0,normalizeOffset:!0}};a.fn.extend({mousewheel:function(a){return a?this.bind("mousewheel",a):this.trigger("mousewheel")},unmousewheel:function(a){return this.unbind("mousewheel",a)}})});

// Parse and Format Library
//http://www.xaprb.com/blog/2005/12/12/javascript-closures-for-runtime-efficiency/
/*
 * Copyright (C) 2004 Baron Schwartz <baron at sequent dot org>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation, version 2.1.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 */
Date.parseFunctions={count:0};Date.parseRegexes=[];Date.formatFunctions={count:0};Date.prototype.dateFormat=function(b){if(b=="unixtime"){return parseInt(this.getTime()/1000);}if(Date.formatFunctions[b]==null){Date.createNewFormat(b);}var a=Date.formatFunctions[b];return this[a]();};Date.createNewFormat=function(format){var funcName="format"+Date.formatFunctions.count++;Date.formatFunctions[format]=funcName;var codePrefix="Date.prototype."+funcName+" = function() {return ";var code="";var special=false;var ch="";for(var i=0;i<format.length;++i){ch=format.charAt(i);if(!special&&ch=="\\"){special=true;}else{if(special){special=false;code+="'"+String.escape(ch)+"' + ";}else{code+=Date.getFormatCode(ch);}}}if(code.length==0){code="\"\"";}else{code=code.substring(0,code.length-3);}eval(codePrefix+code+";}");};Date.getFormatCode=function(a){switch(a){case"d":return"String.leftPad(this.getDate(), 2, '0') + ";case"D":return"Date.dayNames[this.getDay()].substring(0, 3) + ";case"j":return"this.getDate() + ";case"l":return"Date.dayNames[this.getDay()] + ";case"S":return"this.getSuffix() + ";case"w":return"this.getDay() + ";case"z":return"this.getDayOfYear() + ";case"W":return"this.getWeekOfYear() + ";case"F":return"Date.monthNames[this.getMonth()] + ";case"m":return"String.leftPad(this.getMonth() + 1, 2, '0') + ";case"M":return"Date.monthNames[this.getMonth()].substring(0, 3) + ";case"n":return"(this.getMonth() + 1) + ";case"t":return"this.getDaysInMonth() + ";case"L":return"(this.isLeapYear() ? 1 : 0) + ";case"Y":return"this.getFullYear() + ";case"y":return"('' + this.getFullYear()).substring(2, 4) + ";case"a":return"(this.getHours() < 12 ? 'am' : 'pm') + ";case"A":return"(this.getHours() < 12 ? 'AM' : 'PM') + ";case"g":return"((this.getHours() %12) ? this.getHours() % 12 : 12) + ";case"G":return"this.getHours() + ";case"h":return"String.leftPad((this.getHours() %12) ? this.getHours() % 12 : 12, 2, '0') + ";case"H":return"String.leftPad(this.getHours(), 2, '0') + ";case"i":return"String.leftPad(this.getMinutes(), 2, '0') + ";case"s":return"String.leftPad(this.getSeconds(), 2, '0') + ";case"O":return"this.getGMTOffset() + ";case"T":return"this.getTimezone() + ";case"Z":return"(this.getTimezoneOffset() * -60) + ";default:return"'"+String.escape(a)+"' + ";}};Date.parseDate=function(a,c){if(c=="unixtime"){return new Date(!isNaN(parseInt(a))?parseInt(a)*1000:0);}if(Date.parseFunctions[c]==null){Date.createParser(c);}var b=Date.parseFunctions[c];return Date[b](a);};Date.createParser=function(format){var funcName="parse"+Date.parseFunctions.count++;var regexNum=Date.parseRegexes.length;var currentGroup=1;Date.parseFunctions[format]=funcName;var code="Date."+funcName+" = function(input) {\nvar y = -1, m = -1, d = -1, h = -1, i = -1, s = -1, z = -1;\nvar d = new Date();\ny = d.getFullYear();\nm = d.getMonth();\nd = d.getDate();\nvar results = input.match(Date.parseRegexes["+regexNum+"]);\nif (results && results.length > 0) {";var regex="";var special=false;var ch="";for(var i=0;i<format.length;++i){ch=format.charAt(i);if(!special&&ch=="\\"){special=true;}else{if(special){special=false;regex+=String.escape(ch);}else{obj=Date.formatCodeToRegex(ch,currentGroup);currentGroup+=obj.g;regex+=obj.s;if(obj.g&&obj.c){code+=obj.c;}}}}code+="if (y > 0 && z > 0){\nvar doyDate = new Date(y,0);\ndoyDate.setDate(z);\nm = doyDate.getMonth();\nd = doyDate.getDate();\n}";code+="if (y > 0 && m >= 0 && d > 0 && h >= 0 && i >= 0 && s >= 0)\n{return new Date(y, m, d, h, i, s);}\nelse if (y > 0 && m >= 0 && d > 0 && h >= 0 && i >= 0)\n{return new Date(y, m, d, h, i);}\nelse if (y > 0 && m >= 0 && d > 0 && h >= 0)\n{return new Date(y, m, d, h);}\nelse if (y > 0 && m >= 0 && d > 0)\n{return new Date(y, m, d);}\nelse if (y > 0 && m >= 0)\n{return new Date(y, m);}\nelse if (y > 0)\n{return new Date(y);}\n}return null;}";Date.parseRegexes[regexNum]=new RegExp("^"+regex+"$",'i');eval(code);};Date.formatCodeToRegex=function(b,a){switch(b){case"D":return{g:0,c:null,s:"(?:Sun|Mon|Tue|Wed|Thu|Fri|Sat)"};case"j":case"d":return{g:1,c:"d = parseInt(results["+a+"], 10);\n",s:"(\\d{1,2})"};case"l":return{g:0,c:null,s:"(?:"+Date.dayNames.join("|")+")"};case"S":return{g:0,c:null,s:"(?:st|nd|rd|th)"};case"w":return{g:0,c:null,s:"\\d"};case"z":return{g:1,c:"z = parseInt(results["+a+"], 10);\n",s:"(\\d{1,3})"};case"W":return{g:0,c:null,s:"(?:\\d{2})"};case"F":return{g:1,c:"m = parseInt(Date.monthNumbers[results["+a+"].substring(0, 3)], 10);\n",s:"("+Date.monthNames.join("|")+")"};case"M":return{g:1,c:"m = parseInt(Date.monthNumbers[results["+a+"]], 10);\n",s:"(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)"};case"n":case"m":return{g:1,c:"m = parseInt(results["+a+"], 10) - 1;\n",s:"(\\d{1,2})"};case"t":return{g:0,c:null,s:"\\d{1,2}"};case"L":return{g:0,c:null,s:"(?:1|0)"};case"Y":return{g:1,c:"y = parseInt(results["+a+"], 10);\n",s:"(\\d{4})"};case"y":return{g:1,c:"var ty = parseInt(results["+a+"], 10);\ny = ty > Date.y2kYear ? 1900 + ty : 2000 + ty;\n",s:"(\\d{1,2})"};case"a":return{g:1,c:"if (results["+a+"] == 'am') {\nif (h == 12) { h = 0; }\n} else { if (h < 12) { h += 12; }}",s:"(am|pm)"};case"A":return{g:1,c:"if (results["+a+"] == 'AM') {\nif (h == 12) { h = 0; }\n} else { if (h < 12) { h += 12; }}",s:"(AM|PM)"};case"g":case"G":case"h":case"H":return{g:1,c:"h = parseInt(results["+a+"], 10);\n",s:"(\\d{1,2})"};case"i":return{g:1,c:"i = parseInt(results["+a+"], 10);\n",s:"(\\d{2})"};case"s":return{g:1,c:"s = parseInt(results["+a+"], 10);\n",s:"(\\d{2})"};case"O":return{g:0,c:null,s:"[+-]\\d{4}"};case"T":return{g:0,c:null,s:"[A-Z]{3}"};case"Z":return{g:0,c:null,s:"[+-]\\d{1,5}"};default:return{g:0,c:null,s:String.escape(b)};}};Date.prototype.getTimezone=function(){return this.toString().replace(/^.*? ([A-Z]{3}) [0-9]{4}.*$/,"$1").replace(/^.*?\(([A-Z])[a-z]+ ([A-Z])[a-z]+ ([A-Z])[a-z]+\)$/,"$1$2$3");};Date.prototype.getGMTOffset=function(){return(this.getTimezoneOffset()>0?"-":"+")+String.leftPad(Math.floor(Math.abs(this.getTimezoneOffset())/60),2,"0")+String.leftPad(Math.abs(this.getTimezoneOffset())%60,2,"0");};Date.prototype.getDayOfYear=function(){var a=0;Date.daysInMonth[1]=this.isLeapYear()?29:28;for(var b=0;b<this.getMonth();++b){a+=Date.daysInMonth[b];}return a+this.getDate();};Date.prototype.getWeekOfYear=function(){var b=this.getDayOfYear()+(4-this.getDay());var a=new Date(this.getFullYear(),0,1);var c=(7-a.getDay()+4);return String.leftPad(Math.ceil((b-c)/7)+1,2,"0");};Date.prototype.isLeapYear=function(){var a=this.getFullYear();return((a&3)==0&&(a%100||(a%400==0&&a)));};Date.prototype.getFirstDayOfMonth=function(){var a=(this.getDay()-(this.getDate()-1))%7;return(a<0)?(a+7):a;};Date.prototype.getLastDayOfMonth=function(){var a=(this.getDay()+(Date.daysInMonth[this.getMonth()]-this.getDate()))%7;return(a<0)?(a+7):a;};Date.prototype.getDaysInMonth=function(){Date.daysInMonth[1]=this.isLeapYear()?29:28;return Date.daysInMonth[this.getMonth()];};Date.prototype.getSuffix=function(){switch(this.getDate()){case 1:case 21:case 31:return"st";case 2:case 22:return"nd";case 3:case 23:return"rd";default:return"th";}};String.escape=function(a){return a.replace(/('|\\)/g,"\\$1");};String.leftPad=function(d,b,c){var a=new String(d);if(c==null){c=" ";}while(a.length<b){a=c+a;}return a;};Date.daysInMonth=[31,28,31,30,31,30,31,31,30,31,30,31];Date.monthNames=["January","February","March","April","May","June","July","August","September","October","November","December"];Date.dayNames=["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"];Date.y2kYear=50;Date.monthNumbers={Jan:0,Feb:1,Mar:2,Apr:3,May:4,Jun:5,Jul:6,Aug:7,Sep:8,Oct:9,Nov:10,Dec:11};Date.patterns={ISO8601LongPattern:"Y-m-d H:i:s",ISO8601ShortPattern:"Y-m-d",ShortDatePattern:"n/j/Y",LongDatePattern:"l, F d, Y",FullDateTimePattern:"l, F d, Y g:i:s A",MonthDayPattern:"F d",ShortTimePattern:"g:i A",LongTimePattern:"g:i:s A",SortableDateTimePattern:"Y-m-d\\TH:i:s",UniversalSortableDateTimePattern:"Y-m-d H:i:sO",YearMonthPattern:"F, Y"};
}());

(function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
var ui         = require( './../libs/ui.js' );
var imgOption  = require( './../libs/image-option.js' );
var error      = require( './../public/error.js' );
var helper     = require( './../public/helper.js' );
var imagefunc  = require( './../public/image.js' );
var videofunc  = require( './../public/video.js' );
var effectfunc = require( './../public/effect.js' );
var notefunc   = require( './../public/note.js' );
var boxfunc    = require( './../public/box.js' );
var frontfunc  = require( './../public/front.js' );

(function($)
{
  "use strict";

  $(document).ready(function()
  {
    //
    //Init ui
    ui.base.modal.prototype.top_margin = '20px';
    var modal  = new ui.base.modal();

    ui.base.loader.prototype.image_base  = ippdc_img_url;
    ui.base.loader.prototype.loader_file = 'loading.gif';
    var loader  = new ui.base.loader();
    var message = new ui.base.message();

    //
    // Build front views
    //
    frontfunc.init();

    //
    //Remodal init
    //
    $(document).on('closed', '.remodal', function (e)
    {
      var current = e.currentTarget;
      if ( $(current).attr( 'data-modal-before') != undefined )
      {
        var before = $(current).attr( 'data-modal-before');
        var inst   = $('[data-remodal-id="'+before+'"]').remodal();
        inst.open();
      }
    });

    //
    //Effect options
    //
  $( '.ippdc-effect-edit-trigger a' ).click( function()
  {
    var deco   = $(this).parents( '.ippdc-front-effect-edit' );
    var option = $( '.ippdc-effect-edit-list', deco );
    if ( option.length > 0 )
    {
      option.show();
      var height = $( '.ippdc-effect-edit-items', deco ).height();
      option.hide();
      if ( $(this).hasClass( 'active' ))
      {
        option.removeClass( 'open' );
        $(this).removeClass( 'active' );
      }
      else {
        option.show();
        option.addClass( 'open' );
        $(this).addClass( 'active' );
      }
    }
    return false;
  });

    /**
     * Image option
     */
    imagefunc.init();

    /**
     * Effect option
     */
    effectfunc.init();

    /**
     * Video option
     */
    videofunc.init();

    /**
     * Note option
     */
    notefunc.init();

    /**
     * Box option
     */
    boxfunc.init();

  });
})(jQuery);

},{"./../libs/image-option.js":2,"./../libs/ui.js":3,"./../public/box.js":4,"./../public/effect.js":5,"./../public/error.js":6,"./../public/front.js":7,"./../public/helper.js":8,"./../public/image.js":9,"./../public/note.js":10,"./../public/video.js":13}],2:[function(require,module,exports){
/*
 *===========================================================
 *  Input image option
 *===========================================================*/
var option;

(function($)
{
    "use strict";

    option = function( root, options )
    {
        var defaults  = {
            after: function( value, input ){},
        };
        var options = $.extend( defaults, options );

        root.each( function()
        {
            var input = $(this);

            $( '._item', input ).click( function()
            {
                $( '._item', input ).removeClass( '_selected' );
                var value = $(this).data( 'value' );
                $(this).addClass( '_selected' );
                $( '._value-selected', input ).val( value );
                //
                //Callback
                options.after( value, $(this), input );
                return false;
            })
        });
    };

})(jQuery);

module.exports = option;

},{}],3:[function(require,module,exports){
/*
 *===========================================================
 * UI
 *===========================================================
 */
var ui;

(function($)
{
    "use strict";

    //Inherit function
    function inherit( proto )
    {
        function F() {}
        F.prototype = proto
        return new F
    }

    /*
     *===========================================================
     * Ui prototype
     *===========================================================*/
    function ui_construct( options ){};

    ui_construct.prototype =
    {

        vars:               {},
        class_prefix:       'ippdc-',
        class_main:         '-main',
        class_title:        '-title',
        class_content:      '-content',
        class_disabled:     'disabled',
        class_close:        'ui-close',
        label_close:        'x',
        image_base:         '',

        top_margin:         '80px',
        overlay_speed:      600,
        main_speed:         400,
        show_speed:         4000,

        show_after:         function(){},
        hide_after:         function(){},

        popup_body: function( class_root, content, title, close )
        {
            var body = $( '<div class="'+class_root+'"></div>' );
            var main = $( '<div class="'+class_root + this.class_main+'"></div>' );
            if ( title )
            {
                var _title = $( '<div class="'+class_root + this.class_title+'"></div>' )
                                .append( '<h3>'+title+'</h3>' );
                if ( close )
                {
                    var _close = $( '<a href="#">'+this.label_close+'</a>' );
                    this.popup_close( _close, class_root );

                    _title.append(
                        $( '<div class="'+this.class_prefix+this.class_close+'"></div>' ).append( _close )
                    );
                }
                main.append( _title );
            }
            if ( content ) {
                main.append(
                    $( '<div class="'+class_root + this.class_content+'"></div>' ).append( content )
                );
            }
            body.append( main );
            return body;
        },
        popup_show: function( popup )
        {
            var c_root = popup.attr( 'class' );
            var main   = $( '.'+c_root+this.class_main, popup );
            popup.show();
            main.css( 'margin-top', '-40%' )
                .animate({marginTop: this.top_margin}, this.main_speed, this.show_after);
        },
        popup_hide: function( popup )
        {
            var c_root = popup.attr( 'class' );
            var main   = $( '.'+c_root+this.class_main, popup );

            popup.animate( {opacity: 0}, this.overlay_speed, function(){
                $(this).css( 'opacity', 1 )
                       .hide();
            });
            main.animate( {marginTop: '-60%'}, this.main_speed, this.hide_after);
        },
        popup_close: function( button, class_popup )
        {
            var ui = this;
            button.click( function(){
                var popup = $( '.'+class_popup );
                ui.popup_hide( popup );
                return false;
            });
        },
        is_load: function( selector )
        {
            if ( $( selector ).length > 0 ) {
                return true;
            }
            return false;
        },
        set_vars: function( options )
        {
            this.vars = $.extend(this.vars, options);
        },
        set_base_vars: function( options )
        {
            this.vars = $.extend(this, options);
        },
        go_to: function( selector )
        {
            var pos = $( selector ).position();
            $('html, body').animate({scrollTop: ( pos.top )}, 600);
            return false;
        }
    };

    /*
     * Modal Class
     **/
    function modal(){};
    modal.prototype = inherit( ui_construct.prototype );
    //Modal message
    modal.prototype.ajax = function( id, url )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_modal;
        var modal   = this.popup_body( c_root, '', false, false ).appendTo( $( 'body' ) );
        modal.addClass( class_type )
             .attr( 'id', id );

        this.popup_show( modal );
    };

    /*
     * Loader Class
     **/
    function loader(){};
    loader.prototype = inherit( ui_construct.prototype );
    //Properties
    loader.prototype.class_root     = 'ui-loader';
    loader.prototype.loader_file    = 'loading.gif';
    //Show loader
    loader.prototype.show = function()
    {
        var loader = this.create();
        this.popup_show( loader );
    };
    //Hide loader
    loader.prototype.hide = function()
    {
        var loader = this.create();
        this.popup_hide( loader );
    };
    //Create loader
    loader.prototype.create = function()
    {
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            return $( '.'+c_root );
        } else
        {
            var image  = '<img src="'+this.image_base+this.loader_file+'" alt="Loading...">';
            var loader = this.popup_body( c_root, image, false, false ).appendTo( $( 'body' ) );
            loader.hide();

            return loader;
        }
    };


    /*
     * Inline loader Class
     **/
    function iloader(){};
    iloader.prototype = inherit( ui_construct.prototype );
    //Properties
    iloader.prototype.class_root   = 'ui-inline-loader';
    iloader.prototype.loader_file  = 'spin.gif';
    //Loader show
    iloader.prototype.show = function( button )
    {
        button.attr( 'disabled', 'disabled' );
        this.create( button ).show();
    };
    //Loader hide
    iloader.prototype.hide = function( button )
    {
        button.removeAttr( 'disabled' );
        this.create( button ).hide();
    };
    //Creating loader
    iloader.prototype.create = function( button )
    {
        var root   = button.parent();
        var lclass = this.class_prefix + this.class_root;
        if ( $( '.'+lclass, root ).length > 0 ) {
            var loader = $( '.'+lclass, root );
        } else {
            var image  = '<img src="'+this.image_base+this.loader_file+'" alt="Loading...">';
            var loader = $( '<span class="'+lclass+'"></span>' )
                            .append( image )
                            .css( 'margin-left', '8px' );
        }
        button.after( loader );
        return loader;
    };


    /*
     * Confirm popup
     **/
    function confirm( options )
    {
        var defaults = {
            title:      'Confirmation',
            info:       '',
            yes_label:  'Yes',
            no_label:   'Cancel',
            yes_class:  'btn btn-danger',
            no_class:   'btn btn-success',
            action:     function( object ){}
        };
        this.vars = $.extend(defaults, options);
    };
    confirm.prototype = inherit( ui_construct.prototype );
    //Properties
    confirm.prototype.class_root = 'ui-confirm';
    //Confirm show
    confirm.prototype.show = function( object )
    {
        var confirm = this.create( object );
        this.popup_show( confirm );
    };
    //Confirm hide
    confirm.prototype.hide = function( object )
    {
        var confirm = this.create( object );
        this.popup_hide( confirm );
    };
    //Creating confirm
    confirm.prototype.create = function( object )
    {
        var ui     = this;
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            $( '.'+c_root ).remove();
        }
        //Create confirm
        var yesbtn = $( '<a href="#" class="ip-confirm-yes '+this.vars.yes_class+'">'+this.vars.yes_label+'</a>' );
        var nobtn  = $( '<a href="#" class="ip-confirm-no '+this.vars.no_class+'">'+this.vars.no_label+'</a>' );

        yesbtn.click( function(){
            ui.vars.action( object, ui );
            return false;
        });
        this.popup_close( nobtn, c_root );

        var content = $( '<div class="'+c_root+'-inner"></div>' )
            .append( '<p>'+this.vars.info+'</p>' )
            .append(
                $( '<div class="'+c_root+'-actions"></div>' )
                    .append( yesbtn )
                    .append( nobtn )
            );

        var confirm = this.popup_body( c_root, content, this.vars.title, false ).appendTo( $( 'body' ) );
        confirm.hide();

        return confirm;
    };


    /*
     * Alert popup
     **/
    function alert( options )
    {
        var defaults = {
            message:        '',
            label_button:   'Ok',
            class_root:     '',
            class_button:   'ippdc-btn ippdc-btn-sm ippdc-btn-danger',
            after:          function(){}
        };
        this.vars = $.extend(defaults, options);
    };
    alert.prototype = inherit( ui_construct.prototype );
    //Properties
    alert.prototype.class_root = 'ui-alert';
    //Alert show
    alert.prototype.show = function( message )
    {
        this.vars.message = message;
        var alert = this.create();
        this.popup_show( alert );
    };
    //Alert hide
    alert.prototype.hide = function()
    {
        var alert = this.create();
        this.hide_after = this.vars.after;
        this.popup_hide( alert );
    };
    //Creating alert
    alert.prototype.create = function()
    {
        var ui     = this;
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            return $( '.'+c_root );
        } else
        {
            var button = $( '<a href="#" class="'+this.vars.class_button+'">'+this.vars.label_button+'</a>' );
            this.popup_close( button, c_root );

            var c_info  = c_root + '-inner';
            if ( this.vars.class_root != '' ) {
                c_info += ' ' + this.vars.class_root;
            }
            var content = $( '<div class="'+c_info+'"></div>' )
                .append( '<p>'+this.vars.message+'</p>' )
                .append(
                    $( '<div class="'+c_root+'-actions"></div>' )
                        .append( button )
                );

            var popup  = this.popup_body( c_root, content, false, false ).appendTo( $( 'body' ) );
            popup.hide();

            return popup;
        }
    };


    /*
     * Message
     **/
    function message(){};
    message.prototype = inherit( ui_construct.prototype );
    //Properties
    message.prototype.class_modal = 'ui-modal-message';
    message.prototype.class_block = 'ui-message';
    //Modal message
    message.prototype.modal = function( message, class_type )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_modal;
        var content = '<p>'+message+'</p>';
        var msg     = this.popup_body( c_root, content, false, false ).appendTo( $( 'body' ) );
        msg.addClass( class_type )
           .show()
           .animate({top: "0"}, ui.overlay_speed, function(){
                var object = $( this );
                setTimeout( function(){
                    object.animate({top: '-100px'}, ui.overlay_speed, function(){
                        object.remove();
                    });
                }, ui.show_speed);
            });
    };
    //Bloack message
    message.prototype.block = function( message, class_type, block, close )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_block;
        var parent  = block.parent();

        $( '.'+c_root, parent ).remove();

        var msg = $( '<div></div>' );
        msg.addClass( c_root )
           .addClass( class_type )
           .append( '<p>'+message+'</p>' );

        if ( close )
        {
            var _close = $( '<a href="#">'+this.close_label+'</a>' );
            _close.click( function()
            {
                var _msg = $(this).parents( '.'+c_root );
                _msg.animate({opacity: "0"}, ui.overlay_speed, function(){
                    _msg.remove();
                });
                return false;
            });
            msg.append(
                $( '<div class="'+this.class_prefix+this.class_close+'"></div>' ).append( _close )
            );
        }
        msg.css( 'opacity', '0' );
        parent.prepend( msg );
        msg.animate({opacity: "1"}, ui.overlay_speed);
    };

    ui =
    {
        base: {
            construct:  ui_construct,
            loader:     loader,
            iloader:    iloader,
            confirm:    confirm,
            message:    message,
            alert:      alert,
            modal:      modal

        },
        init: function()
        {
            this.loader  = new this.base.loader(),
            this.iloader = new this.base.iloader(),
            this.confirm = new this.base.confirm(),
            this.message = new this.base.message(),
            this.alert   = new this.base.alert(),
            this.modal   = new this.base.modal()
        }
    };

})(jQuery);

module.exports = ui;

},{}],4:[function(require,module,exports){
/*
 *===========================================================
 * Box Function
 *===========================================================*/
var error      = require( './error.js' );
var helper     = require( './helper.js' );
var optionfunc = require( './option.js' );

var ippdc_box;
(function($)
{
    "use strict";

    ippdc_box =
    {
      //
      //Init
      init: function()
      {
        var self = this;

        if ( $( '#ippdc-form-box' ).length > 0 )
        {
          $( '#ippdc-form-box button[type=submit]' ).click( function()
          {
            error.resetError();

            var title   = $( '#ippdc-input-box-title' ).val();
            var label   = $( '#ippdc-input-box-button-label' ).val();
            var url     = $( '#ippdc-input-box-button-url' ).val();
            var content = $( '#ippdc-input-box-content' ).val();
            var width   = $( '#ippdc-input-box-width' ).val();
            var height  = $( '#ippdc-input-box-height' ).val();

            //check errors
            error.checkError( title, 'box_title', 'string' );
            error.checkError( label, 'box_button_label', 'string' );
            error.checkError( url, 'box_button_url', 'string' );
            error.checkError( content, 'box_content', 'string' );
            error.checkError( width, 'box_width', 'number' );
            error.checkError( height, 'box_height', 'number' );

            if ( ! error.isError() )
            {
              //Close modal
              var inst  = $('[data-remodal-id="ippcd-modal-box"]').remodal();
              inst.close();

              //Clear form
              $( '#ippdc-form-box' )[0].reset();

              //Save data
              self.saveDecoration({
                'title':        title,
                'button_label': label,
                'button_url':   url,
                'content':      content,
                'width':        width,
                'height':       height,
              });
            }
            else {
              error.showError( $(this) );
            }
            return false;
         });
        }
      },

      //
      //Save decoration
      saveDecoration: function( data )
      {
        var self = this;
        helper.saveDecoration( 'box', data, function( response )
        {
          var content = self.getBox( data, data );
          helper.addDecoration( 'box', response, content, function( option ){
            return self.buildOptions( data, response );
          });
        });
      },

      //
      //Get box
      getBox: function( data, response )
      {
        var wrapclass = 'ippdc-deco-box-main ippdc-deco-style-width ippdc-deco-style-height';
        wrapclass += ' ippdc-deco-style-bgcolor ippdc-deco-style-color ippdc-deco-style-border';

        var boxwrap = $( '<div class="' + wrapclass + '"></div>' );
        boxwrap.height( response.height );
        boxwrap.width( response.width );

        //Set style
        if ( response.bgcolor != undefined && response.bgcolor != '' ) {
          boxwrap.css( 'backgroundColor', response.bgcolor );
        }
        if ( response.color != undefined && response.color != '' ) {
          boxwrap.css( 'color', response.color );
        }
        if ( response.border_color != undefined && response.border_color != '' ) {
          boxwrap.css( 'borderColor', response.border_color );
        }
        if ( response.border_size != undefined && response.border_size != '' ) {
          boxwrap.css( 'borderWidth', response.border_size );
        }

        var boxTitle   = $( '<h3 class="ippdc-deco-box-title"></h3>' ).text( data.title );
        var boxContent = $( '<div class="ippdc-deco-box-content"></div>' ).text( data.content );
        boxTitle.appendTo( boxwrap );
        boxContent.appendTo( boxwrap );

        var wrapButton = $( '<div class="ippdc-deco-box-button"></div>' );
        var boxButton  = $( '<a class="ippdc-btn"></a>' )
                          .text( data.button_label )
                          .attr( 'href', data.button_url );

        if ( response.button_style != undefined && response.button_style != '' ) {
          boxButton.attr( 'data-style', response.button_style );
        } else {
          boxButton.attr( 'data-style', 'flat' );
        }
        if ( response.button_color != undefined && response.button_color != '' ) {
          boxButton.attr( 'data-color', response.button_color );
        } else {
          boxButton.attr( 'data-color', 'clean' );
        }

        wrapButton.append( boxButton )
                  .appendTo( boxwrap );

        return boxwrap;
      },

      //
      //Build options
      buildOptions: function( data, options )
      {
        var fields = $( '<div class="ippdc-note-fields"></div>' );
        fields.append( this.buildOptionStyle( data, options ) );
        fields.append( this.buildOptionContent( data, options ) );

        return fields;
      },

      //
      //Build option style
      buildOptionStyle: function( data, options )
      {
        var field = $( '<div id="ippdc-tab-content-style" class="ippdc-option-tab-content"></div>' );
        field.append( optionfunc.buildFieldOpacity( false ) )
             .append( optionfunc.buildFieldWidth( data.width ) )
             .append( optionfunc.buildFieldHeight( data.height ) )
             .append( optionfunc.buildFieldBgColor( false ) )
             .append( optionfunc.buildFieldColor( false ) )
             .append( optionfunc.buildFieldBorder( false ) )
             .append( this.buildFieldButton( data, options ) )
             .hide();

        return field;
      },

      //
      //Build field button
      buildFieldButton: function( data, options )
      {
        var fields = $( '<div class="ippdc-fields-button"></div>' );

        //Style
        var styles  = [
          {
            'label': 'Flat',
            'value': 'flat'
          },
          {
            'label': 'Gradient',
            'value': 'gradient'
          },
          {
            'label': 'Rounded',
            'value': 'rounded'
          }
        ];

        var style = false;
        if ( options.button_style != undefined ) {
          style = options.button_style;
        }
        var fieldStyle = optionfunc.buildFieldSelect( 'Button Style', 'button_style', styles, style, function( el )
        {
          var val  = el.val();
          var deco = el.parents( '.ippdc-deco-item' );

          if ( $( '.ippdc-deco-box-button', deco ).length > 0 ) {
            $( '.ippdc-deco-box-button .ippdc-btn', deco ).attr( 'data-style', val );
          }
        });

        //Color
        var colors  = [
          {
            'label': 'Clean',
            'value': 'clean'
          },
          {
            'label': 'Dark',
            'value': 'dark'
          },
          {
            'label': 'Red',
            'value': 'red'
          },
          {
            'label': 'Blue',
            'value': 'blue'
          },
          {
            'label': 'Orange',
            'value': 'orange'
          },
          {
            'label': 'Gold',
            'value': 'gold'
          },
          {
            'label': 'Aqua',
            'value': 'aqua'
          },
          {
            'label': 'Purple',
            'value': 'purple'
          },
          {
            'label': 'Lime',
            'value': 'lime'
          }
        ];

        var color = false;
        if ( options.button_color != undefined ) {
          color = options.button_color;
        }
        var fieldColor = optionfunc.buildFieldSelect( 'Button Color', 'button_color', colors, color, function( el )
        {
          var val  = el.val();
          var deco = el.parents( '.ippdc-deco-item' );

          if ( $( '.ippdc-deco-box-button', deco ).length > 0 ) {
            $( '.ippdc-deco-box-button .ippdc-btn', deco ).attr( 'data-color', val );
          }
        });

        fields.append( fieldStyle );
        fields.append( fieldColor );

        return fields;
      },

      //
      //Build option content
      buildOptionContent: function( data, options )
      {
        var field = $( '<div id="ippdc-tab-content-content" class="ippdc-option-tab-content"></div>' );

        //
        // Title
        field.append( optionfunc.buildFieldInput( 'Title', 'title', data.title, function(input)
          {
            var tivalue = input.val();
            var deco    = input.parents( '.ippdc-deco-item' );
            $( '.ippdc-deco-box-title', deco ).text( tivalue );
          })
        );

        //
        //Content
        field.append( optionfunc.buildFieldTextarea( 'Content', 'content', data.content, function(input)
          {
            var covalue = input.val();
            var deco    = input.parents( '.ippdc-deco-item' );
            $( '.ippdc-deco-box-content', deco ).text( covalue );
          })
        );

        //
        // Button Label
        field.append( optionfunc.buildFieldInput( 'Button Label', 'button_label', data.button_label, function(input)
          {
            var blvalue = input.val();
            var deco    = input.parents( '.ippdc-deco-item' );
            $( '.ippdc-deco-box-button .ippdc-btn', deco ).text( blvalue );
          })
        );

        //
        // Button URL
        field.append( optionfunc.buildFieldInput( 'Button URL', 'button_url', data.button_url, function(input)
          {
            var blvalue = input.val();
            var deco    = input.parents( '.ippdc-deco-item' );
            $( '.ippdc-deco-box-button .ippdc-btn', deco ).attr( 'href', blvalue );
          })
        );

        field.hide();

        return field;
      }
    };

})(jQuery);

module.exports = ippdc_box;

},{"./error.js":6,"./helper.js":8,"./option.js":11}],5:[function(require,module,exports){
/*
 *===========================================================
 * Effect Function
 *===========================================================*/
var error       = require( './error.js' );
var helper      = require( './helper.js' );
var optionfunc  = require( './option.js' );

var ippdc_effect;
(function($)
{
    "use strict";

    ippdc_effect =
    {
      //
      //Init
      init: function()
      {
        var self = this;

        if ( $( '#ippdc-form-bg-effect' ).length > 0 )
        {
          $( '#ippdc-form-bg-effect button[type=submit]' ).click( function()
          {
            error.resetError();

            var type  = $( '#ippdc-input-effect-type' ).val();
            var color = $( '#ippdc-input-effect-color' ).val();

            //check errors
            error.checkError( type, 'effect_type', 'string' );
            error.checkError( color, 'effect_color', 'string' );

            if ( ! error.isError() )
            {
              //
              //Check effect
              // if ( $('body').hasClass( 'ippdc-snow-on' ) )
              // {
              //   var inst  = $('[data-remodal-id="ippcd-modal-ready"]').remodal();
              //   inst.open();
              //   return false;
              // }

              //
              //Close modal
              var inst  = $('[data-remodal-id="ippcd-modal-effect"]').remodal();
              inst.close();

              //Save data
              self.saveDecoration({
                'effect_type':   type,
                'effect_color':  color
              });
            }
            else {
              error.showError( $(this) );
            }
            return false;
          });


          $( '.ippdc-effect-ready-yes' ).click( function()
          {
            var type  = $( '#ippdc-input-effect-type' ).val();
            var color = $( '#ippdc-input-effect-color' ).val();

            //
            //Close modal
            var inst  = $('[data-remodal-id="ippcd-modal-ready"]').remodal();
            inst.close();

            //Save data
            self.saveDecoration({
              'effect_type':   type,
              'effect_color':  color,
            });
            return false;
          });
        }
      },

      //
      //Save decoration
      saveDecoration: function( data )
      {
        var self = this;
        helper.saveDecoration( 'effect', data, function( response )
        {
          self.getEffect( data, response );

          if ( ippdc_isLogin ) {
            self.buildOptions( data, response );
          }
        });
      },

      //
      //Get effect
      getEffect: function( data, options )
      {
        if ( options.decoid != undefined )
        {
          var decoitem = $( '.ippdc-front-deco[data-id="'+options.decoid+'"]' );
          if ( decoitem.length < 1 )
          {
            var decoitem = $( '<div class="ippdc-front-deco"></div>' )
                            .attr( 'data-id', options.decoid )
                            .attr( 'data-type', 'effect' )
                            .hide();

            var decosett = $( '<div class="ippdc-front-deco-settings"></div>' )
                            .attr( 'data-type', data.effect_type )
                            .attr( 'data-color', data.effect_color );

            decoitem.append( decosett );
            $( '.ippdc-front' ).append( decoitem );
          }
        }

        var snowColor   = this.getEffectColor( data.effect_color );
        var snowOptions = {};
        if ( data.effect_type == 'snow' )
        {
          snowOptions = {
            flakeCount : 30,
            flakeColor: snowColor,
            round : true,
            minSize: 6,
            maxSize: 10
          }
        }
        else if ( data.effect_type == 'snowflake' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'snowflake_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        else if ( data.effect_type == 'star' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'star_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        else if ( data.effect_type == 'leaf' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'leaf_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        else if ( data.effect_type == 'hexagon' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'hexagonal_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        else if ( data.effect_type == 'droplet' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'droplet_' + data.effect_color + '.svg',
            minSize: 5,
            maxSize: 30
          }
        }
        else if ( data.effect_type == 'sun' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'sun_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        else if ( data.effect_type == 'cloud' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'cloud_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        $('body').addClass( 'ippdc-snow-on' );
        $('body').snowfall( snowOptions );
      },

      //
      //Get effect color
      getEffectColor: function( color )
      {
        var hex = '#ffffff';
        if ( color == 'black' ) {
          hex = '#000000';
        }
        else if ( color == 'blue' ) {
          hex = '#2f74e7';
        }
        else if ( color == 'light_blue' ) {
          hex = '#20d0d6';
        }
        else if ( color == 'red' ) {
          hex = '#e43333';
        }
        else if ( color == 'green' ) {
          hex = '#72c462';
        }
        else if ( color == 'orange' ) {
          hex = '#e59547';
        }
        else if ( color == 'yellow' ) {
          hex = '#ffcd50';
        }
        return hex;
      },

      //
      //Rebuild effects
      rebuild: function( options )
      {
        var self = this;
        $( '.ippdc-front-deco[data-type="effect"]' ).each( function()
        {
          var item = $(this);
          var datasett = $( '.ippdc-front-deco-settings', item );

          //Effect Color
          var dataColor = datasett.data( 'color' );
          if ( dataColor != undefined && dataColor != '' ) {
            buildOpts.effect_color = dataColor;
          }

          //Effect Type
          var dataType = datasett.data( 'type' );
          if ( dataType != undefined && dataType != '' ) {
            buildOpts.effect_type = dataType;
          }

          self.getEffect( buildOpts, buildOpts );
        });
      },

      //
      //Build options
      buildOptions: function( options, response )
      {
        var self  = this;
        var wrap  = $( '<li class="ipddc-deco-effect-item ippdc-deco-action-trigger ippdc-clear"></li>' );
        wrap.attr( 'data-id', response.decoid )
            .attr( 'data-type', 'effect' );

        var item  = $( '<div class="ipddc-effect-item"></div>' );
        var label = $( '<div class="ipddc-effect-label"></div>' );
        label.text( options.effect_type + ' | ' + options.effect_color );
        item.append( label );

        var edit    = $( '<div class="ipddc-effect-edit"></div>' );
        var editBtn = $( '<a href="#" class="ipddc-effect-edit-btn"></a>' );
        editBtn.html( '<i class="ippdc-fa ippdc-fa-pencil"></i>' );
        editBtn.click( function()
        {
          var deco   = $(this).parents( '.ipddc-deco-effect-item' );
          var option = $( '.ippdc-deco-option', deco );
          if ( option.length > 0 )
          {
            var height = $( '.ippdc-deco-content', deco ).height();
            option.css( 'top', height+20+'px' );
            if ( $(this).hasClass( 'active' ))
            {
              option.removeClass( 'open' );
              $(this).removeClass( 'active' );
            }
            else {
              option.show();
              option.addClass( 'open' );
              $(this).addClass( 'active' );
            }
          }
          return false;
        });
        item.append( edit.append( editBtn ) );
        var options = optionfunc.build( 'effect', options, function()
        {
          return self.buildOptionStyle( options );
        });
        wrap.append( item );
        wrap.append( options );

        //Insert to wrapper
        $( '.ippdc-front-effect-edit .ippdc-effect-edit-items' ).append( wrap );
        $( '.ippdc-front-effect-edit' ).show();

        return wrap;
      },

      //
      //Build option style
      buildOptionStyle: function( options )
      {
        var field = $( '<div id="ippdc-tab-content-style" class="ippdc-option-tab-content"></div>' );
        field.append( this.buildFieldType( options.effect_type ) )
             .append( this.buildFieldColor( options.effect_color ) )
             .hide();

        return field;
      },

      //
      //Build field type
      buildFieldType: function( value )
      {
        var self    = this;
        var options = [
          {
            'label': 'Snow',
            'value': 'snow'
          },
          {
            'label': 'Snowflake',
            'value': 'snowflake'
          },
          {
            'label': 'Star',
            'value': 'star'
          },
          {
            'label': 'Leaf',
            'value': 'leaf'
          },
          {
            'label': 'Hexagon',
            'value': 'hexagon'
          },
          {
            'label': 'Run',
            'value': 'sun'
          },
          {
            'label': 'Cloud',
            'value': 'cloud'
          },
          {
            'label': 'Droplet of Water',
            'value': 'droplet'
          }
        ];
        //
        // Type
        var type = false;
        if ( value ) {
          type = value;
        }
        var fieldType = optionfunc.buildFieldSelect( 'Type', 'effect_type', options, type, function( el )
        {
          var type = el.val();
          var deco = el.parents( '.ippdc-deco-action-trigger' );
          self.changeField( deco, 'type', type );
        });

        return fieldType;
      },

      //
      //Build field color
      buildFieldColor: function( value )
      {
        var self    = this;
        var options = [
          {
            'label': 'White',
            'value': 'white'
          },
          {
            'label': 'Black',
            'value': 'black'
          },
          {
            'label': 'Blue',
            'value': 'blue'
          },
          {
            'label': 'Light Blue',
            'value': 'light_blue'
          },
          {
            'label': 'Red',
            'value': 'red'
          },
          {
            'label': 'Green',
            'value': 'green'
          },
          {
            'label': 'Orange',
            'value': 'orange'
          },
          {
            'label': 'Yellow',
            'value': 'yellow'
          }
        ];

        var color = false;
        if ( value ) {
          color = value;
        }
        var fieldColor = optionfunc.buildFieldSelect( 'Color', 'effect_color', options, color, function( el )
        {
          var color = el.val();
          var deco  = el.parents( '.ippdc-deco-action-trigger' );
          self.changeField( deco, 'color', color );
        });

        return fieldColor;
      },

      //
      //Change fields
      changeField: function( deco, name, value )
      {
        var decoid   = deco.data( 'id' );
        var decoitem = $( '.ippdc-front-deco[data-id="'+decoid+'"]' );

        if ( decoitem.length > 0 )
        {
          var decosett = $( '.ippdc-front-deco-settings', decoitem );
          decosett.attr( 'data-'+name, value );

          //Change label
          var color = decosett.attr( 'data-color' );
          var type  = decosett.attr( 'data-type' );

          $( '.ipddc-effect-label', deco ).text( type + ' | ' + color );
        }
        this.rebuildEffect({
          decoid: decoid
        });
      },
      //
      //Rebuild effect
      rebuildEffect: function( options )
      {
        var self = this;

        $( 'body' ).snowfall('clear');

        $( '.ippdc-front-deco[data-type="effect"]' ).each( function()
        {
          var item = $(this);
          var datasett = $( '.ippdc-front-deco-settings', item );
          var buildOpts = {};

          //Effect Color
          var dataColor = datasett.attr( 'data-color' );
          if ( dataColor != undefined && dataColor != '' ) {
            buildOpts.effect_color = dataColor;
          }

          //Effect Type
          var dataType = datasett.attr( 'data-type' );
          if ( dataType != undefined && dataType != '' ) {
            buildOpts.effect_type = dataType;
          }

          self.getEffect( buildOpts, options );
        });
      }
    };

})(jQuery);

module.exports = ippdc_effect;

},{"./error.js":6,"./helper.js":8,"./option.js":11}],6:[function(require,module,exports){
/*
 *===========================================================
 * Error handler Function
 *===========================================================*/
var ippdc_error;
(function($)
{
    "use strict";

    ippdc_error =
    {
      errorCount: 0,

      //
      //resetError
      resetError: function()
      {
        this.errorCount = 0;
        $( '.ippdc-remodal-error .ippdc-error-messages' ).html( '' );
      },

      //
      //isError
      isError: function()
      {
        if ( this.errorCount > 0 ) {
          return true;
        }
        return false;
      },

      //
      //showError
      showError: function( button )
      {
        var modalId = button.parents( '.ippdc-remodal' ).attr( 'data-remodal-id' );
        if ( this.errorCount > 0 )
        {
          $('[data-remodal-id="ippcd-modal-error"]').attr( 'data-modal-before', modalId );
          var inst  = $('[data-remodal-id="ippcd-modal-error"]').remodal();
          inst.open();
        }
      },

      //
      //checkError
      checkError: function( value, name, type )
      {
        var isError = false;
        var message = '';

        if ( type == 'number' )
        {
          if ( value < 1 ) {
            isError = true;
            message = this.getMessage( name );
          }
        }
        else
        {
          if ( value == '' || value == ' ' ) {
            isError = true;
            message = this.getMessage( name );
          }
        }

        if ( isError )
        {
          this.errorCount++;
          $( '.ippdc-remodal-error .ippdc-error-messages' ).append( '<li>' + message + '</li>' );
        }
      },

      //
      //getMessage
      getMessage: function( name )
      {
        var message = '';
        if ( ippdc_messages[name] != undefined ) {
          message = ippdc_messages[name];
        }
        return message;
      }
    };

})(jQuery);

module.exports = ippdc_error;

},{}],7:[function(require,module,exports){
/*
 *===========================================================
 * Front Function
 *===========================================================*/
var errorfunc     = require( './error.js' );
var helperfunc    = require( './helper.js' );
var positionfunc  = require( './position.js' );
var imagefunc     = require( './image.js' );
var notefunc      = require( './note.js' );
var boxfunc       = require( './box.js' );
var videofunc     = require( './video.js' );
var effectfunc    = require( './effect.js' );

var ippdc_front;
(function($)
{
    "use strict";

    helperfunc.isFront = true;

    ippdc_front =
    {
      //
      //Init
      init: function()
      {
        var self = this;

        if ( $( '.ippdc-front-deco' ).length > 0 )
        {
          $( '.ippdc-front-deco' ).each( function()
          {
            var deco     = $(this);
            var type     = deco.data( 'type' );
            var datasett = $( '.ippdc-front-deco-settings', deco );

            //
            //Build options
            var buildOpts = {};
            buildOpts.decoid = deco.data( 'id' );

            buildOpts = self.getPositionOptions( datasett, buildOpts );
            buildOpts = self.getBasicStyleOptions( datasett, buildOpts );
            buildOpts = self.getDurationOptions( datasett, buildOpts );

            //
            //Image
            //
            if ( type == 'image' )
            {
              var imgdata = $( '.ippdc-front-deco-image', deco );
              var imgOpts = {};
              imgOpts.image      = imgdata.data( 'src' );
              imgOpts.image_type = imgdata.data( 'imagetype' );

              var content = imagefunc.getImage( imgOpts, buildOpts );
              helperfunc.addDecoration( 'image', buildOpts, content, function( option ){
                return imagefunc.buildOptions( option );
              });
            }
            //
            //Note
            //
            else if ( type == 'note' )
            {
              var content  = $( '.ippdc-front-deco-note-content', deco ).text();

              var noteOpts = {};
              noteOpts.content  = content;
              buildOpts.content = content;

              buildOpts   = self.getNoteOptions( datasett, buildOpts );

              var content = notefunc.getNote( noteOpts, buildOpts );
              helperfunc.addDecoration( 'note', buildOpts, content, function( option ){
                return notefunc.buildOptions( noteOpts, option );
              });
            }
            //
            //Box
            //
            else if ( type == 'box' )
            {
              var content = $( '.ippdc-front-deco-box-content', deco ).text();
              var title   = $( '.ippdc-front-deco-box-title', deco ).text();
              var label   = $( '.ippdc-front-deco-box-button', deco ).text();
              var url     = $( '.ippdc-front-deco-box-button', deco ).attr( 'href' );

              var boxOpts = {};
              boxOpts.content      = content;
              boxOpts.title        = title;
              boxOpts.button_label = label;
              boxOpts.button_url   = url;

              buildOpts   = self.getBoxOptions( datasett, buildOpts );

              var content = boxfunc.getBox( boxOpts, buildOpts );
              helperfunc.addDecoration( 'box', buildOpts, content, function( option ){
                return boxfunc.buildOptions( boxOpts, buildOpts );
              });
            }
            //
            //video
            //
            else if ( type == 'video' )
            {
              var id       = $( '.ippdc-front-deco-video', deco ).attr( 'data-id' );
              var autoplay = $( '.ippdc-front-deco-video', deco ).attr( 'data-autoplay' );

              var videoOpts = {};
              videoOpts.video_id  = id;
              videoOpts.autoplay  = autoplay;

              var content = videofunc.getVideo( videoOpts, buildOpts );
              helperfunc.addDecoration( 'video', buildOpts, content, function( option ){
                return videofunc.buildOptions( videoOpts, buildOpts );
              });
            }
            //
            //Effect
            //
            else if ( type == 'effect' )
            {
              //Effect Color
              var dataColor = datasett.data( 'color' );
              if ( dataColor != undefined && dataColor != '' ) {
                buildOpts.effect_color = dataColor;
              }

              //Effect Type
              var dataType = datasett.data( 'type' );
              if ( dataType != undefined && dataType != '' ) {
                buildOpts.effect_type = dataType;
              }

              effectfunc.getEffect( buildOpts, buildOpts );

              if ( ippdc_isLogin ) {
                effectfunc.buildOptions( buildOpts, buildOpts );
              }
            }
          })
        }
      },

      //
      //Get position options
      getPositionOptions: function( datasett, buildOpts )
      {
        var self = this;

        //Top
        var dataTop = datasett.data( 'top' );
        if ( dataTop != undefined && dataTop != '' ) {
          buildOpts.top = dataTop;
        }

        //Left
        var dataLeft = datasett.data( 'left' );
        if ( dataLeft != undefined && dataLeft != '' ) {
          buildOpts.left = dataLeft;
        }

        //Z-Index
        var dataZindex = datasett.data( 'zindex' );
        if ( dataZindex != undefined && dataZindex != '' ) {
          buildOpts.zindex = dataZindex;
        }

        //Pos helper
        var dataHelper = datasett.data( 'poshelper' );
        if ( dataHelper != undefined && dataHelper != '' ) {
          buildOpts.poshelper = dataLeft;
        }

        return buildOpts;
      },

      //
      //Get basic style options
      getBasicStyleOptions: function( datasett, buildOpts )
      {
        var self = this;

        //Height
        var dataHeight = datasett.data( 'height' );
        if ( dataHeight != undefined && dataHeight != '' ) {
          buildOpts.height = dataHeight;
        }

        //Width
        var dataWidth = datasett.data( 'width' );
        if ( dataWidth != undefined && dataWidth != '' ) {
          buildOpts.width = dataWidth;
        }

        //Opacity
        var dataOpacity = datasett.data( 'opacity' );
        if ( dataOpacity != undefined && dataOpacity != '' ) {
          buildOpts.opacity = dataOpacity;
        }

        return buildOpts;
      },

      //
      //Get duration options
      getDurationOptions: function( datasett, buildOpts )
      {
        var self = this;

        //Date Start
        var dataStart = datasett.data( 'start' );
        if ( dataStart != undefined && dataStart != '' ) {
          buildOpts.start = dataStart;
        }

        //Date End
        var dataEnd = datasett.data( 'end' );
        if ( dataEnd != undefined && dataEnd != '' ) {
          buildOpts.end = dataEnd;
        }

        return buildOpts;
      },

      //
      //Get note options
      getNoteOptions: function( datasett, buildOpts )
      {
        var self = this;

        //Background color
        var bgcolor = datasett.data( 'bgcolor' );
        if ( bgcolor != undefined && bgcolor != '' ) {
          buildOpts.bgcolor = bgcolor;
        }
        //Color
        var color = datasett.data( 'color' );
        if ( color != undefined && color != '' ) {
          buildOpts.color = color;
        }
        //border Color
        var bocolor = datasett.data( 'bordercolor' );
        if ( bocolor != undefined && bocolor != '' ) {
          buildOpts.border_color = bocolor;
        }
        //border size
        var bosize = datasett.data( 'bordersize' );
        if ( bosize != undefined && bosize != '' ) {
          buildOpts.border_size = bosize;
        }

        return buildOpts;
      },

      //
      //Get box options
      getBoxOptions: function( datasett, buildOpts )
      {
        var self = this;

        //Background color
        var bgcolor = datasett.data( 'bgcolor' );
        if ( bgcolor != undefined && bgcolor != '' ) {
          buildOpts.bgcolor = bgcolor;
        }
        //Color
        var color = datasett.data( 'color' );
        if ( color != undefined && color != '' ) {
          buildOpts.color = color;
        }
        //border Color
        var bocolor = datasett.data( 'bordercolor' );
        if ( bocolor != undefined && bocolor != '' ) {
          buildOpts.border_color = bocolor;
        }
        //border size
        var bosize = datasett.data( 'bordersize' );
        if ( bosize != undefined && bosize != '' ) {
          buildOpts.border_size = bosize;
        }
        //button style
        var btnstyle = datasett.data( 'btnstyle' );
        if ( btnstyle != undefined && btnstyle != '' ) {
          buildOpts.button_style = btnstyle;
        }
        //button color
        var btncolor = datasett.data( 'btncolor' );
        if ( btncolor != undefined && btncolor != '' ) {
          buildOpts.button_color = btncolor;
        }

        return buildOpts;
      }
    };

})(jQuery);

module.exports = ippdc_front;

},{"./box.js":4,"./effect.js":5,"./error.js":6,"./helper.js":8,"./image.js":9,"./note.js":10,"./position.js":12,"./video.js":13}],8:[function(require,module,exports){
/*
 *===========================================================
 * Helper Function
 *===========================================================*/
var optionfunc   = require( './option.js' );
var positionfunc = require( './position.js' );

var ippdc_helper;
(function($)
{
    "use strict";

    ippdc_helper =
    {
      isFront: false,

      //
      //Save decoration
      saveDecoration: function( type, data, successCallback )
      {
        //
        //Show loader
        var loader = $('[data-remodal-id="ippcd-modal-loader"]').remodal();
        loader.open();

        var self    = this;
        var ajaxUrl = ippdc_ajaxurl + '?doajax=1&ippdc=1&action=save_decoration&type=' + type;
        ajaxUrl += '&page_type=' + ippdc_typePage + '&postid=' + ippdc_postId;

        $.ajax({
          url: ajaxUrl,
          type: "POST",
          dataType: "json",
          data: data,
          success: function ( response )
          {
            successCallback( response );
            //
            //Hide loader
            loader.close();
          }
        });
      },
      //
      //Add decoration
      addDecoration: function( type, options, content, optionCallback )
      {
        var itclass = 'ippdc-deco-item ippdc-deco-action-trigger ippdc-deco-'+type;
        if ( ippdc_isLogin ) {
          itclass += ' ippdc-islogin';
        }
        var item    = $( '<div class="' + itclass + '"></div>' )
                      .attr( 'data-id', options.decoid )
                      .attr( 'data-type', type );

        var inner    = $( '<div class="ippdc-deco-inner"></div>' );
        var decomain = this.getDecorationContent( content );

        inner.append( decomain );
        if ( ippdc_isLogin )
        {
          var option = optionfunc.build( type, options, optionCallback );
          inner.append( option );
        }
        inner.appendTo( item );

        if ( ippdc_isLogin )
        {
          //
          //Set draggable
          item.draggable({
            handle: ".ippdc-deco-action-move",
            span: false,
            cursorAt: {
              top: -10,
              left: -10
            },
            drag: function( event, ui )
            {
              var top    = ui.position.top;
              var left   = ui.position.left;

              item.find( 'input[name="top"]' ).val( top );
              item.find( 'input[name="left"]' ).val( left );
            },
            stop: function( event, ui )
            {
              var top    = ui.position.top;
              var left   = ui.position.left;
              var decoId = item.attr( 'data-id' );

              item.find( 'input[name="top"]' ).val( top );
              item.find( 'input[name="left"]' ).val( left );

              //Save position
              var saveData = {
                'deco_id': decoId,
                'top':     top,
                'left':    left
              };
              var ajaxUrl = ippdc_ajaxurl + '?doajax=1&ippdc=1&action=save_decoration&type=' + type;
              ajaxUrl += '&page_type=' + ippdc_typePage + '&postid=' + ippdc_postId;

              $.ajax({
                url: ajaxUrl,
                type: "POST",
                dataType: "json",
                data: saveData,
                success: function ( response ){}
              });
            }
          });
        }

        //
        //Set options
        this.setStyleOptions( item, options );

        //Positioning item in top center
        positionfunc.isFront = this.isFront;
        if ( options.top != undefined && options.left != undefined ) {
          positionfunc.setPositionManual( options.top, options.left, item );
        }
        else {
          positionfunc.setPositionManual( '50', 'center', item );
        }

        $( 'body' ).append( item );
      },
      //
      //Get decoration content
      getDecorationContent: function( content )
      {
        var main    = $( '<div class="ippdc-deco-main"></div>' );
        var cowrap  = $( '<div class="ippdc-deco-content ippdc-deco-style-opacity"></div>' ).append( content );

        if ( ippdc_isLogin ) {
          var actions = this.getDecorationActions();
          main.append( actions );
        }
        main.append( cowrap );

        return main;
      },
      //
      //Get decoration actions
      getDecorationActions: function()
      {
        var actmove = this.getDecorationActionMove();
        var actedit = this.getDecorationActionEdit();
        var actions = $( '<div class="ippdc-deco-actions"></div>' )
                        .append( actmove )
                        .append( actedit );
        return actions;
      },
      //
      //Get decoration action move
      getDecorationActionMove: function()
      {
        var actmove = $( '<a class="ippdc-deco-action ippdc-deco-action-move" href="#"></a>' );
        actmove.html( '<span><i class="ippdc-fa ippdc-fa-arrows"></i></span>' );
        return actmove;
      },
      //
      //Get decoration action edit
      getDecorationActionEdit: function()
      {
        var actedit = $( '<a class="ippdc-deco-action ippdc-deco-action-edit" href="#"></a>' );
        actedit.html( '<span><i class="ippdc-fa ippdc-fa-pencil"></i></span>' );

        //event click
        actedit.click( function()
        {
          var deco   = $(this).parents( '.ippdc-deco-item' );
          var option = $( '.ippdc-deco-option', deco );
          if ( option.length > 0 )
          {
            var height = $( '.ippdc-deco-content', deco ).height();
            option.css( 'top', height+20+'px' );
            if ( $(this).hasClass( 'active' ))
            {
              option.removeClass( 'open' );
              $(this).removeClass( 'active' );
            }
            else {
              option.show();
              option.addClass( 'open' );
              $(this).addClass( 'active' );
            }
          }
          return false;
        });

        return actedit;
      },

      //
      //Set style options
      setStyleOptions: function( item, options )
      {
        //
        //Width
        if ( options.width != undefined && options.width != 0 && options.width != '0' && options.width != '' )
        {
          item.find( '.ippdc-deco-style-width' ).css( 'width', options.width );
        }
        //
        //Height
        if ( options.height != undefined && options.height != 0 && options.height != '0' && options.height != '' )
        {
          item.find( '.ippdc-deco-style-height' ).css( 'height', options.height );
        }
        //
        //Opacity
        if ( options.opacity != undefined && options.opacity != 0 && options.opacity != '0' && options.opacity != '' )
        {
          item.find( '.ippdc-deco-style-opacity' ).css( 'opacity', options.opacity );
        }
        //
        //Z-Index
        if ( options.zindex != undefined && options.zindex != 0 && options.zindex != '0' && options.zindex != '' )
        {
          item.css( 'z-index', options.zindex );
        }
      }
    };

})(jQuery);

module.exports = ippdc_helper;

},{"./option.js":11,"./position.js":12}],9:[function(require,module,exports){
/*
 *===========================================================
 * Image Function
 *===========================================================*/
var imgOption  = require( './../libs/image-option.js' );
var helper     = require( './helper.js' );
var optionfunc = require( './option.js' );

var ippdc_image;
(function($)
{
    "use strict";

    ippdc_image =
    {
      //
      //init
      init: function()
      {
        var self = this;

        if ( $( '.ippdc-images-list' ).length > 0 ) {
          imgOption( $( '.ippdc-images-list' ), {
            after: function( value, item, input )
            {
              var type = item.data( 'type' );

              //Close modal
              var inst = $('[data-remodal-id="ippcd-modal-image"]').remodal();
              inst.close();

              //Save data
              self.saveDecoration({
                'image_type':  type,
                'image'     : value,
              });
            }
          });
        }
      },

      //
      //Save decoration
      saveDecoration: function( data )
      {
        var self = this;

        helper.saveDecoration( 'image', data, function( response )
        {
          var content = self.getImage( data, response );
          helper.addDecoration( 'image', response, content, function( option ){
            return self.buildOptions( option );
          });
        });
      },

      //
      //Build options
      buildOptions: function( option )
      {
        var fields = $( '<div class="ippdc-image-fields"></div>' );
        fields.append( this.buildOptionStyle( option ) );

        return fields;
      },

      //
      //Build option style
      buildOptionStyle: function( option )
      {
        var field = $( '<div id="ippdc-tab-content-style" class="ippdc-option-tab-content"></div>' );
        field.append( optionfunc.buildFieldOpacity( false ) )
             .append( optionfunc.buildFieldWidth( false ) )
             .append( optionfunc.buildFieldHeight( false ) )
             .hide();

        return field;
      },

      //
      //Get image
      getImage: function( data, response )
      {
        var imgurl  = '';
        if ( data.image_type == 'attachment' ) {
          imgurl  = ippdc_upload_url + data.image;
        } else {
          imgurl  = ippdc_deco_img_url + data.image;
        }
        var imgwrap = $( '<div class="ippdc-deco-image-main"></div>' );
        var image   = $( '<img class="ippdc-deco-style-width ippdc-deco-style-height" alt="" />' );
        image.attr( 'src', imgurl )
             .appendTo( imgwrap );

        return imgwrap;
      }
    };

})(jQuery);

module.exports = ippdc_image;

},{"./../libs/image-option.js":2,"./helper.js":8,"./option.js":11}],10:[function(require,module,exports){
/*
 *===========================================================
 * Note Function
 *===========================================================*/
var error      = require( './error.js' );
var helper     = require( './helper.js' );
var optionfunc = require( './option.js' );

var ippdc_note;
(function($)
{
    "use strict";

    ippdc_note =
    {
      //
      //Init
      init: function()
      {
        var self = this;

        if ( $( '#ippdc-form-note' ).length > 0 )
        {
          $( '#ippdc-form-note button[type=submit]' ).click( function()
          {
            error.resetError();

            var content = $( '#ippdc-input-note-content' ).val();
            var width   = $( '#ippdc-input-note-width' ).val();
            var height  = $( '#ippdc-input-note-height' ).val();

            //check errors
            error.checkError( content, 'note_content', 'string' );
            error.checkError( width, 'note_width', 'number' );
            error.checkError( height, 'note_height', 'number' );

            if ( ! error.isError() )
            {
              //Close note
              var inst  = $('[data-remodal-id="ippcd-modal-note"]').remodal();
              inst.close();

              //Clear form
              $( '#ippdc-form-note' )[0].reset();

              //Save data
              self.saveDecoration({
                'content':   content,
                'width':     width,
                'height':    height,
              });
            }
            else {
              error.showError( $(this) );
            }
            return false;
          });
        }
      },

      //
      //Save decoration
      saveDecoration: function( data )
      {
        var self = this;

        helper.saveDecoration( 'note', data, function( response )
        {
          var content = self.getNote( data, data );
          helper.addDecoration( 'note', response, content, function( option ){
            return self.buildOptions( data, option );
          });
        });
      },

      //
      //Get note
      getNote: function( data, response )
      {
        var wrapclass = 'ippdc-deco-note-main ippdc-deco-style-width ippdc-deco-style-height';
        wrapclass += ' ippdc-deco-style-bgcolor ippdc-deco-style-color ippdc-deco-style-border';

        var notewrap = $( '<div class="' + wrapclass + '"></div>' );
        notewrap.height( response.height );
        notewrap.width( response.width );

        //Set style
        if ( response.bgcolor != undefined && response.bgcolor != '' ) {
          notewrap.css( 'backgroundColor', response.bgcolor );
        }
        if ( response.color != undefined && response.color != '' ) {
          notewrap.css( 'color', response.color );
        }
        if ( response.border_color != undefined && response.border_color != '' ) {
          notewrap.css( 'borderColor', response.border_color );
        }
        if ( response.border_size != undefined && response.border_size != '' ) {
          notewrap.css( 'borderWidth', response.border_size );
        }

        var noteContent = $( '<div class="ippdc-deco-note-content"></div>' ).text( data.content );
        noteContent.appendTo( notewrap );

        return notewrap;
      },

      //
      //Build options
      buildOptions: function( data, option )
      {
        var fields = $( '<div class="ippdc-note-fields"></div>' );
        fields.append( this.buildOptionStyle( data, option ) );
        fields.append( this.buildOptionContent( data, option ) );

        return fields;
      },

      //
      //Build option style
      buildOptionStyle: function( data, option )
      {
        var field = $( '<div id="ippdc-tab-content-style" class="ippdc-option-tab-content"></div>' );
        field.append( optionfunc.buildFieldOpacity( false ) )
             .append( optionfunc.buildFieldWidth( data.width ) )
             .append( optionfunc.buildFieldHeight( data.height ) )
             .append( optionfunc.buildFieldBgColor( false ) )
             .append( optionfunc.buildFieldColor( false ) )
             .append( optionfunc.buildFieldBorder( false ) )
             .hide();

        return field;
      },
      //
      //Build option content
      buildOptionContent: function( data, option )
      {
        var field = $( '<div id="ippdc-tab-content-content" class="ippdc-option-tab-content"></div>' );
        field.append( optionfunc.buildFieldTextarea( 'Content', 'content', data.content, function(input)
          {
            var covalue = input.val();
            var deco    = input.parents( '.ippdc-deco-item' );
            $( '.ippdc-deco-note-content', deco ).text( covalue );
          })
        ).hide();

        return field;
      }
    };

})(jQuery);

module.exports = ippdc_note;

},{"./error.js":6,"./helper.js":8,"./option.js":11}],11:[function(require,module,exports){
/*
 *===========================================================
 * Option builder Function
 *===========================================================*/
var positionfunc = require( './position.js' );

var ippdc_option;
(function($)
{
    "use strict";

    ippdc_option =
    {
      root: null,
      type: '',
      options: null,

      //
      //Build option
      build: function( type, options, optionCallback )
      {
        this.type    = type;
        this.options = options;

        var wrapper = $( '<div class="ippdc-deco-option" style="display:none;"></div>' );
        var inner   = $( '<div class="ippdc-option-inner"></div>' );
        var form    = $( '<form action="#" method="post"></form>' );

        //Add header
        var header = this.buildHeader();
        form.append( header );

        //Add main content
        var main = this.buildMain( optionCallback );
        form.append( main );

        //Add footer content
        var footer = this.buildFooter();
        form.append( footer );

        //Active first tab
        var firstTab = form.find( '.ippdc-tab-menu:first-child a' );

        if ( firstTab.length > 0 )
        {
          firstTab.addClass( 'active' );
          var href   = firstTab.attr( 'href' );
          var target = form.find( href );
          if ( target.length > 0 ) {
            target.show();
          }
        }

        form.appendTo( inner );
        inner.appendTo( wrapper );
        this.root = wrapper;

        return this.root;
      },

      //
      //Build header
      buildHeader: function()
      {
        var header = $( '<div class="ippdc-option-header"></div>' );
        var inner  = $( '<div class="ippdc-header-inner ippdc-clear"></div>' );

        var titleText = this.getTitleText();
        var title = $( '<div class="ippdc-option-title"></div>' );
        title.text( titleText );
        inner.append( title );

        var tab = this.buildTab();
        inner.append( tab );

        var close = this.buildOptionClose();
        inner.append( close );

        inner.appendTo( header );
        return header;
      },

      //
      //Get title text
      getTitleText: function()
      {
        var title = 'Edit Decoration';
        if ( this.type == 'image' ) {
          title = 'Edit Image';
        }
        else if ( this.type == 'effect' ) {
          title = 'Edit Snow Effect';
        }
        else if ( this.type == 'video' ) {
          title = 'Edit Video';
        }
        else if ( this.type == 'note' ) {
          title = 'Edit Note';
        }
        else if ( this.type == 'box' ) {
          title = 'Edit Box';
        }
        return title;
      },

      //
      //Build tab
      buildTab: function()
      {
        var tab   = $( '<div class="ippdc-option-tab ippdc-clear"></div>' );
        var menus = $( '<ul></ul>' );

        if ( this.type == 'note' || this.type == 'box' ) {
          menus.append( this.buildTabMenu( 'content', 'Content' ) );
        }
        if ( this.type == 'video' ) {
          menus.append( this.buildTabMenu( 'video', 'Video' ) );
        }
        menus.append( this.buildTabMenu( 'style', 'Style' ) );

        if ( this.type != 'effect' ) {
          menus.append( this.buildTabMenu( 'position', 'Position' ) );
        }
        menus.append( this.buildTabMenu( 'duration', 'Duration' ) );

        menus.appendTo( tab );
        return tab;
      },

      //
      //Build tab menu
      buildTabMenu: function( name, label )
      {
        var menuWrap = $( '<li class="ippdc-tab-menu"></li>' );
        var menu     = $( '<a href="#ippdc-tab-content-' + name + '"></a>').text( label );
        menu.click( function()
        {
          var option = $(this).parents( '.ippdc-deco-option' );
          var target = $(this).attr( 'href' );
          if ( $( target, option ).length > 0 )
          {
            $( '.ippdc-option-tab a', option ).removeClass( 'active' );
            $( '.ippdc-option-tab-content', option ).hide();
            $(this).addClass( 'active' );
            $( target, option ).show();
          }

          return false;
        });

        menu.appendTo( menuWrap );
        return menuWrap;
      },

      //
      //Build close link for option
      buildOptionClose: function()
      {
        var close  = $( '<div class="ippdc-option-close"></div>' );
        var link   = $( '<a href="#"><i class="ippdc-fa ippdc-fa-times"></i></a>' );
        link.click( function()
        {
          var option = $(this).parents( '.ippdc-deco-option' );
          var deco   = $(this).parents( '.ippdc-deco-item' );
          option.removeClass( 'open' );
          $( '.ippdc-deco-action-edit', deco ).removeClass( 'active' );

          return false;
        });

        link.appendTo( close );
        return close;
      },

      //
      //Build main
      buildMain: function( optionCallback )
      {
        var main     = $( '<div class="ippdc-option-main"></div>' );
        var duration = this.buildTabDuration();
        var others   = optionCallback( this );

        if ( this.type != 'effect' ) {
          var position = this.buildTabPosition();
          main.append( position );
        }
        main.append( duration );
        main.append( others );
        return main;
      },

      //
      //Build tab position
      buildTabPosition: function()
      {
        var tab = $( '<div id="ippdc-tab-content-position" class="ippdc-option-tab-content"></div>' );
        tab.append( this.buildFieldTop( false ) )
           .append( this.buildFieldLeft( false ) )
           .append( this.buildFieldPositionHelper( false ) )
           .append( this.buildFieldZIndex( false ) )
           .hide();


        return tab;
      },

      //
      //Build tab duration
      buildTabDuration: function()
      {
        var tab = $( '<div id="ippdc-tab-content-duration" class="ippdc-option-tab-content"></div>' );
        tab.append( this.buildFieldDateStart( false ) )
           .append( this.buildFieldDateEnd( false ) )
           .hide();

        return tab;
      },

      //
      //Build field opacity
      buildFieldOpacity: function( value )
      {
        if ( this.options.opacity != undefined ) {
          value = this.options.opacity;
        }
        var field = this.buildFieldInputSm( 'Opacity', 'opacity', value, function( el )
        {
          var opacity = el.val();
          var deco    = el.parents( '.ippdc-deco-item' );

          if ( $( '.ippdc-deco-style-opacity', deco ).length > 0 ) {
            $( '.ippdc-deco-style-opacity', deco ).css( 'opacity', opacity );
          }
        });
        return field;
      },

      //
      //Build field height
      buildFieldHeight: function( value )
      {
        if ( this.options.height != undefined ) {
          value = this.options.height;
        }
        var field = this.buildFieldSize( 'Height', 'height', value, function( el )
        {
          var height = el.val();
          var deco   = el.parents( '.ippdc-deco-item' );

          if ( $( '.ippdc-deco-style-height', deco ).length > 0 ) {
            $( '.ippdc-deco-style-height', deco ).css( 'height', height );
          }
        });
        return field;
      },

      //
      //Build field width
      buildFieldWidth: function( value )
      {
        if ( this.options.width != undefined ) {
          value = this.options.width;
        }
        var field = this.buildFieldSize( 'Width', 'width', value, function( el )
        {
          var width = el.val();
          var deco  = el.parents( '.ippdc-deco-item' );

          if ( $( '.ippdc-deco-style-width', deco ).length > 0 ) {
            $( '.ippdc-deco-style-width', deco ).css( 'width', width );
          }
        });
        return field;
      },

      //
      //Build field top
      buildFieldTop: function( value )
      {
        if ( this.options.top != undefined ) {
          value = this.options.top;
        }
        var field = this.buildFieldSize( 'Top', 'top', value, function( el )
        {
          var top  = el.val();
          var deco = el.parents( '.ippdc-deco-item' );
          deco.css( 'top', top+'px' );
        });
        return field;
      },

      //
      //Build field left
      buildFieldLeft: function( value )
      {
        if ( this.options.left != undefined ) {
          value = this.options.left;
        }
        var field = this.buildFieldSize( 'Left', 'left', value, function( el )
        {
          var left = el.val();
          var deco = el.parents( '.ippdc-deco-item' );
          deco.css( 'left', left+'px' );
        });
        return field;
      },

      //
      //Build field z-index
      buildFieldZIndex: function( value )
      {
        if ( this.options.zindex != undefined ) {
          value = this.options.zindex;
        }
        var field = this.buildFieldInputSm( 'Z-Index', 'zindex', value, function( el )
        {
          var index = el.val();
          var deco = el.parents( '.ippdc-deco-item' );
          deco.css( 'z-index', index );
        });
        return field;
      },

      //
      //Build field color
      buildFieldColor: function( value )
      {
        if ( this.options.color != undefined ) {
          value = this.options.color;
        }
        var field = this.buildFieldInputColor( 'Color', 'color', value, function( input, hex )
        {
          var deco = input.parents( '.ippdc-deco-item' );
          if ( $( '.ippdc-deco-style-color', deco ).length > 0 ) {
            $( '.ippdc-deco-style-color', deco ).css( 'color', '#' + hex );
          }
        });
        return field;
      },

      //
      //Build field bakground color
      buildFieldBgColor: function( value )
      {
        if ( this.options.bgcolor != undefined ) {
          value = this.options.bgcolor;
        }
        var field = this.buildFieldInputColor( 'Background Color', 'bgcolor', value, function( input, hex )
        {
          var deco = input.parents( '.ippdc-deco-item' );
          if ( $( '.ippdc-deco-style-bgcolor', deco ).length > 0 ) {
            $( '.ippdc-deco-style-bgcolor', deco ).css( 'background-color', '#' + hex );
          }
        });
        return field;
      },

      //
      //Build field border
      buildFieldBorder: function( border_size, border_color )
      {
        if ( this.options.border_color != undefined ) {
          border_color = this.options.border_color;
        }
        if ( this.options.border_size != undefined ) {
          border_size = this.options.border_size;
        }
        var inputBorder = $( '<div class="ippdc-option-input-border"></div>' );

        //
        //Input size
        var inputSize   = $( '<input type="text" class="ippdc-option-control ippdc-option-control-xs">' );
        if ( border_size ) {
          inputSize.attr( 'value', border_size );
        }
        inputSize.attr( 'name', 'border_size' )
                 .change(function(el)
                 {
                   var bosize = $(this).val();
                   var deco   = $(this).parents( '.ippdc-deco-item' );

                   if ( $( '.ippdc-deco-style-border', deco ).length > 0 ) {
                     $( '.ippdc-deco-style-border', deco ).css( 'borderWidth', bosize+'px' );
                   }
                 });

        //
        //Input color
        var inputColor    = $( '<div id="colorSelector"><div></div></div>' );
        var inputColorVal = $( '<input type="hidden" class="ippdc-color-picker">' );

        if ( border_color ) {
          inputColorVal.attr( 'value', border_color );
          inputColor.css('backgroundColor', border_color);
        }
        inputColorVal.attr( 'name', 'border_color' );
        inputColor.ColorPicker({
          onSubmit: function(hsb, hex, rgb, el)
          {
            var selector = $(el);
            $( 'input', selector ).val('#'+hex);
		        $(el).ColorPickerHide();
            $('div', selector).css('backgroundColor', '#' + hex);

            var deco = selector.parents( '.ippdc-deco-item' );
            if ( $( '.ippdc-deco-style-border', deco ).length > 0 ) {
              $( '.ippdc-deco-style-border', deco ).css( 'borderColor', '#' + hex );
            }
          }
        }).bind('keyup', function(){
        	$(this).ColorPickerSetColor(this.value);
        });

        var inputSizeGroup = $( '<div class="ippdc-option-input-group"></div>' );
        inputSizeGroup.append( inputSize )
                      .append( '<span class="ippdc-option-input-addon">px</span>' );

        inputBorder.append( inputSizeGroup );
        inputColor.append( inputColorVal );
        inputBorder.append( inputColor );

        var field = this.buildField( 'Border', inputBorder );
        return field;
      },

      //
      //Build field position helper
      buildFieldPositionHelper: function( value )
      {
        if ( this.options.poshelper != undefined ) {
          value = this.options.poshelper;
        }
        var data  = [
          {
            'label': 'Top Left of Page',
            'value': 'topleft'
          },
          {
            'label': 'Top Center of Page',
            'value': 'topcenter'
          },
          {
            'label': 'Top Right of Page',
            'value': 'topright'
          },
          {
            'label': 'Middle Left of Page',
            'value': 'middleleft'
          },
          {
            'label': 'Middle Center of Page',
            'value': 'middlecenter'
          },
          {
            'label': 'Middle Right of Page',
            'value': 'middleright'
          },
          {
            'label': 'Bottom Left of Page',
            'value': 'bottomleft'
          },
          {
            'label': 'Bottom Center of Page',
            'value': 'bottomcenter'
          },
          {
            'label': 'Bottom Right of Page',
            'value': 'bottomright'
          }
        ];
        var field = this.buildFieldSelect( 'Helper', 'pos_helper', data, value, function( el )
        {
          var type = el.val();
          var deco = el.parents( '.ippdc-deco-item' );
          positionfunc.setPosition( type, deco );
        });
        return field;
      },

      //
      //Build field date start
      buildFieldDateStart: function( value )
      {
        if ( this.options.start != undefined ) {
          value = this.options.start;
        }
        var field = this.buildFieldInputDate( 'Date Start', 'date_start', value,
        {
          format: 'd-m-Y h:i:s'
        });
        return field;
      },

      //
      //Build field date end
      buildFieldDateEnd: function( value )
      {
        if ( this.options.end != undefined ) {
          value = this.options.end;
        }
        var field = this.buildFieldInputDate( 'Date End', 'date_end', value,
        {
          format: 'd-m-Y h:i:s'
        });
        return field;
      },

      //
      //Build field
      buildFieldSize: function( label, name, value, changeCallback )
      {
        var inputGroup = $( '<div class="ippdc-option-input-group"></div>' );
        var inputCtrl  = $( '<input type="text" class="ippdc-option-control ippdc-option-control-sm">' );

        if ( value ) {
          inputCtrl.attr( 'value', value );
        }
        inputCtrl.attr( 'name', name )
                 .change(function()
                 {
                    changeCallback( $(this) );
                 });

        inputGroup.append( inputCtrl )
                  .append( '<span class="ippdc-option-input-addon">px</span>' );

        var field = this.buildField( label, inputGroup );
        return field;
      },

      //
      //Build field input
      buildFieldInput: function( label, name, value, changeCallback )
      {
        var input = $( '<input type="text" class="ippdc-option-control">' );

        if ( value ) {
          input.attr( 'value', value );
        }
        input.attr( 'name', name )
             .change(function()
             {
                changeCallback( $(this) );
             });

        var field = this.buildField( label, input );
        return field;
      },

      //
      //Build field input sm
      buildFieldInputSm: function( label, name, value, changeCallback )
      {
        var input = $( '<input type="text" class="ippdc-option-control ippdc-option-control-sm">' );

        if ( value ) {
          input.attr( 'value', value );
        }
        input.attr( 'name', name )
             .change(function()
             {
                changeCallback( $(this) );
             });

        var field = this.buildField( label, input );
        return field;
      },

      //
      //Build field textarea
      buildFieldTextarea: function( label, name, value, changeCallback )
      {
        var input = $( '<textarea class="ippdc-option-control"></textarea>' );

        if ( value ) {
          input.val( value );
        }
        input.attr( 'name', name )
             .change(function()
             {
                changeCallback( $(this) );
             });

        var field = this.buildField( label, input );
        return field;
      },

      //
      //Build field select
      buildFieldSelect: function( label, name, data, value, changeCallback )
      {
        var select = $( '<select class="ippdc-option-control"></select>' );
        select.attr( 'name', name )
              .change(function()
              {
                changeCallback( $(this) );
              });

        if ( data )
        {
          for( var i = 0; i < data.length; i++ )
          {
            select.append(
              $( '<option></option>')
                .attr( 'value', data[i].value )
                .text( data[i].label )
            );
          }
        }
        if ( value ) {
          select.val( value );
        }
        var field = this.buildField( label, select );
        return field;
      },

      //
      //Build field input date
      buildFieldInputDate: function( label, name, value, dtoptions )
      {
        var input = $( '<input type="text" class="ippdc-option-control ippdc-option-control-sm ippdc-option-datetime">' );

        if ( value ) {
          input.attr( 'value', value );
        }
        input.attr( 'name', name );
        input.datetimepicker( dtoptions );

        var field = this.buildField( label, input );
        return field;
      },

      //
      //Build field input color
      buildFieldInputColor: function( label, name, value, changeCallback )
      {
        var input    = $( '<div id="colorSelector"><div></div></div>' );
        var inputVal = $( '<input type="hidden" class="ippdc-color-picker">' );

        if ( value ) {
          inputVal.attr( 'value', value );
          input.css('backgroundColor', value);
        }
        inputVal.attr( 'name', name );
        input.ColorPicker({
          onSubmit: function(hsb, hex, rgb, el)
          {
            var selector = $(el);
            $( 'input', selector ).val('#'+hex);
		        $(el).ColorPickerHide();
            $('div', selector).css('backgroundColor', '#' + hex);
            //callback
            changeCallback( selector, hex );
          }
        }).bind('keyup', function(){
        	$(this).ColorPickerSetColor(this.value);
        });

        input.append( inputVal );

        var field = this.buildField( label, input );
        return field;
      },

      //
      //Build field
      buildField: function( label, input )
      {
        var field = $( '<div class="ippdc-option-field ippdc-clear"></div>' );
        field.append( $( '<label></label>').text( label ) );
        field.append(
          $( '<div class="ippdc-option-input"></div>' ).append( input )
        );

        return field;
      },

      //
      //Build footer
      buildFooter: function()
      {
        var footer = $( '<div class="ippdc-option-footer"></div>' );
        var inner  = $( '<div class="ippdc-footer-inner ippdc-clear"></div>' );

        var btnSave   = this.buildButtonSave();
        var btnDelete = this.buildButtonDelete();
        inner.append( btnSave );
        inner.append( btnDelete );

        inner.appendTo( footer );
        return footer;
      },

      //
      //Build button save
      buildButtonSave: function()
      {
        var self        = this;
        var btnSaveWrap = $( '<div class="ippdc-save"></div>' );
        var btnSave     = $( '<a href="#" class="ippdc-save-link">Save Change</a>' );
        btnSave.click( function()
        {
          //
          //Show loader
          var loader = $('[data-remodal-id="ippcd-modal-loader"]').remodal();
          loader.open();

          var deco = $(this).parents( '.ippdc-deco-action-trigger' );
          var type = deco.data( 'type' );
          var id   = deco.attr( 'data-id' );

          var ajaxUrl  = ippdc_ajaxurl + '?doajax=1&ippdc=1&action=save_decoration&type=' + type;
          ajaxUrl += '&page_type=' + ippdc_typePage + '&postid=' + ippdc_postId;

          var formdata  = $( '.ippdc-deco-option form', deco ).serialize();
          var winHeight = $(window).height();
          var winWidth  = $(window).width();
          formdata += '&deco_id=' + id;
          formdata += '&window_height=' + winHeight;
          formdata += '&window_width=' + winWidth;

          $.ajax({
            url: ajaxUrl,
            type: "POST",
            dataType: "json",
            data: formdata,
            success: function ( response )
            {
              //
              //Hide loader
              loader.close();
              if ( response.status == 1 )
              {
                //Show message
                var modal = $('[data-remodal-id="ippcd-modal-success-edit"]').remodal();
                modal.open();
              }
              else {
                //Show message
                var modal = $('[data-remodal-id="ippcd-modal-error-edit"]').remodal();
                modal.open();
              }
            }
          });
          return false;
        });

        btnSave.appendTo( btnSaveWrap );
        return btnSaveWrap;
      },

      //
      //Build button delete
      buildButtonDelete: function()
      {
        var self = this;
        var btnDeleteWrap = $( '<div class="ippdc-delete"></div>' );
        var btnDelete     = $( '<a href="#" class="ippdc-delete-link">Delete</a>' );
        btnDelete.click( function()
        {
          //
          //Show loader
          var loader = $('[data-remodal-id="ippcd-modal-loader"]').remodal();
          loader.open();

          var deco    = $(this).parents( '.ippdc-deco-action-trigger' );
          var id      = deco.attr( 'data-id' );
          var ajaxUrl = ippdc_ajaxurl + '?doajax=1&ippdc=1&action=delete_decoration';
          var data    = 'id='+id;

          $.ajax({
            url: ajaxUrl,
            type: "POST",
            dataType: "json",
            data: data,
            success: function ( response )
            {
              //
              //Hide loader
              loader.close();
              
              if ( response.status == 1 || response.status == '1' )
              {
                //Show message
                var modal = $('[data-remodal-id="ippcd-modal-success-delete"]').remodal();
                modal.open();
                //remove deco item
                deco.remove();
                $( '.ippdc-front-deco[data-id="'+id+'"]' ).remove();

                //Snow effect reset
                if ( self.type == 'effect' )
                {
                  $('body').snowfall('clear');
                  self.rebuildEffect();

                  if ( $( '.ippdc-front-deco[data-type="'+type+'"]' ).length < 1 ) {
                    $( '.ippdc-front-effect-edit' ).hide();
                  }
                }
              }
              else {
                //Show message
                var modal = $('[data-remodal-id="ippcd-modal-error-delete"]').remodal();
                modal.open();
              }
            }
          });
          return false;
        });

        btnDelete.appendTo( btnDeleteWrap );
        return btnDeleteWrap;
      },

      //
      //Rebuild effect
      rebuildEffect: function()
      {
        var self = this;
        $( '.ippdc-front-deco[data-type="effect"]' ).each( function()
        {
          var item = $(this);
          var datasett = $( '.ippdc-front-deco-settings', item );
          var buildOpts = {};

          //Effect Color
          var dataColor = datasett.data( 'color' );
          if ( dataColor != undefined && dataColor != '' ) {
            buildOpts.effect_color = dataColor;
          }

          //Effect Type
          var dataType = datasett.data( 'type' );
          if ( dataType != undefined && dataType != '' ) {
            buildOpts.effect_type = dataType;
          }

          self.getEffect( buildOpts );
        });
      },

      //
      //Get effect
      getEffect: function( data )
      {
        var snowColor   = this.getEffectColor( data.effect_color );
        var snowOptions = {};
        if ( data.effect_type == 'snow' )
        {
          snowOptions = {
            flakeCount : 30,
            flakeColor: snowColor,
            round : true,
            minSize: 6,
            maxSize: 10
          }
        }
        else if ( data.effect_type == 'snowflake' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'snowflake_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        else if ( data.effect_type == 'star' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'star_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        else if ( data.effect_type == 'leaf' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'leaf_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        else if ( data.effect_type == 'hexagon' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'hexagonal_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        else if ( data.effect_type == 'droplet' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'droplet_' + data.effect_color + '.svg',
            minSize: 5,
            maxSize: 30
          }
        }
        else if ( data.effect_type == 'sun' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'sun_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        else if ( data.effect_type == 'cloud' )
        {
          snowOptions = {
            flakeCount : 30,
            image: ippdc_effect_img_url + 'cloud_' + data.effect_color + '.svg',
            minSize: 10,
            maxSize: 32
          }
        }
        $('body').addClass( 'ippdc-snow-on' );
        $('body').snowfall( snowOptions );
      },

      //
      //Get effect color
      getEffectColor: function( color )
      {
        var hex = '#ffffff';
        if ( color == 'black' ) {
          hex = '#000000';
        }
        else if ( color == 'blue' ) {
          hex = '#2f74e7';
        }
        else if ( color == 'light_blue' ) {
          hex = '#20d0d6';
        }
        else if ( color == 'red' ) {
          hex = '#e43333';
        }
        else if ( color == 'green' ) {
          hex = '#72c462';
        }
        else if ( color == 'orange' ) {
          hex = '#e59547';
        }
        else if ( color == 'yellow' ) {
          hex = '#ffcd50';
        }
        return hex;
      }

    };

})(jQuery);

module.exports = ippdc_option;

},{"./position.js":12}],12:[function(require,module,exports){
/*
 *===========================================================
 * Positioning Function
 *===========================================================*/

var ippdc_position;
(function($)
{
    "use strict";

    ippdc_position =
    {
      isFront: false,
      //
      // Set position
      setPosition: function( type, deco )
      {
        if ( type == 'topleft' ){
          this.setPositionManual( 'top', 'left', deco );
        }
        else if ( type == 'topcenter' ){
          this.setPositionManual( 'top', 'center', deco );
        }
        else if ( type == 'topright' ){
          this.setPositionManual( 'top', 'right', deco );
        }
        else if ( type == 'middleleft' ){
          this.setPositionManual( 'middle', 'left', deco );
        }
        else if ( type == 'middlecenter' ){
          this.setPositionManual( 'middle', 'center', deco );
        }
        else if ( type == 'middleright' ){
          this.setPositionManual( 'middle', 'right', deco );
        }
        else if ( type == 'bottomleft' ){
          this.setPositionManual( 'bottom', 'left', deco );
        }
        else if ( type == 'bottomcenter' ){
          this.setPositionManual( 'bottom', 'center', deco );
        }
        else if ( type == 'bottomright' ){
          this.setPositionManual( 'bottom', 'right', deco );
        }
      },

      //
      // Set position manual
      setPositionManual: function( y, x, deco )
      {
        var decoHeight = deco.outerHeight();
        var decoWidth  = deco.outerWidth();
        var pageHeight = $( 'body' ).height();
        var winWidth   = $(window).width();

        if ( y == 'top' ) {
          y = 20;
        }
        else if ( y == 'bottom' ) {
          y = pageHeight - decoHeight - 20;
        }
        else if ( y == 'middle' ) {
          y = (pageHeight - decoHeight)/2;
        }

        if ( x == 'left' ) {
          x = 20;
        }
        else if ( x == 'right' ) {
          x = winWidth - decoWidth - 20;
        }
        else if ( x == 'center' ) {
          x = (winWidth - decoWidth)/2;
        }

        deco.css( 'top', y + 'px' );
        deco.css( 'left', x + 'px' );

        deco.find( 'input[name="top"]' ).val( y );
        deco.find( 'input[name="left"]' ).val( x );

        if ( ! this.isFront ) {
          this.moveScroll( y );
        }
      },

      //
      // Move scroll
      moveScroll: function( top )
      {
        $('html, body').animate({
          scrollTop: top
        }, 800);
      }
    };

})(jQuery);

module.exports = ippdc_position;

},{}],13:[function(require,module,exports){
/*
 *===========================================================
 * Video Function
 *===========================================================*/
var error      = require( './error.js' );
var helper     = require( './helper.js' );
var optionfunc = require( './option.js' );

var ippdc_video;
(function($)
{
    "use strict";

    ippdc_video =
    {
      //
      //Init
      init: function()
      {
        var self = this;

        if ( $( '#ippdc-form-video' ).length > 0 )
        {
          $( '#ippdc-form-video button[type=submit]' ).click( function()
          {
            error.resetError();

            var id     = $( '#ippdc-input-video-id' ).val();
            var auto   = $( '#ippdc-input-video-autoplay' ).val();
            var width  = $( '#ippdc-input-video-width' ).val();
            var height = $( '#ippdc-input-video-height' ).val();

            //check errors
            error.checkError( id, 'video_id', 'string' );
            error.checkError( auto, 'video_autoplay', 'string' );
            error.checkError( width, 'video_width', 'string' );
            error.checkError( height, 'video_height', 'string' );

            if ( ! error.isError() )
            {
              //Close modal
              var inst  = $('[data-remodal-id="ippcd-modal-video"]').remodal();
              inst.close();

              //Clear form
              $( '#ippdc-form-video' )[0].reset();

              //Save data
              self.saveDecoration({
                'video_id': id,
                'autoplay': auto,
                'width':    width,
                'height':   height,
              });
            }
            else {
              error.showError( $(this) );
            }
            return false;
          });
        }
      },

      //
      //Save decoration
      saveDecoration: function( data )
      {
        var self = this;
        helper.saveDecoration( 'video', data, function( response )
        {
          var content = self.getVideo( data, data );
          helper.addDecoration( 'video', response, content, function( option ){
            return self.buildOptions( data, response );
          });
        });
      },

      //
      //Get video
      getVideo: function( data, response )
      {
        var wrapclass = 'ippdc-deco-box-video ippdc-deco-style-width ippdc-deco-style-height';

        var boxwrap = $( '<div class="' + wrapclass + '"></div>' );
        boxwrap.height( response.height );
        boxwrap.width( response.width );

        var videoIframe = this.getVideoIframe( data.video_id, data.autoplay, response );
        videoIframe.appendTo( boxwrap );

        return boxwrap;
      },

      //
      //Get video iframe
      getVideoIframe: function( id, autoplay, options )
      {
        var videoUrl    = "https://www.youtube.com/embed/" + id + "?autoplay=" + autoplay + "&autohide=1";
        var videoIframe = $( '<iframe class="ippdc-deco-style-width ippdc-deco-style-height"></iframe>');
        videoIframe.attr( 'src', videoUrl )
                   .attr( 'frameborder', '0' );

        videoIframe.width( options.width );
        videoIframe.height( options.height );

        return videoIframe;
      },

      //
      //Build options
      buildOptions: function( data, options )
      {
        var fields = $( '<div class="ippdc-video-fields"></div>' );
        fields.append( this.buildOptionStyle( data, options ) );
        fields.append( this.buildOptionVideo( data, options ) );

        return fields;
      },

      //
      //Build option style
      buildOptionStyle: function( data, options )
      {
        var field = $( '<div id="ippdc-tab-content-style" class="ippdc-option-tab-content"></div>' );
        field.append( optionfunc.buildFieldOpacity( false ) )
             .append( optionfunc.buildFieldWidth( data.width ) )
             .append( optionfunc.buildFieldHeight( data.height ) )
             .hide();

        return field;
      },

      //
      //Build option video
      buildOptionVideo: function( data, options )
      {
        var self  = this;
        var field = $( '<div id="ippdc-tab-content-video" class="ippdc-option-tab-content"></div>' );

        //
        // Video ID
        field.append( optionfunc.buildFieldInput( 'Video ID', 'video_id', data.video_id, function(input)
          {
            var id   = input.val();
            var deco = input.parents( '.ippdc-deco-item' );
            if ( $( '.ippdc-deco-box-video', deco ).length > 0 )
            {
              var autoplay = $( 'input[name="autoplay"]', deco ).val();
              var width    = $( '.ippdc-deco-box-video', deco ).width();
              var height   = $( '.ippdc-deco-box-video', deco ).height();
              var iframe   = self.getVideoIframe( id, autoplay, {
                'width': width,
                'height': height
              });
              $( '.ippdc-deco-box-video', deco ).html( iframe );
            }
          })
        );

        var options = [
          {
            'label': 'Yes',
            'value': '1'
          },
          {
            'label': 'No',
            'value': '0'
          }
        ];
        //
        // Video Autoplay
        var auto = false;
        if ( options.autoplay != undefined ) {
          auto = options.autoplay;
        }
        var fieldAutoplay = optionfunc.buildFieldSelect( 'Autoplay', 'autoplay', options, auto, function( el )
        {
          var autoplay = input.val();
          var deco     = input.parents( '.ippdc-deco-item' );
          if ( $( '.ippdc-deco-box-video', deco ).length > 0 )
          {
            var id     = $( 'input[name="video_id"]', deco ).val();
            var width  = $( '.ippdc-deco-box-video', deco ).width();
            var height = $( '.ippdc-deco-box-video', deco ).height();
            var iframe = self.getVideoIframe( id, autoplay, {
              'width': width,
              'height': height
            });
            $( '.ippdc-deco-box-video', deco ).html( iframe );
          }
        });
        field.append( fieldAutoplay );

        return field;
      },
    };

})(jQuery);

module.exports = ippdc_video;

},{"./error.js":6,"./helper.js":8,"./option.js":11}]},{},[1]);
